/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_0HucXN3z);
  numBytes += sLine_init(&sLine_nDMOLc3m);
  numBytes += sLine_init(&sLine_BYH4uA5Y);
  numBytes += sLine_init(&sLine_PXg2JSPZ);
  numBytes += sLine_init(&sLine_s6oSb9gt);
  numBytes += sBiquad_init(&sBiquad_s_LthPhTIT);
  numBytes += sLine_init(&sLine_e8xxJOS0);
  numBytes += sLine_init(&sLine_PbDBYzb8);
  numBytes += sLine_init(&sLine_5I6MSQ4v);
  numBytes += sLine_init(&sLine_H7sQ16gl);
  numBytes += sLine_init(&sLine_xX4wplt8);
  numBytes += sBiquad_init(&sBiquad_s_xctzSyh3);
  numBytes += sLine_init(&sLine_tL7mhmue);
  numBytes += sLine_init(&sLine_m0KcAdht);
  numBytes += sLine_init(&sLine_S0f2ihLX);
  numBytes += sLine_init(&sLine_0PbuoEW9);
  numBytes += sLine_init(&sLine_P71gEBTC);
  numBytes += sLine_init(&sLine_DBFz2biW);
  numBytes += sBiquad_init(&sBiquad_s_zGONn4Mv);
  numBytes += sLine_init(&sLine_2TA6eTbV);
  numBytes += sLine_init(&sLine_YtZgQT4O);
  numBytes += sLine_init(&sLine_DDscuPlK);
  numBytes += sLine_init(&sLine_Qq0cSRym);
  numBytes += sLine_init(&sLine_iORoK5K4);
  numBytes += sLine_init(&sLine_UUagzppM);
  numBytes += sBiquad_init(&sBiquad_s_gFbCgZ6o);
  numBytes += sLine_init(&sLine_7xxPHLLZ);
  numBytes += sLine_init(&sLine_6iY1H8Kd);
  numBytes += sLine_init(&sLine_cjEFPaVo);
  numBytes += sLine_init(&sLine_PZUJhcZk);
  numBytes += sLine_init(&sLine_lWkhNk3t);
  numBytes += sBiquad_init(&sBiquad_s_ISk06CUF);
  numBytes += sLine_init(&sLine_hQFqWAMI);
  numBytes += sLine_init(&sLine_LLrVIbIJ);
  numBytes += sLine_init(&sLine_PvYeXCpk);
  numBytes += sLine_init(&sLine_kBsVJ50Q);
  numBytes += sLine_init(&sLine_b1AdTQDL);
  numBytes += sLine_init(&sLine_9SDkS5Mb);
  numBytes += sBiquad_init(&sBiquad_s_JqCaNrYb);
  numBytes += sLine_init(&sLine_o1AaAOB1);
  numBytes += sLine_init(&sLine_pY30rcy8);
  numBytes += sLine_init(&sLine_xQHU0Epf);
  numBytes += sLine_init(&sLine_8BOBNoKg);
  numBytes += sLine_init(&sLine_qYrhfA9V);
  numBytes += sLine_init(&sLine_rv7q04gf);
  numBytes += sLine_init(&sLine_zEks98oB);
  numBytes += sLine_init(&sLine_M8CCoqfr);
  numBytes += sLine_init(&sLine_MRRdV0yh);
  numBytes += sLine_init(&sLine_2fBuFhsA);
  numBytes += sLine_init(&sLine_zG2tIeqh);
  numBytes += sLine_init(&sLine_yHlGqKyB);
  numBytes += sLine_init(&sLine_zDS0866T);
  numBytes += sLine_init(&sLine_ZUn0YUQJ);
  numBytes += sLine_init(&sLine_hkYgUgXE);
  numBytes += sEnv_init(&sEnv_GgxBQ18X, 512, 256);
  numBytes += sEnv_init(&sEnv_rrgeOUly, 512, 256);
  numBytes += sLine_init(&sLine_wqpsTZL8);
  numBytes += sLine_init(&sLine_2fOMXUgw);
  numBytes += sLine_init(&sLine_b6Qfohmy);
  numBytes += sLine_init(&sLine_Ebb8WwMA);
  numBytes += sLine_init(&sLine_FhWVJ0zi);
  numBytes += sLine_init(&sLine_xo0QmQVi);
  numBytes += sLine_init(&sLine_o8SlLqDS);
  numBytes += sLine_init(&sLine_oMK9TRn3);
  numBytes += sLine_init(&sLine_x6RgB9WE);
  numBytes += sLine_init(&sLine_YyQEh9u7);
  numBytes += sLine_init(&sLine_f1E1Uy1W);
  numBytes += sLine_init(&sLine_HsoUeM5i);
  numBytes += sLine_init(&sLine_6Mt26uGm);
  numBytes += sLine_init(&sLine_I5DCrMpQ);
  numBytes += sLine_init(&sLine_ck43FXAX);
  numBytes += sLine_init(&sLine_eDgg0PwA);
  numBytes += sLine_init(&sLine_pxW1SLgH);
  numBytes += sLine_init(&sLine_BHHkwTaM);
  numBytes += sEnv_init(&sEnv_erGK5Qki, 512, 256);
  numBytes += sEnv_init(&sEnv_7ILklKDO, 512, 256);
  numBytes += sLine_init(&sLine_gfm3mWj8);
  numBytes += sLine_init(&sLine_92HnC1Vy);
  numBytes += sLine_init(&sLine_PWnysAH7);
  numBytes += sLine_init(&sLine_Lezhu0b1);
  numBytes += sLine_init(&sLine_UGLpcDgt);
  numBytes += sLine_init(&sLine_dNucvAGq);
  numBytes += sLine_init(&sLine_3xmGkRcs);
  numBytes += sLine_init(&sLine_VHFDXA5G);
  numBytes += sLine_init(&sLine_ajge1EVh);
  numBytes += sLine_init(&sLine_xSRmXzF8);
  numBytes += sLine_init(&sLine_8CLskRsg);
  numBytes += sLine_init(&sLine_VHjPO0HH);
  numBytes += sLine_init(&sLine_4NevKAYw);
  numBytes += sLine_init(&sLine_qgWseyf9);
  numBytes += sLine_init(&sLine_Oc8aIfMv);
  numBytes += sLine_init(&sLine_cebGtGv0);
  numBytes += sLine_init(&sLine_PAbkkNZ5);
  numBytes += sLine_init(&sLine_IN6LGc5O);
  numBytes += sLine_init(&sLine_f1H87OMH);
  numBytes += sLine_init(&sLine_cS8NfZw1);
  numBytes += sEnv_init(&sEnv_jHkLDs2A, 512, 256);
  numBytes += sEnv_init(&sEnv_M1ztaHkP, 512, 256);
  numBytes += sLine_init(&sLine_Cs1Tkt1O);
  numBytes += sLine_init(&sLine_nayA95MO);
  numBytes += sLine_init(&sLine_YCcuSv6S);
  numBytes += sLine_init(&sLine_BVRin6cN);
  numBytes += sLine_init(&sLine_V8ZGuZjh);
  numBytes += sLine_init(&sLine_UY8DMc2t);
  numBytes += sLine_init(&sLine_atYrB240);
  numBytes += sLine_init(&sLine_Chh7glFY);
  numBytes += sLine_init(&sLine_r9UnceFd);
  numBytes += sLine_init(&sLine_lj11PxgX);
  numBytes += sLine_init(&sLine_hWSIOwf6);
  numBytes += sLine_init(&sLine_wzTPAB9p);
  numBytes += sLine_init(&sLine_nt5YWIPu);
  numBytes += sLine_init(&sLine_Fs1yZxSE);
  numBytes += sLine_init(&sLine_0sqKPS0W);
  numBytes += sLine_init(&sLine_5TgBz0pp);
  numBytes += sLine_init(&sLine_SGgnbdf8);
  numBytes += sLine_init(&sLine_9tt20iza);
  numBytes += sEnv_init(&sEnv_Aw4s6Ktc, 512, 256);
  numBytes += sEnv_init(&sEnv_6nZ2nBEy, 512, 256);
  numBytes += sLine_init(&sLine_uHp4Nza9);
  numBytes += sLine_init(&sLine_dSRJfNfn);
  numBytes += sLine_init(&sLine_p4jwr0K8);
  numBytes += sLine_init(&sLine_db3rgKYx);
  numBytes += sLine_init(&sLine_RjI3XPcd);
  numBytes += sLine_init(&sLine_ebwkwDcR);
  numBytes += sLine_init(&sLine_9GagYI1W);
  numBytes += sLine_init(&sLine_n51eMeqk);
  numBytes += sLine_init(&sLine_MEFmCGvh);
  numBytes += sLine_init(&sLine_JUxH14t1);
  numBytes += sLine_init(&sLine_Yh34iFsi);
  numBytes += sLine_init(&sLine_h56eAOdX);
  numBytes += sLine_init(&sLine_4D4GoHrf);
  numBytes += sLine_init(&sLine_vci09NfC);
  numBytes += sLine_init(&sLine_lElvWhTQ);
  numBytes += sLine_init(&sLine_BNiOG6Z4);
  numBytes += sLine_init(&sLine_vj9jdnTJ);
  numBytes += sLine_init(&sLine_tR4OpRre);
  numBytes += sLine_init(&sLine_pl8jjA4C);
  numBytes += sLine_init(&sLine_UKq8yFOZ);
  numBytes += sEnv_init(&sEnv_aLJxoS6L, 512, 256);
  numBytes += sEnv_init(&sEnv_qKAlHCz7, 512, 256);
  numBytes += sLine_init(&sLine_AfVr09VM);
  numBytes += sLine_init(&sLine_PGQhgIhc);
  numBytes += sLine_init(&sLine_H1gR5cIP);
  numBytes += sLine_init(&sLine_ZznukeWS);
  numBytes += sLine_init(&sLine_mPHkToZa);
  numBytes += sLine_init(&sLine_y1rWFdUu);
  numBytes += sLine_init(&sLine_QSV7jF2H);
  numBytes += sLine_init(&sLine_VBzNERzf);
  numBytes += sLine_init(&sLine_G7K66R7F);
  numBytes += sLine_init(&sLine_oq5JqRbj);
  numBytes += sLine_init(&sLine_kb37IWWA);
  numBytes += sLine_init(&sLine_EhzHw3xI);
  numBytes += sLine_init(&sLine_NWPIlSaB);
  numBytes += sLine_init(&sLine_Km2eSX9z);
  numBytes += sLine_init(&sLine_27HAHVZx);
  numBytes += sLine_init(&sLine_TqENmSrB);
  numBytes += sLine_init(&sLine_Yn7gINbm);
  numBytes += sLine_init(&sLine_W81k2cl1);
  numBytes += sEnv_init(&sEnv_rdO8K1Wn, 512, 256);
  numBytes += sEnv_init(&sEnv_pARMQSOW, 512, 256);
  numBytes += sLine_init(&sLine_ZLv5Oz5S);
  numBytes += sLine_init(&sLine_EHB8fYs2);
  numBytes += sLine_init(&sLine_UmUlPt9H);
  numBytes += sLine_init(&sLine_e0qFycQ2);
  numBytes += sLine_init(&sLine_ysdqPJbW);
  numBytes += sLine_init(&sLine_MaiJM1Ul);
  numBytes += cVar_init_f(&cVar_0LoEddKJ, 0.0f);
  numBytes += cVar_init_f(&cVar_hnlavMnv, 0.0f);
  numBytes += cVar_init_f(&cVar_5wID3qSA, 0.0f);
  numBytes += cVar_init_f(&cVar_dq9SGiVh, 0.0f);
  numBytes += cVar_init_f(&cVar_T20VTnHs, 0.0f);
  numBytes += cVar_init_f(&cVar_WUyZb1WY, 1.0f);
  numBytes += cVar_init_f(&cVar_mRKCC2EJ, 0.0f);
  numBytes += cVar_init_f(&cVar_KhcheFgM, 0.0f);
  numBytes += cVar_init_f(&cVar_r0UQmc3K, 0.0f);
  numBytes += cVar_init_f(&cVar_pgsemKKD, 0.0f);
  numBytes += cSlice_init(&cSlice_0byqd8cN, 1, -1);
  numBytes += cVar_init_f(&cVar_SKMhT36u, 1337.0f);
  numBytes += cVar_init_f(&cVar_iiOc5bOy, 0.0f);
  numBytes += cIf_init(&cIf_6j5x3SkX, false);
  numBytes += cIf_init(&cIf_ZUdzliUj, false);
  numBytes += cBinop_init(&cBinop_M1nmh6Rf, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aLZX0GXp, false);
  numBytes += cBinop_init(&cBinop_dlSyf8BG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_i5BerGCm, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_kBYw6i5F, 0.0f);
  numBytes += cIf_init(&cIf_ph9M45sI, false);
  numBytes += cIf_init(&cIf_9xWCRUdL, false);
  numBytes += cBinop_init(&cBinop_yVdvWLHR, 0.0f); // __pow
  numBytes += cIf_init(&cIf_2nZPq9Eh, false);
  numBytes += cBinop_init(&cBinop_ONk6uOoY, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_GwpvfvAx, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_jHrluBJ9, 0.0f);
  numBytes += cIf_init(&cIf_Za0UaXwW, false);
  numBytes += cIf_init(&cIf_FZ2S4i7c, false);
  numBytes += cBinop_init(&cBinop_jnt6KkMn, 0.0f); // __pow
  numBytes += cIf_init(&cIf_LiqU0Ic0, false);
  numBytes += cBinop_init(&cBinop_X3vr1UQg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_OVCdyUHz, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Bd5O14oZ, false);
  numBytes += cSlice_init(&cSlice_YCYpqduB, 1, -1);
  numBytes += cVar_init_f(&cVar_pQOymYDR, 0.0f);
  numBytes += cSlice_init(&cSlice_HrS1K8ZN, 1, -1);
  numBytes += cVar_init_f(&cVar_EPMAoYsw, 0.0f);
  numBytes += cSlice_init(&cSlice_tSzmYo9c, 1, -1);
  numBytes += cVar_init_f(&cVar_UZIZ2knu, 0.0f);
  numBytes += cSlice_init(&cSlice_0AMGbXHZ, 1, -1);
  numBytes += cVar_init_f(&cVar_qSnwDKV4, 0.313f);
  numBytes += cBinop_init(&cBinop_7dHwnzbc, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_nbExkXkW, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_GghSnqyP, 0.0f);
  numBytes += cVar_init_f(&cVar_00XZKX25, 1337.0f);
  numBytes += cVar_init_f(&cVar_BkQ1HJXX, 0.3f);
  numBytes += cBinop_init(&cBinop_HmOB5Cu4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UCKaJxIz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GIPikKfk, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_izS7bBxF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Mh5UzhTI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6ECso3Gj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_U6sG0urL, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_bRo5QMzQ, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_c74WeSCg, 0.0f);
  numBytes += cVar_init_f(&cVar_waDHxliF, 1337.0f);
  numBytes += cVar_init_f(&cVar_rZrJK02e, 0.313f);
  numBytes += cBinop_init(&cBinop_g4OcvHgw, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3KGSQBxa, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dN996kdU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3mr4azHK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_InGC8K7i, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NOj85KN3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_e56gldAL, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1qxzVYLx, 0.0f);
  numBytes += cVar_init_f(&cVar_1kQ4UZ5P, 1037.0f);
  numBytes += cVar_init_f(&cVar_ZW8M5yM9, 0.4f);
  numBytes += cBinop_init(&cBinop_XLpTnhGW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uWQXErGz, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CgftqWZB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_J4BtovUv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RO0FzrQV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JLOMCqsd, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_093ba2nK, 1, -1);
  numBytes += cVar_init_f(&cVar_ppFs5YQH, 1337.0f);
  numBytes += cVar_init_f(&cVar_fOccWZGA, 0.0f);
  numBytes += cIf_init(&cIf_I6c6foyZ, false);
  numBytes += cIf_init(&cIf_mkxv8Htq, false);
  numBytes += cBinop_init(&cBinop_mhgePlBC, 0.0f); // __pow
  numBytes += cIf_init(&cIf_qcJvmQgC, false);
  numBytes += cBinop_init(&cBinop_4G5p1H6Q, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_figVwyLw, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_c8b1YwNa, 0.0f);
  numBytes += cIf_init(&cIf_7VMa0C9b, false);
  numBytes += cIf_init(&cIf_JVcS4pnR, false);
  numBytes += cBinop_init(&cBinop_avSDbuwu, 0.0f); // __pow
  numBytes += cIf_init(&cIf_fLtymR23, false);
  numBytes += cBinop_init(&cBinop_QNFpuVxf, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_R3XBIe0T, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Fu2LmynN, 0.0f);
  numBytes += cIf_init(&cIf_Rtx7921h, false);
  numBytes += cIf_init(&cIf_khbZ674p, false);
  numBytes += cBinop_init(&cBinop_ZOAwYyUt, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Zaf1eyW0, false);
  numBytes += cBinop_init(&cBinop_I6rGkXMp, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nkNG3usH, -15.0f); // __eq
  numBytes += cIf_init(&cIf_dNWvkJdP, false);
  numBytes += cSlice_init(&cSlice_yTm5Hjne, 1, -1);
  numBytes += cVar_init_f(&cVar_nM24sZTx, 0.0f);
  numBytes += cSlice_init(&cSlice_MWKlmICT, 1, -1);
  numBytes += cVar_init_f(&cVar_KmJueRo3, 0.0f);
  numBytes += cSlice_init(&cSlice_4fCfRRsn, 1, -1);
  numBytes += cVar_init_f(&cVar_GZUqHJN5, 0.0f);
  numBytes += cSlice_init(&cSlice_pEv6yhdf, 1, -1);
  numBytes += cVar_init_f(&cVar_Om6pUeqF, 0.313f);
  numBytes += cBinop_init(&cBinop_sBSpjc08, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_XN2rmmUo, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_0w6hGGef, 0.0f);
  numBytes += cVar_init_f(&cVar_WtTLrH5T, 1337.0f);
  numBytes += cVar_init_f(&cVar_VUf5KScP, 0.3f);
  numBytes += cBinop_init(&cBinop_Qu8uTKyQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zeQIcUnl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9XGHrdRI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_l9ckmXFs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_2r8oIsQB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pPkEQf3r, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_f8jMHcOF, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_O9dHDrT3, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_iLNMx7Dx, 0.0f);
  numBytes += cVar_init_f(&cVar_Mho8f2UX, 1337.0f);
  numBytes += cVar_init_f(&cVar_xvcOlvrR, 0.313f);
  numBytes += cBinop_init(&cBinop_oZBzaPd9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_N7StKpq8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_btVAoJqr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hmWQMXN3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ng7KAZqT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NM0uYUTO, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_lS1zKVnh, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_idJ4f5fV, 0.0f);
  numBytes += cVar_init_f(&cVar_CpgAvpV8, 1037.0f);
  numBytes += cVar_init_f(&cVar_vmAlKlKg, 0.4f);
  numBytes += cBinop_init(&cBinop_bNsRH78T, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jWCW0czV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_JBYDr03m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3yKcyG9l, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_P9LjaGkb, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jv2uEc1N, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_TUVSE99b, 5705.6f);
  numBytes += cVar_init_f(&cVar_CdpVa0K8, 313.3f);
  numBytes += cBinop_init(&cBinop_GhqFYBtJ, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_6YAHVeIF, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_nYZm4cAL, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_gNDrEag9, 1, -1);
  numBytes += cVar_init_f(&cVar_BjRVFyB7, 0.5f);
  numBytes += cVar_init_f(&cVar_kLmapVVQ, 0.0f);
  numBytes += cVar_init_f(&cVar_wCTnGY5w, 0.0f);
  numBytes += cIf_init(&cIf_LXgIr118, false);
  numBytes += cIf_init(&cIf_XD8Pux4S, false);
  numBytes += cDelay_init(this, &cDelay_5xry2IVt, 10.0f);
  numBytes += cIf_init(&cIf_FYIK6d8J, false);
  numBytes += cIf_init(&cIf_vDgnMp2I, false);
  numBytes += cDelay_init(this, &cDelay_BGLvIW0v, 10.0f);
  numBytes += cIf_init(&cIf_pSesjkxK, false);
  numBytes += cIf_init(&cIf_JN7FuLkA, false);
  numBytes += cDelay_init(this, &cDelay_PcQteLG8, 10.0f);
  numBytes += cIf_init(&cIf_ylEcGGIf, false);
  numBytes += cIf_init(&cIf_aochpmOq, false);
  numBytes += cDelay_init(this, &cDelay_JXkOEiHL, 10.0f);
  numBytes += cIf_init(&cIf_Io36skL5, false);
  numBytes += cIf_init(&cIf_Aq1Roz4O, false);
  numBytes += cDelay_init(this, &cDelay_5vDSjL7U, 10.0f);
  numBytes += cIf_init(&cIf_GrUvTtgd, false);
  numBytes += cIf_init(&cIf_eo8pngWF, false);
  numBytes += cDelay_init(this, &cDelay_VwPj0rZs, 10.0f);
  numBytes += cIf_init(&cIf_RH6H0Tlh, false);
  numBytes += cIf_init(&cIf_bVrdHTNk, false);
  numBytes += cDelay_init(this, &cDelay_Uu9MoxRQ, 10.0f);
  numBytes += cIf_init(&cIf_4PEZSVja, false);
  numBytes += cIf_init(&cIf_WJAIQG8f, false);
  numBytes += cDelay_init(this, &cDelay_uCjV1YyZ, 10.0f);
  numBytes += cIf_init(&cIf_JVIE7IuY, false);
  numBytes += cIf_init(&cIf_I6hpGPSJ, false);
  numBytes += cDelay_init(this, &cDelay_UWj1zzfW, 10.0f);
  numBytes += cIf_init(&cIf_6X7y7xZa, false);
  numBytes += cIf_init(&cIf_3bdgz8FA, false);
  numBytes += cDelay_init(this, &cDelay_gkIg8k8c, 10.0f);
  numBytes += cIf_init(&cIf_5KC5ZTJN, false);
  numBytes += cIf_init(&cIf_XZKFupAz, false);
  numBytes += cDelay_init(this, &cDelay_n3xcXKHA, 10.0f);
  numBytes += cIf_init(&cIf_I0KuHJkj, false);
  numBytes += cIf_init(&cIf_s2yCBeKZ, false);
  numBytes += cDelay_init(this, &cDelay_cOZQPj4s, 10.0f);
  numBytes += sVarf_init(&sVarf_SYWXqxEb, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jMIgMWJj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rCfEko39, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7D8hlm6R, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aHGqMzcp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rVA2MQZE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cBp4Z6Yk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_H2ncCDNp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_IJNhhYMG, 0.0f);
  numBytes += cSlice_init(&cSlice_n1gbj6q6, 1, -1);
  numBytes += cVar_init_f(&cVar_W8YE5yJs, 1.0f);
  numBytes += cSlice_init(&cSlice_mldim5Gx, 1, -1);
  numBytes += cVar_init_f(&cVar_PnnM8CbE, 0.0f);
  numBytes += cSlice_init(&cSlice_rmPdGS04, 1, -1);
  numBytes += cVar_init_f(&cVar_TS6pQRih, 512.0f);
  numBytes += cSlice_init(&cSlice_VVml5aIs, 1, -1);
  numBytes += cVar_init_f(&cVar_ul0MPTVW, 1.0f);
  numBytes += cSlice_init(&cSlice_I33pyIzK, 1, -1);
  numBytes += cVar_init_f(&cVar_ovACBqFA, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Zn2MNaO3, 20.0f);
  numBytes += cVar_init_f(&cVar_4UQ6OPaA, 0.0f);
  numBytes += cIf_init(&cIf_PWuKZ2Uu, false);
  numBytes += cIf_init(&cIf_axopUEjQ, false);
  numBytes += cBinop_init(&cBinop_yC0mzxOY, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_qRV5TOqy, 1, -1);
  numBytes += cVar_init_f(&cVar_ji9ULSjz, 0.0f);
  numBytes += sVarf_init(&sVarf_8N3UFzjd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_s22xOvfK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OHNVvGam, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AVBVcGaW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_X3T2mwvT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MZyS91H1, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_6Qn9NPUQ, 0.0f);
  numBytes += cVar_init_f(&cVar_INwKtGV9, 0.0f);
  numBytes += cIf_init(&cIf_s503L93z, false);
  numBytes += cIf_init(&cIf_Nkq8ipRh, false);
  numBytes += cDelay_init(this, &cDelay_rYwA5Wn5, 10.0f);
  numBytes += cIf_init(&cIf_ebUBStIr, false);
  numBytes += cIf_init(&cIf_Rwi9ffCU, false);
  numBytes += cDelay_init(this, &cDelay_OYJyH31z, 10.0f);
  numBytes += cIf_init(&cIf_KscKAAYl, false);
  numBytes += cIf_init(&cIf_yY5LxH17, false);
  numBytes += cDelay_init(this, &cDelay_s5bTPOg6, 10.0f);
  numBytes += cIf_init(&cIf_9xRkGhBa, false);
  numBytes += cIf_init(&cIf_LkqnKe3z, false);
  numBytes += cDelay_init(this, &cDelay_X7odDqaO, 10.0f);
  numBytes += cIf_init(&cIf_0lKputYa, false);
  numBytes += cIf_init(&cIf_Ij77rBXw, false);
  numBytes += cDelay_init(this, &cDelay_vmQWWGwk, 10.0f);
  numBytes += cIf_init(&cIf_PHkgRQwE, false);
  numBytes += cIf_init(&cIf_KnEryivx, false);
  numBytes += cDelay_init(this, &cDelay_0DAikkpV, 10.0f);
  numBytes += cIf_init(&cIf_48LYflo7, false);
  numBytes += cIf_init(&cIf_MdOnbrAO, false);
  numBytes += cDelay_init(this, &cDelay_HRdHTaVY, 10.0f);
  numBytes += cIf_init(&cIf_OPahWzgp, false);
  numBytes += cIf_init(&cIf_RBRIcDkL, false);
  numBytes += cDelay_init(this, &cDelay_2ZfYabiM, 10.0f);
  numBytes += cIf_init(&cIf_VvrU071w, false);
  numBytes += cIf_init(&cIf_yNvwLR3t, false);
  numBytes += cDelay_init(this, &cDelay_RstYMjV5, 10.0f);
  numBytes += cIf_init(&cIf_CNR9X6In, false);
  numBytes += cIf_init(&cIf_ZjRNBeHa, false);
  numBytes += cDelay_init(this, &cDelay_YjlgwysW, 10.0f);
  numBytes += cIf_init(&cIf_PkQyXTvp, false);
  numBytes += cIf_init(&cIf_XqnnOlWP, false);
  numBytes += cDelay_init(this, &cDelay_irOK2fEz, 10.0f);
  numBytes += cIf_init(&cIf_3sxFNgh6, false);
  numBytes += cIf_init(&cIf_sQULVl1o, false);
  numBytes += cDelay_init(this, &cDelay_EM8cyfD8, 10.0f);
  numBytes += sVarf_init(&sVarf_6rgvdb1n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rpQr75WJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZH9cElfP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hTS9VHpS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EBeFvJfq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4GEaY3dq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3dByHp3s, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sPb1rCyx, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1NWRpcQi, 0.0f);
  numBytes += cSlice_init(&cSlice_kFW6LQLc, 1, -1);
  numBytes += cVar_init_f(&cVar_yzhsnxr9, 1.0f);
  numBytes += cSlice_init(&cSlice_L6p1ucos, 1, -1);
  numBytes += cVar_init_f(&cVar_I0wGVO4T, 0.0f);
  numBytes += cSlice_init(&cSlice_YiHGyg1Y, 1, -1);
  numBytes += cVar_init_f(&cVar_x4gtU1xv, 512.0f);
  numBytes += cSlice_init(&cSlice_Mh0thIAL, 1, -1);
  numBytes += cVar_init_f(&cVar_WZkWRE5C, 1.0f);
  numBytes += cSlice_init(&cSlice_IoBqvO5r, 1, -1);
  numBytes += cVar_init_f(&cVar_kBbkJEa1, 1.0f);
  numBytes += cDelay_init(this, &cDelay_fRmO0YoL, 20.0f);
  numBytes += cVar_init_f(&cVar_FG5RXmCw, 0.0f);
  numBytes += cIf_init(&cIf_V8nGcuTn, false);
  numBytes += cIf_init(&cIf_3kxrrLyN, false);
  numBytes += cBinop_init(&cBinop_cWhpUlpB, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_H7IjoDsz, 1, -1);
  numBytes += cVar_init_f(&cVar_PQV3UZge, 0.0f);
  numBytes += sVarf_init(&sVarf_VIC6Yeyw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PltCbYt5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5fSyx84T, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_znImre8P, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pZiFwR7Z, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NKQy5d4F, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yMXszRg7, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TP6IwKxB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1CP6RK4K, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Gi1tVZFZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_8trWV5Be, 0.0f);
  numBytes += cVar_init_f(&cVar_AKUGMb8s, 0.0f);
  numBytes += cVar_init_f(&cVar_8QjcTkCA, 0.0f);
  numBytes += cVar_init_f(&cVar_MLugZl8h, 0.0f);
  numBytes += cVar_init_f(&cVar_bHBLs69x, 0.0f);
  numBytes += cVar_init_f(&cVar_9geuDKnv, 1.0f);
  numBytes += cSlice_init(&cSlice_fEDoNUSj, 1, -1);
  numBytes += cVar_init_f(&cVar_Hoy6B2JM, 0.5f);
  numBytes += cVar_init_f(&cVar_LTh5dVCk, 0.0f);
  numBytes += cVar_init_f(&cVar_ueAyOBYN, 0.0f);
  numBytes += cIf_init(&cIf_FTt80AdF, false);
  numBytes += cIf_init(&cIf_wfoHo3hD, false);
  numBytes += cDelay_init(this, &cDelay_i2HmqcaH, 10.0f);
  numBytes += cIf_init(&cIf_aCDHeEQ4, false);
  numBytes += cIf_init(&cIf_RHU5zGfx, false);
  numBytes += cDelay_init(this, &cDelay_cBRFgD2Q, 10.0f);
  numBytes += cIf_init(&cIf_6UB0NIGL, false);
  numBytes += cIf_init(&cIf_QaoPNXuI, false);
  numBytes += cDelay_init(this, &cDelay_b95Gjwvi, 10.0f);
  numBytes += cIf_init(&cIf_dKUnFiSx, false);
  numBytes += cIf_init(&cIf_UPs1E6iz, false);
  numBytes += cDelay_init(this, &cDelay_jpbUKDa7, 10.0f);
  numBytes += cIf_init(&cIf_prvkHJBT, false);
  numBytes += cIf_init(&cIf_P41nkP8m, false);
  numBytes += cDelay_init(this, &cDelay_rope0W4d, 10.0f);
  numBytes += cIf_init(&cIf_Jk2z5xha, false);
  numBytes += cIf_init(&cIf_yHz6yS3T, false);
  numBytes += cDelay_init(this, &cDelay_Whr32zxF, 10.0f);
  numBytes += cIf_init(&cIf_okQUsXUD, false);
  numBytes += cIf_init(&cIf_b5WZ7bow, false);
  numBytes += cDelay_init(this, &cDelay_pTluTa7t, 10.0f);
  numBytes += cIf_init(&cIf_2uwd28ww, false);
  numBytes += cIf_init(&cIf_8Jtnoyaz, false);
  numBytes += cDelay_init(this, &cDelay_PR544wjn, 10.0f);
  numBytes += cIf_init(&cIf_R1GVz8Oj, false);
  numBytes += cIf_init(&cIf_pdHzwBkS, false);
  numBytes += cDelay_init(this, &cDelay_uo7ynn3L, 10.0f);
  numBytes += cIf_init(&cIf_Ed9RT6pX, false);
  numBytes += cIf_init(&cIf_hY3FnE4l, false);
  numBytes += cDelay_init(this, &cDelay_oTXKH104, 10.0f);
  numBytes += cIf_init(&cIf_EU2v8Q9N, false);
  numBytes += cIf_init(&cIf_ge5NXkKF, false);
  numBytes += cDelay_init(this, &cDelay_riZjIgRA, 10.0f);
  numBytes += cIf_init(&cIf_1WHHJINk, false);
  numBytes += cIf_init(&cIf_BLyDNZnY, false);
  numBytes += cDelay_init(this, &cDelay_IiUPsKKi, 10.0f);
  numBytes += sVarf_init(&sVarf_mI86uprW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2PkJkCUm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rlNO2e2l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eA1uXFGP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PENGz0ur, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uZH50O89, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NFDfXXbV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BTZ0gOrq, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1971RmlP, 0.0f);
  numBytes += cSlice_init(&cSlice_h6aFU9N6, 1, -1);
  numBytes += cVar_init_f(&cVar_hcm46hWq, 1.0f);
  numBytes += cSlice_init(&cSlice_fVwcyA2Z, 1, -1);
  numBytes += cVar_init_f(&cVar_jJ7jhHrn, 0.0f);
  numBytes += cSlice_init(&cSlice_icIl4YIa, 1, -1);
  numBytes += cVar_init_f(&cVar_tqZVNR8g, 512.0f);
  numBytes += cSlice_init(&cSlice_Vxbw8KLz, 1, -1);
  numBytes += cVar_init_f(&cVar_mpJkPYs5, 1.0f);
  numBytes += cSlice_init(&cSlice_tWBZtZgz, 1, -1);
  numBytes += cVar_init_f(&cVar_GTBB6NiB, 1.0f);
  numBytes += cDelay_init(this, &cDelay_jrSCE2ga, 20.0f);
  numBytes += cVar_init_f(&cVar_4cyjsivu, 0.0f);
  numBytes += cIf_init(&cIf_HodXXODV, false);
  numBytes += cIf_init(&cIf_rxdCsvpT, false);
  numBytes += cBinop_init(&cBinop_w8LOIpHV, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_5azkhrQl, 1, -1);
  numBytes += cVar_init_f(&cVar_IzOwrsre, 0.0f);
  numBytes += sVarf_init(&sVarf_daLK4A41, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p7640zv2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Hs9k5ie0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MfTxyNib, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_EfO3E0Nh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jqGKeCdG, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_GqqfnJHt, 0.0f);
  numBytes += cVar_init_f(&cVar_ODxMZeIh, 0.0f);
  numBytes += cIf_init(&cIf_vctzvvm2, false);
  numBytes += cIf_init(&cIf_HbpBtOuX, false);
  numBytes += cDelay_init(this, &cDelay_mfuksUY9, 10.0f);
  numBytes += cIf_init(&cIf_ZLtEqhWY, false);
  numBytes += cIf_init(&cIf_2cuMDk9h, false);
  numBytes += cDelay_init(this, &cDelay_z7QWSAwp, 10.0f);
  numBytes += cIf_init(&cIf_AqVTslyn, false);
  numBytes += cIf_init(&cIf_nLWqbYlj, false);
  numBytes += cDelay_init(this, &cDelay_040kHwGK, 10.0f);
  numBytes += cIf_init(&cIf_FMFVPc4Q, false);
  numBytes += cIf_init(&cIf_CuK4oRWV, false);
  numBytes += cDelay_init(this, &cDelay_C85TNyry, 10.0f);
  numBytes += cIf_init(&cIf_kmRHFZ8B, false);
  numBytes += cIf_init(&cIf_QTrNik2j, false);
  numBytes += cDelay_init(this, &cDelay_c66xZ3hv, 10.0f);
  numBytes += cIf_init(&cIf_ApZvOYn5, false);
  numBytes += cIf_init(&cIf_Na1r44Gs, false);
  numBytes += cDelay_init(this, &cDelay_jMBBAiiZ, 10.0f);
  numBytes += cIf_init(&cIf_gKXqp8up, false);
  numBytes += cIf_init(&cIf_g7STWyg7, false);
  numBytes += cDelay_init(this, &cDelay_6Kn0Q47B, 10.0f);
  numBytes += cIf_init(&cIf_sn7iPe2T, false);
  numBytes += cIf_init(&cIf_khtDOyGF, false);
  numBytes += cDelay_init(this, &cDelay_Z2yeIwo5, 10.0f);
  numBytes += cIf_init(&cIf_fKwHHaGV, false);
  numBytes += cIf_init(&cIf_HgEyxOvS, false);
  numBytes += cDelay_init(this, &cDelay_Kw4lcnYv, 10.0f);
  numBytes += cIf_init(&cIf_CHRgQhVC, false);
  numBytes += cIf_init(&cIf_A9DdOgSv, false);
  numBytes += cDelay_init(this, &cDelay_AhzPuMQs, 10.0f);
  numBytes += cIf_init(&cIf_rZtSS3Hk, false);
  numBytes += cIf_init(&cIf_LeQ1gvtW, false);
  numBytes += cDelay_init(this, &cDelay_l4wEVtPZ, 10.0f);
  numBytes += cIf_init(&cIf_szyqVBFT, false);
  numBytes += cIf_init(&cIf_mtRFv95U, false);
  numBytes += cDelay_init(this, &cDelay_uVYPSUQr, 10.0f);
  numBytes += sVarf_init(&sVarf_RGu9tjFE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T5zZOzoK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0jTre8CO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jk2yhC6U, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tfhlolxY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kLhIEV6E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_L5khhKiP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gbwEZ8Fz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_oGE9u2C5, 0.0f);
  numBytes += cSlice_init(&cSlice_V7gpMFGz, 1, -1);
  numBytes += cVar_init_f(&cVar_8n9384mf, 1.0f);
  numBytes += cSlice_init(&cSlice_UpogBaD3, 1, -1);
  numBytes += cVar_init_f(&cVar_WhETMERJ, 0.0f);
  numBytes += cSlice_init(&cSlice_Xjlq2LDi, 1, -1);
  numBytes += cVar_init_f(&cVar_Maw2L9fN, 512.0f);
  numBytes += cSlice_init(&cSlice_wgmbAToX, 1, -1);
  numBytes += cVar_init_f(&cVar_E2jOiNms, 1.0f);
  numBytes += cSlice_init(&cSlice_lqMWGPBV, 1, -1);
  numBytes += cVar_init_f(&cVar_SSYtOPBt, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Ro69sD4e, 20.0f);
  numBytes += cVar_init_f(&cVar_qRCvqwoE, 0.0f);
  numBytes += cIf_init(&cIf_MunECurI, false);
  numBytes += cIf_init(&cIf_2p5SdT3R, false);
  numBytes += cBinop_init(&cBinop_sX5ry2Ax, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_ejxfdgiZ, 1, -1);
  numBytes += cVar_init_f(&cVar_kmQvQPPU, 0.0f);
  numBytes += sVarf_init(&sVarf_brP5PssF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2WqyrQFu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7K3FzZh3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sOCEDgRB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ExPlOtyX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mOO2bNh0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_reSAgJTx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rMpquXcZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vZHwAdYk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IHRO1zR1, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_FVrlnGwY, 0.0f);
  numBytes += cVar_init_f(&cVar_diChbwFY, 0.0f);
  numBytes += cVar_init_f(&cVar_isXZ5kbl, 0.0f);
  numBytes += cVar_init_f(&cVar_EED9v9Tb, 0.0f);
  numBytes += cVar_init_f(&cVar_5zgOyVQm, 0.0f);
  numBytes += cVar_init_f(&cVar_sX8KNmK8, 1.0f);
  numBytes += cSlice_init(&cSlice_x9Q5DgWX, 1, -1);
  numBytes += cVar_init_f(&cVar_ckMqw03o, 0.5f);
  numBytes += cVar_init_f(&cVar_KQ6SCaMz, 0.0f);
  numBytes += cVar_init_f(&cVar_utdLUcWg, 0.0f);
  numBytes += cIf_init(&cIf_QvgzZUN5, false);
  numBytes += cIf_init(&cIf_G2sobD90, false);
  numBytes += cDelay_init(this, &cDelay_h91gsYxk, 10.0f);
  numBytes += cIf_init(&cIf_HD3ChczU, false);
  numBytes += cIf_init(&cIf_dBW6fSK1, false);
  numBytes += cDelay_init(this, &cDelay_59N0DHYb, 10.0f);
  numBytes += cIf_init(&cIf_Dqbw5iCX, false);
  numBytes += cIf_init(&cIf_DV50H71B, false);
  numBytes += cDelay_init(this, &cDelay_TchCPR6c, 10.0f);
  numBytes += cIf_init(&cIf_xqjlDy0u, false);
  numBytes += cIf_init(&cIf_RT5uIUkR, false);
  numBytes += cDelay_init(this, &cDelay_JuSIdCJc, 10.0f);
  numBytes += cIf_init(&cIf_7AtDllpC, false);
  numBytes += cIf_init(&cIf_eGhLOpft, false);
  numBytes += cDelay_init(this, &cDelay_CpPpBjZq, 10.0f);
  numBytes += cIf_init(&cIf_Qc1OHQuu, false);
  numBytes += cIf_init(&cIf_00r5pg9a, false);
  numBytes += cDelay_init(this, &cDelay_IZtVFmZE, 10.0f);
  numBytes += cIf_init(&cIf_iQcNMcqb, false);
  numBytes += cIf_init(&cIf_U0YaaeEV, false);
  numBytes += cDelay_init(this, &cDelay_FnBhPmlO, 10.0f);
  numBytes += cIf_init(&cIf_eYUBL4FT, false);
  numBytes += cIf_init(&cIf_3haB47a2, false);
  numBytes += cDelay_init(this, &cDelay_xym5tHfB, 10.0f);
  numBytes += cIf_init(&cIf_4vAVCxYl, false);
  numBytes += cIf_init(&cIf_2sspKRuL, false);
  numBytes += cDelay_init(this, &cDelay_8jrMcMl9, 10.0f);
  numBytes += cIf_init(&cIf_9NZjIHXO, false);
  numBytes += cIf_init(&cIf_a1QO8k5m, false);
  numBytes += cDelay_init(this, &cDelay_EEPAWvmw, 10.0f);
  numBytes += cIf_init(&cIf_29BF93v7, false);
  numBytes += cIf_init(&cIf_Fgn9Elxu, false);
  numBytes += cDelay_init(this, &cDelay_BFvtu0un, 10.0f);
  numBytes += cIf_init(&cIf_MVVeCGQJ, false);
  numBytes += cIf_init(&cIf_q7QqbBYG, false);
  numBytes += cDelay_init(this, &cDelay_1vOzGwVq, 10.0f);
  numBytes += sVarf_init(&sVarf_9QnPw7FR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LoI82Eq5, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_GGRofFvh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BcVv9mHr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aRpoOTJd, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_B8vSQbLW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mXohqjRm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_edH4RbO6, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ecqVXXSx, 0.0f);
  numBytes += cSlice_init(&cSlice_b7Gm3n5j, 1, -1);
  numBytes += cVar_init_f(&cVar_FyQTiD4e, 1.0f);
  numBytes += cSlice_init(&cSlice_nx8aqolL, 1, -1);
  numBytes += cVar_init_f(&cVar_pF2IPUHe, 0.0f);
  numBytes += cSlice_init(&cSlice_AZRDZAcN, 1, -1);
  numBytes += cVar_init_f(&cVar_qPWYcVBN, 512.0f);
  numBytes += cSlice_init(&cSlice_XnpqPA7b, 1, -1);
  numBytes += cVar_init_f(&cVar_nxxCnwoS, 1.0f);
  numBytes += cSlice_init(&cSlice_cAzlESYP, 1, -1);
  numBytes += cVar_init_f(&cVar_9TtqVedg, 1.0f);
  numBytes += cDelay_init(this, &cDelay_mCev2zxQ, 20.0f);
  numBytes += cVar_init_f(&cVar_AeIQCzxH, 0.0f);
  numBytes += cIf_init(&cIf_AbyXUaR5, false);
  numBytes += cIf_init(&cIf_1OqQCDxK, false);
  numBytes += cBinop_init(&cBinop_hhrFh2VJ, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_1A0Xwgyn, 1, -1);
  numBytes += cVar_init_f(&cVar_4AtlXus5, 0.0f);
  numBytes += sVarf_init(&sVarf_PdjVRSMo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sSZ00y7Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oAwFFC3n, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xKglvWYP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lvZzo5gV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NCT0qabi, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_3ce3BwXr, 0.0f);
  numBytes += cVar_init_f(&cVar_8KOaKqxu, 0.0f);
  numBytes += cIf_init(&cIf_R9hblzXm, false);
  numBytes += cIf_init(&cIf_dwzKfUmh, false);
  numBytes += cDelay_init(this, &cDelay_belbq5m9, 10.0f);
  numBytes += cIf_init(&cIf_daXC27vR, false);
  numBytes += cIf_init(&cIf_5dyovFen, false);
  numBytes += cDelay_init(this, &cDelay_pdu4UXqP, 10.0f);
  numBytes += cIf_init(&cIf_xMYU6TFB, false);
  numBytes += cIf_init(&cIf_Q4r45IkW, false);
  numBytes += cDelay_init(this, &cDelay_C1zEVmUS, 10.0f);
  numBytes += cIf_init(&cIf_AVSNamY4, false);
  numBytes += cIf_init(&cIf_DKV1xND5, false);
  numBytes += cDelay_init(this, &cDelay_oST4NIoh, 10.0f);
  numBytes += cIf_init(&cIf_NIXhJGWL, false);
  numBytes += cIf_init(&cIf_0hroPjhO, false);
  numBytes += cDelay_init(this, &cDelay_8qF3Bd4t, 10.0f);
  numBytes += cIf_init(&cIf_aPGjyKqM, false);
  numBytes += cIf_init(&cIf_5DTIzfoY, false);
  numBytes += cDelay_init(this, &cDelay_WRuqEYgk, 10.0f);
  numBytes += cIf_init(&cIf_F0Pr3G6M, false);
  numBytes += cIf_init(&cIf_pyBJCfJ6, false);
  numBytes += cDelay_init(this, &cDelay_4cJDDfvn, 10.0f);
  numBytes += cIf_init(&cIf_jQ6ZgSnm, false);
  numBytes += cIf_init(&cIf_oSM8srbh, false);
  numBytes += cDelay_init(this, &cDelay_6rZgGBfX, 10.0f);
  numBytes += cIf_init(&cIf_qAmOgJBF, false);
  numBytes += cIf_init(&cIf_q8Lbrrhw, false);
  numBytes += cDelay_init(this, &cDelay_Anm6lByl, 10.0f);
  numBytes += cIf_init(&cIf_tKe3ZR8S, false);
  numBytes += cIf_init(&cIf_Vp8UE44f, false);
  numBytes += cDelay_init(this, &cDelay_9iEZI6mE, 10.0f);
  numBytes += cIf_init(&cIf_mDS9s5kJ, false);
  numBytes += cIf_init(&cIf_MxJQpHzA, false);
  numBytes += cDelay_init(this, &cDelay_ZVglQOX6, 10.0f);
  numBytes += cIf_init(&cIf_bjvD5pzo, false);
  numBytes += cIf_init(&cIf_2MDvYOKJ, false);
  numBytes += cDelay_init(this, &cDelay_7qHktjYJ, 10.0f);
  numBytes += sVarf_init(&sVarf_B6Yg8hcx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cXXy78bn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PKP7lM0r, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4NNInWiE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hx0Miwa3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dAIPgKsV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lYKdZe1E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_p3gZauHs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_P1QL84Ba, 0.0f);
  numBytes += cSlice_init(&cSlice_szTAJL7Q, 1, -1);
  numBytes += cVar_init_f(&cVar_wHMFqTiz, 1.0f);
  numBytes += cSlice_init(&cSlice_68rd1tyf, 1, -1);
  numBytes += cVar_init_f(&cVar_x6bIDSh8, 0.0f);
  numBytes += cSlice_init(&cSlice_RtfqXZRh, 1, -1);
  numBytes += cVar_init_f(&cVar_TfZTuRjH, 512.0f);
  numBytes += cSlice_init(&cSlice_uP2nxlFY, 1, -1);
  numBytes += cVar_init_f(&cVar_pks8Tx2u, 1.0f);
  numBytes += cSlice_init(&cSlice_q0otuQlk, 1, -1);
  numBytes += cVar_init_f(&cVar_Lu7se2NK, 1.0f);
  numBytes += cDelay_init(this, &cDelay_09g6TlNs, 20.0f);
  numBytes += cVar_init_f(&cVar_ZDY7xU5a, 0.0f);
  numBytes += cIf_init(&cIf_2RJRKEI0, false);
  numBytes += cIf_init(&cIf_QUHuOKPq, false);
  numBytes += cBinop_init(&cBinop_ilX497I3, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_HmXhKBuT, 1, -1);
  numBytes += cVar_init_f(&cVar_3Ib33IVH, 0.0f);
  numBytes += sVarf_init(&sVarf_PoxVzO9R, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_9CTwNomO, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3ESRZ7r6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_rYqjhZJq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_43uMA4fo, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J8vmWd6b, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3Tzt07Xq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_34sa5y57, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hPWkA7IK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_oHc3q8G0, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_UEkV0KYU, 0.0f);
  numBytes += cVar_init_f(&cVar_6dnXM9ij, 0.0f);
  numBytes += cVar_init_f(&cVar_AgfrkVZs, 0.0f);
  numBytes += sVarf_init(&sVarf_v3j5zxfP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_t2gtX5Et, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jCs1f6uB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7TjGDr1I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cZQ8Z0JD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dMko461o, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_U3bnt8u9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Kvtdbswp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_7Uoz1Hxn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fBp5DmdP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CQNAGpX3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kpdvl9H7, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_GgxBQ18X);
  sEnv_free(&sEnv_rrgeOUly);
  sEnv_free(&sEnv_erGK5Qki);
  sEnv_free(&sEnv_7ILklKDO);
  sEnv_free(&sEnv_jHkLDs2A);
  sEnv_free(&sEnv_M1ztaHkP);
  sEnv_free(&sEnv_Aw4s6Ktc);
  sEnv_free(&sEnv_6nZ2nBEy);
  sEnv_free(&sEnv_aLJxoS6L);
  sEnv_free(&sEnv_qKAlHCz7);
  sEnv_free(&sEnv_rdO8K1Wn);
  sEnv_free(&sEnv_pARMQSOW);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_weYc8keV_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qUl8jZPl_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oR3v4xWB_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eJxoqp0n_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_d743fjkq_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pjSnzgBc_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ezFVH3Px_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6r4FsIOc_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_abnKStkO_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wcFf1X32_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dAC1LKHw_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nWQgjPbL_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kCLi75KY_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DN74hq6m_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7md1AKdi_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KpGiKDKA_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_6DArWdMX_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YwZ4klC2_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2wiBU3Pe_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0x73W7fX_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mn84inKY_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zvu5s0go_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KUvXBV7f_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uQz4jh2s_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9DSiBSsz_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ihGn3IwI_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bZnrJ2aS_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vZcqokvd_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D3LWVS22_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_obAjhLyx_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l9J3n0mO_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PAOSmNSW_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_L1L7pcgE_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_S3qyPif5_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9MPY4t7t_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hTuANUHs_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FFIwsnzk_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NrFmEcZR_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EsRNtRUP_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vlkKGr3V_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hzxOqVe2_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RIydixWc_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_URmIZkZc_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Pxdrq2Ev_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BS6BACjK_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AvEzp8rn_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GqD03T1z_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z2yMyDJj_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_a8EUIwAb_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IqXDorA9_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bWNWbxuY_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_koDzYlI6_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n4MlYepK_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SYVexDWb_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gJMmQPOv_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aci8luP9_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_D0WYEijN_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cXIVHbqt_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jEgHlgTf_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KCpHR8bu_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BEZZKpmg_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VSJBwof0_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UpoWkETq_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9Gnu0cJ6_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_GoQSXUaH_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AAejjQgr_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eH6F7lT7_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uy5RmBRx_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KZgk1hX0_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kiR8H1iF_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aCJAnbdz_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yNRczHMr_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_suRHW43E_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gpfBI8BS_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_duR5cfRu_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_l9JGzCyB_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QveBqcDq_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iI2XUKFE_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A2FK1ODP_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NMQgjnvi_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oYOf0XBm_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R0v8YieQ_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LunKUzOm_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_AIypy3CX_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HEv3ahud_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PfjCDOXA_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LlhZ5U3D_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wEYLFMR3_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Wld2ApVS_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_p6wgRulk_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zGJBmRbb_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3je2GmWY_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9wiP7ccS_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_0LoEddKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GHugsdU8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hnlavMnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xXRPZnpW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5wID3qSA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bCMBxmdZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dq9SGiVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8uJ8JjAs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_T20VTnHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YGwYQj0c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WUyZb1WY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jT8S34Xh_sendMessage);
  cMsg_MTy3uzGT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jT8S34Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WUyZb1WY, 1, m, &cVar_WUyZb1WY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5xesWBUg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jGGqHBwt_sendMessage(_c, 0, m);
  cMsg_sIGJ5JNk_sendMessage(_c, 0, m);
  cMsg_W2mimA4Q_sendMessage(_c, 0, m);
  cMsg_obWoEtcP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_mRKCC2EJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rXf2F1mG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_KhcheFgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nEKweOm9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_r0UQmc3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XqGncrDJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pgsemKKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HNvaJQYo_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VUKEqqP1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2dkcGHO6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wKfezIAv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_27vKdEOR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0byqd8cN, 0, m, &cSlice_0byqd8cN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_bYQATkOJ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0byqd8cN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KK5qdRHm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KK5qdRHm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SKMhT36u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KK5qdRHm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KK5qdRHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vZcqokvd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_iiOc5bOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_w63CagU8_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_6j5x3SkX, 0, m, &cIf_6j5x3SkX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_6j5x3SkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_6xSXHA9i_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZUdzliUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_K3P3lok8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_VjVCbulI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_SEuTbD2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_M1nmh6Rf, HV_BINOP_POW, 0, m, &cBinop_M1nmh6Rf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M1nmh6Rf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aLZX0GXp, 0, m, &cIf_aLZX0GXp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d7gtvHl1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8Y7fNe1H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_axauzJu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_InLFUFmR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gs96PXCo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZUdzliUj, 0, m, &cIf_ZUdzliUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_InLFUFmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZUdzliUj, 1, m, &cIf_ZUdzliUj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VjVCbulI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_d7gtvHl1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K3P3lok8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aLZX0GXp, 0, m, &cIf_aLZX0GXp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8Y7fNe1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M1nmh6Rf, HV_BINOP_POW, 1, m, &cBinop_M1nmh6Rf_sendMessage);
  cMsg_SEuTbD2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_aLZX0GXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cNBRyykB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_w63CagU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6j5x3SkX, 1, m, &cIf_6j5x3SkX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6xSXHA9i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YHAvPPIj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TT3VGapL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zWvHwISq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_axauzJu8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gs96PXCo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dlSyf8BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aLZX0GXp, 1, m, &cIf_aLZX0GXp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i5BerGCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SAVefEfj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SAVefEfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_cNBRyykB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_vfTstb2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_zWvHwISq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TT3VGapL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlSyf8BG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dlSyf8BG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YHAvPPIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i5BerGCm, HV_BINOP_EQ, 1, m, &cBinop_i5BerGCm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1yqR9uir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vfTstb2G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WqLRUok5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i5BerGCm, HV_BINOP_EQ, 0, m, &cBinop_i5BerGCm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S5w5Nx7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlSyf8BG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dlSyf8BG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6ygDaFDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iiOc5bOy, 0, m, &cVar_iiOc5bOy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_kBYw6i5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Dpd7yWUR_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ph9M45sI, 0, m, &cIf_ph9M45sI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ph9M45sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3z6EpK8b_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9xWCRUdL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_adStvSpW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_XVpFbL5C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_nTf7ivp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yVdvWLHR, HV_BINOP_POW, 0, m, &cBinop_yVdvWLHR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yVdvWLHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nZPq9Eh, 0, m, &cIf_2nZPq9Eh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_94g3Zj5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vKQsTu93_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zQAMiy1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_I9alumyu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5hJ3wRso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9xWCRUdL, 0, m, &cIf_9xWCRUdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I9alumyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9xWCRUdL, 1, m, &cIf_9xWCRUdL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XVpFbL5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_94g3Zj5O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_adStvSpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_2nZPq9Eh, 0, m, &cIf_2nZPq9Eh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vKQsTu93_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yVdvWLHR, HV_BINOP_POW, 1, m, &cBinop_yVdvWLHR_sendMessage);
  cMsg_nTf7ivp5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_2nZPq9Eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1X47XbbO_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qrTfoEzp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_Dpd7yWUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ph9M45sI, 1, m, &cIf_ph9M45sI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3z6EpK8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lAqrtK55_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KBK90Ot7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uF9NGcC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQAMiy1U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5hJ3wRso_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ONk6uOoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2nZPq9Eh, 1, m, &cIf_2nZPq9Eh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GwpvfvAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FJsDXLuy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FJsDXLuy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1X47XbbO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qrTfoEzp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3sTiaDS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_uF9NGcC7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KBK90Ot7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ONk6uOoY, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ONk6uOoY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lAqrtK55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GwpvfvAx, HV_BINOP_EQ, 1, m, &cBinop_GwpvfvAx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n5oH3P52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ONk6uOoY, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ONk6uOoY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8NuEoO7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3sTiaDS6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BDVQCuU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GwpvfvAx, HV_BINOP_EQ, 0, m, &cBinop_GwpvfvAx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yU93IP2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kBYw6i5F, 0, m, &cVar_kBYw6i5F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_jHrluBJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yLibPyuY_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Za0UaXwW, 0, m, &cIf_Za0UaXwW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Za0UaXwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UBBceAUZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FZ2S4i7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ASKKcFtu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mWeBKVgm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_RUaeUbIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jnt6KkMn, HV_BINOP_POW, 0, m, &cBinop_jnt6KkMn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jnt6KkMn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LiqU0Ic0, 0, m, &cIf_LiqU0Ic0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yUaQRpd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_uXFWSbb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lGVDrspa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FZ2S4i7c, 0, m, &cIf_FZ2S4i7c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pvEwNUJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_RleJRnNY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RleJRnNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FZ2S4i7c, 1, m, &cIf_FZ2S4i7c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mWeBKVgm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_yUaQRpd2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ASKKcFtu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_LiqU0Ic0, 0, m, &cIf_LiqU0Ic0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uXFWSbb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jnt6KkMn, HV_BINOP_POW, 1, m, &cBinop_jnt6KkMn_sendMessage);
  cMsg_RUaeUbIG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_LiqU0Ic0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BhSfpMik_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_yLibPyuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Za0UaXwW, 1, m, &cIf_Za0UaXwW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UBBceAUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rPAdMqHh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ikONYmTB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4Nb43VIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pvEwNUJL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lGVDrspa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_X3vr1UQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LiqU0Ic0, 1, m, &cIf_LiqU0Ic0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OVCdyUHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lI4lI5CC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lI4lI5CC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_BhSfpMik_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pZ8i6mfL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_4Nb43VIR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ikONYmTB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X3vr1UQg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_X3vr1UQg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rPAdMqHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OVCdyUHz, HV_BINOP_EQ, 1, m, &cBinop_OVCdyUHz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pKuVHWdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_X3vr1UQg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_X3vr1UQg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QNR2zsAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OVCdyUHz, HV_BINOP_EQ, 0, m, &cBinop_OVCdyUHz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YR678Vjf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pZ8i6mfL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_W7G4p1uR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jHrluBJ9, 0, m, &cVar_jHrluBJ9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Bd5O14oZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MMUKlojs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oY0HoT85_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YCYpqduB, 0, m, &cSlice_YCYpqduB_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eldOHlNl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YCYpqduB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0EShHDHQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0EShHDHQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pQOymYDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0EShHDHQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0EShHDHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ihGn3IwI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eldOHlNl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HrS1K8ZN, 0, m, &cSlice_HrS1K8ZN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_27vKdEOR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HrS1K8ZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dEkJ4G9n_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dEkJ4G9n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EPMAoYsw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dEkJ4G9n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dEkJ4G9n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_obAjhLyx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bYQATkOJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tSzmYo9c, 0, m, &cSlice_tSzmYo9c_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lEGNUBiX_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tSzmYo9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sJ0Ak3lK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sJ0Ak3lK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_UZIZ2knu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sJ0Ak3lK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sJ0Ak3lK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bZnrJ2aS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lEGNUBiX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0AMGbXHZ, 0, m, &cSlice_0AMGbXHZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0AMGbXHZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4udtZfrU_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4udtZfrU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qSnwDKV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4udtZfrU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4udtZfrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D3LWVS22_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AuW8wyrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0HucXN3z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LsRJ4ee0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nDMOLc3m, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hP6kZnF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BYH4uA5Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Rw853ylZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PXg2JSPZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RxuohAQa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_s6oSb9gt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4fL4ffWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jfM6XUXb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_jfM6XUXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dHwnzbc, HV_BINOP_DIVIDE, 1, m, &cBinop_7dHwnzbc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9APmTFK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_n2w9owjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_EnCRqumi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PZZdQC8L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_n2w9owjo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EnCRqumi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7dHwnzbc, HV_BINOP_DIVIDE, 0, m, &cBinop_7dHwnzbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s9APmTFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PZZdQC8L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_7dHwnzbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nbExkXkW, HV_BINOP_MULTIPLY, 1, m, &cBinop_nbExkXkW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nbExkXkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HxQeQIY5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LIabpwjL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_s7qO1K4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6SYnLKqb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_cbjwTY7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kDpFUa3Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vRPzhWbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_TpUhyStR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TpUhyStR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nbExkXkW, HV_BINOP_MULTIPLY, 0, m, &cBinop_nbExkXkW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_svu79HIM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_QTcbHBu2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QTcbHBu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TXOwE4vi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_syK4Al9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GghSnqyP, 1, m, &cVar_GghSnqyP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_GghSnqyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IpTEVIFS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_35XTLl8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UCKaJxIz, HV_BINOP_MULTIPLY, 1, m, &cBinop_UCKaJxIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OsMxfPnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_35XTLl8b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pyTpbA1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9QFdpt5f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9QFdpt5f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GIPikKfk, HV_BINOP_MULTIPLY, 1, m, &cBinop_GIPikKfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1xisG6j8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_izS7bBxF, HV_BINOP_MULTIPLY, 1, m, &cBinop_izS7bBxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B6S9kgbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1xisG6j8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ny8RykrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mh5UzhTI, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mh5UzhTI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ApMt1m8M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_7wYHjsu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7wYHjsu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ECso3Gj, HV_BINOP_MULTIPLY, 1, m, &cBinop_6ECso3Gj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_00XZKX25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UvrmoKxt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_vRPzhWbH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kBbuCDH4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_BkQ1HJXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_svu79HIM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HxQeQIY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_s7qO1K4K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LIabpwjL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_cbjwTY7C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_6SYnLKqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_L1L7pcgE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_kDpFUa3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PAOSmNSW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ykivAuUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l9J3n0mO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TXOwE4vi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_V9hPGC7H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V9hPGC7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmOB5Cu4, HV_BINOP_MULTIPLY, 1, m, &cBinop_HmOB5Cu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HmOB5Cu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8cgoyoQh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8cgoyoQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ykivAuUj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IpTEVIFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XIjMJuzc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XIjMJuzc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_53tjBJ0G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X3mCSgWt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5FXyntTU_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bGSaR4kW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7hQ1aVFN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xVif4YRi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UCKaJxIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AuW8wyrP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GIPikKfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LsRJ4ee0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_izS7bBxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hP6kZnF3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Mh5UzhTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Rw853ylZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_6ECso3Gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RxuohAQa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_x7gAJ67U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_00XZKX25, 0, m, &cVar_00XZKX25_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YROlABJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BkQ1HJXX, 1, m, &cVar_BkQ1HJXX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7hQ1aVFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GIPikKfk, HV_BINOP_MULTIPLY, 0, m, &cBinop_GIPikKfk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bGSaR4kW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_izS7bBxF, HV_BINOP_MULTIPLY, 0, m, &cBinop_izS7bBxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_53tjBJ0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_5FXyntTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mh5UzhTI, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mh5UzhTI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xVif4YRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UCKaJxIz, HV_BINOP_MULTIPLY, 0, m, &cBinop_UCKaJxIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X3mCSgWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6ECso3Gj, HV_BINOP_MULTIPLY, 0, m, &cBinop_6ECso3Gj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UvrmoKxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BkQ1HJXX, 0, m, &cVar_BkQ1HJXX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kBbuCDH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GghSnqyP, 0, m, &cVar_GghSnqyP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ayAkxyJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PbDBYzb8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EpnCnJ4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5I6MSQ4v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uhIjjHAm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H7sQ16gl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_a6SWdFHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xX4wplt8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2y7EIOfq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fyMgOpX3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_fyMgOpX3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U6sG0urL, HV_BINOP_DIVIDE, 1, m, &cBinop_U6sG0urL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TMmdKeB2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_c7D4PhFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fsBZjAUN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NMMIdr14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_c7D4PhFC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fsBZjAUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_U6sG0urL, HV_BINOP_DIVIDE, 0, m, &cBinop_U6sG0urL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TMmdKeB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NMMIdr14_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_U6sG0urL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bRo5QMzQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_bRo5QMzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bRo5QMzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aD3UT8VG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rsHYlOVm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_hxwJP4uU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_p8n2P3E8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_2iV0nTVD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mDtylxk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sEaUnchS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_EVhKoccb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EVhKoccb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bRo5QMzQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_bRo5QMzQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2oaKgWu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_sWeIdf2E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sWeIdf2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SdtrL42L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4yuGsYiu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dN996kdU, HV_BINOP_MULTIPLY, 1, m, &cBinop_dN996kdU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pIlXa0F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c74WeSCg, 1, m, &cVar_c74WeSCg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3ewJvZom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3mr4azHK, HV_BINOP_MULTIPLY, 1, m, &cBinop_3mr4azHK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_I59MLcUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_6mdBngmp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6mdBngmp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_InGC8K7i, HV_BINOP_MULTIPLY, 1, m, &cBinop_InGC8K7i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_c74WeSCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lGi4orcU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_waDHxliF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JLZhqtZl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_sEaUnchS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gAS1qQ2Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_rZrJK02e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_2oaKgWu7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aD3UT8VG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_hxwJP4uU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rsHYlOVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_2iV0nTVD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_p8n2P3E8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hTuANUHs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mDtylxk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9MPY4t7t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_L9QBHCxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_S3qyPif5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SdtrL42L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_Gf4LU5WO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gf4LU5WO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4OcvHgw, HV_BINOP_MULTIPLY, 1, m, &cBinop_g4OcvHgw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g4OcvHgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MNDLTJSl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MNDLTJSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L9QBHCxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lGi4orcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_jCiDhib2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jCiDhib2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LGabkWad_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GwyPp6LI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gqqUs0gj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OCqeb0Og_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3KGSQBxa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ayAkxyJ0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_dN996kdU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EpnCnJ4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3mr4azHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uhIjjHAm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_InGC8K7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_a6SWdFHy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VQFC7TzR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_waDHxliF, 0, m, &cVar_waDHxliF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n9mMcYOT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rZrJK02e, 1, m, &cVar_rZrJK02e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JLZhqtZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rZrJK02e, 0, m, &cVar_rZrJK02e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gAS1qQ2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c74WeSCg, 0, m, &cVar_c74WeSCg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gqqUs0gj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dN996kdU, HV_BINOP_MULTIPLY, 0, m, &cBinop_dN996kdU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GwyPp6LI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3mr4azHK, HV_BINOP_MULTIPLY, 0, m, &cBinop_3mr4azHK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LGabkWad_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_InGC8K7i, HV_BINOP_MULTIPLY, 0, m, &cBinop_InGC8K7i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OCqeb0Og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KGSQBxa, HV_BINOP_MULTIPLY, 0, m, &cBinop_3KGSQBxa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SDoXZm67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m0KcAdht, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3co70Qhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_S0f2ihLX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RrFXDDFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0PbuoEW9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_N823Wrja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_P71gEBTC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1BbNe4TH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DBFz2biW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VUVwKAGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_MmDneS04_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_MmDneS04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NOj85KN3, HV_BINOP_DIVIDE, 1, m, &cBinop_NOj85KN3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_txgG0TDS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Pe0kzFvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Mx1H9fNo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H00rFF23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_Pe0kzFvw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Mx1H9fNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NOj85KN3, HV_BINOP_DIVIDE, 0, m, &cBinop_NOj85KN3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_txgG0TDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H00rFF23_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NOj85KN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e56gldAL, HV_BINOP_MULTIPLY, 1, m, &cBinop_e56gldAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e56gldAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_meI6YxM2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m3ktx6Er_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_NBXtwdjm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nUAId9ql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_oOxZ7IEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LuXanJUp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_IjEinVhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ruTo9iX1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ruTo9iX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_e56gldAL, HV_BINOP_MULTIPLY, 0, m, &cBinop_e56gldAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d8BiKC2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_GNEZthKM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GNEZthKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zu2vbEf4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_IHtygpR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uWQXErGz, HV_BINOP_MULTIPLY, 1, m, &cBinop_uWQXErGz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_74BlYElW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_b6gCvFu1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_b6gCvFu1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IHtygpR2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L9nXdhYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_t5rjDS6i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t5rjDS6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CgftqWZB, HV_BINOP_MULTIPLY, 1, m, &cBinop_CgftqWZB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y7OYCSt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J4BtovUv, HV_BINOP_MULTIPLY, 1, m, &cBinop_J4BtovUv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bHt3OXcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1JisKKni_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1JisKKni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y7OYCSt4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qCRvYiDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1qxzVYLx, 1, m, &cVar_1qxzVYLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I0UReeWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RO0FzrQV, HV_BINOP_MULTIPLY, 1, m, &cBinop_RO0FzrQV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YwkZ3nAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9Gl96WtX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9Gl96WtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLOMCqsd, HV_BINOP_MULTIPLY, 1, m, &cBinop_JLOMCqsd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1qxzVYLx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vzrb8CUJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1kQ4UZ5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Aq6riIbG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_IjEinVhw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ijL5HRxA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZW8M5yM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_d8BiKC2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_meI6YxM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_NBXtwdjm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_m3ktx6Er_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_oOxZ7IEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_nUAId9ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EsRNtRUP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_LuXanJUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NrFmEcZR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HQoJbFyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FFIwsnzk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zu2vbEf4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2TjEymhd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2TjEymhd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLpTnhGW, HV_BINOP_MULTIPLY, 1, m, &cBinop_XLpTnhGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XLpTnhGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dEggsMGx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dEggsMGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HQoJbFyM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Vzrb8CUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3QaqzMuI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3QaqzMuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NUDGBxuF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_orGt4P6a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1IGEdbZj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qjU5THEW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YVQKYmFY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0L0jb541_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uWQXErGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SDoXZm67_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CgftqWZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3co70Qhy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_J4BtovUv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RrFXDDFh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_RO0FzrQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N823Wrja_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JLOMCqsd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1BbNe4TH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rI6WoqsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZW8M5yM9, 1, m, &cVar_ZW8M5yM9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cL8e4ltF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1kQ4UZ5P, 0, m, &cVar_1kQ4UZ5P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1IGEdbZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RO0FzrQV, HV_BINOP_MULTIPLY, 0, m, &cBinop_RO0FzrQV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NUDGBxuF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_YVQKYmFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CgftqWZB, HV_BINOP_MULTIPLY, 0, m, &cBinop_CgftqWZB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0L0jb541_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uWQXErGz, HV_BINOP_MULTIPLY, 0, m, &cBinop_uWQXErGz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_orGt4P6a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JLOMCqsd, HV_BINOP_MULTIPLY, 0, m, &cBinop_JLOMCqsd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qjU5THEW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J4BtovUv, HV_BINOP_MULTIPLY, 0, m, &cBinop_J4BtovUv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ijL5HRxA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1qxzVYLx, 0, m, &cVar_1qxzVYLx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Aq6riIbG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZW8M5yM9, 0, m, &cVar_ZW8M5yM9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qVmMeUS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bd5O14oZ, 1, m, &cIf_Bd5O14oZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7AsuDpch_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_MMUKlojs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_gH4FFelH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7AsuDpch_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CPDAPgFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Bd5O14oZ, 0, m, &cIf_Bd5O14oZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cNBRyykB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e8xxJOS0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MMUKlojs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tL7mhmue, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BhSfpMik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2TA6eTbV, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1X47XbbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qVmMeUS9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gH4FFelH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qrTfoEzp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_CPDAPgFN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q4e1tXw3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_093ba2nK, 0, m, &cSlice_093ba2nK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4UOYSmov_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_093ba2nK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_PPdpUWp1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_PPdpUWp1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ppFs5YQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_PPdpUWp1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_PPdpUWp1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RIydixWc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_fOccWZGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pR0USRmW_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_I6c6foyZ, 0, m, &cIf_I6c6foyZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_I6c6foyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HBpw7amo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mkxv8Htq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5n13PJ3X_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UQQpHpmA_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_AKiIYHWM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mhgePlBC, HV_BINOP_POW, 0, m, &cBinop_mhgePlBC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mhgePlBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qcJvmQgC, 0, m, &cIf_qcJvmQgC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eP7kHHS6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_heQllQYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p7pTenFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mkxv8Htq, 0, m, &cIf_mkxv8Htq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o5ZY4G7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GGBZJdmj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GGBZJdmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mkxv8Htq, 1, m, &cIf_mkxv8Htq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UQQpHpmA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_eP7kHHS6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5n13PJ3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qcJvmQgC, 0, m, &cIf_qcJvmQgC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_heQllQYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mhgePlBC, HV_BINOP_POW, 1, m, &cBinop_mhgePlBC_sendMessage);
  cMsg_AKiIYHWM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_qcJvmQgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0asyETrU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_pR0USRmW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I6c6foyZ, 1, m, &cIf_I6c6foyZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HBpw7amo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6xpjbawY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S1JoYmAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m4pJnKhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_o5ZY4G7E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p7pTenFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4G5p1H6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qcJvmQgC, 1, m, &cIf_qcJvmQgC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_figVwyLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PAfNrlu4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PAfNrlu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_0asyETrU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NmIezXul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_m4pJnKhz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S1JoYmAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4G5p1H6Q, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4G5p1H6Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6xpjbawY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_figVwyLw, HV_BINOP_EQ, 1, m, &cBinop_figVwyLw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rJVrBc0K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NmIezXul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_chaSnXVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fOccWZGA, 0, m, &cVar_fOccWZGA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LrylYC9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4G5p1H6Q, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4G5p1H6Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YyxY6KUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_figVwyLw, HV_BINOP_EQ, 0, m, &cBinop_figVwyLw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_c8b1YwNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Mym2P4oU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_7VMa0C9b, 0, m, &cIf_7VMa0C9b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_7VMa0C9b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mZc7ji1h_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JVcS4pnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_krcaXPb4_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WGOrVl3A_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_I5SqEPTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_avSDbuwu, HV_BINOP_POW, 0, m, &cBinop_avSDbuwu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_avSDbuwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fLtymR23, 0, m, &cIf_fLtymR23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FgS6Pt0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_meOVH3dl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ue8UkQ1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JVcS4pnR, 0, m, &cIf_JVcS4pnR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RkOEKZez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_fgPO8PAs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fgPO8PAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JVcS4pnR, 1, m, &cIf_JVcS4pnR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WGOrVl3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_FgS6Pt0y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_krcaXPb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_fLtymR23, 0, m, &cIf_fLtymR23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_meOVH3dl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_avSDbuwu, HV_BINOP_POW, 1, m, &cBinop_avSDbuwu_sendMessage);
  cMsg_I5SqEPTL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_fLtymR23_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJBvy2uo_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaYtOrA8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_Mym2P4oU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7VMa0C9b, 1, m, &cIf_7VMa0C9b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mZc7ji1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SEYmFm3Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eaqcYYUq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8g2aLN09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RkOEKZez_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ue8UkQ1b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QNFpuVxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fLtymR23, 1, m, &cIf_fLtymR23_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R3XBIe0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sGto48o5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sGto48o5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VJBvy2uo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SaYtOrA8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bQlkgRcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_8g2aLN09_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eaqcYYUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QNFpuVxf, HV_BINOP_GREATER_THAN, 1, m, &cBinop_QNFpuVxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SEYmFm3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R3XBIe0T, HV_BINOP_EQ, 1, m, &cBinop_R3XBIe0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BqjuxxD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R3XBIe0T, HV_BINOP_EQ, 0, m, &cBinop_R3XBIe0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mojRlTD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QNFpuVxf, HV_BINOP_GREATER_THAN, 0, m, &cBinop_QNFpuVxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iZV1KHLs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bQlkgRcm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_thBmz0Zj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_c8b1YwNa, 0, m, &cVar_c8b1YwNa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Fu2LmynN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_co7BmypX_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_Rtx7921h, 0, m, &cIf_Rtx7921h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_Rtx7921h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jK2MiDux_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_khbZ674p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_wR1H3YHw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7DfV1pTi_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_apzh0ABR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZOAwYyUt, HV_BINOP_POW, 0, m, &cBinop_ZOAwYyUt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZOAwYyUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zaf1eyW0, 0, m, &cIf_Zaf1eyW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8cYYgz8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_1oSv3f4Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UXYxOiNj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_khbZ674p, 0, m, &cIf_khbZ674p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lHJsMjTY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zhwF3tgK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zhwF3tgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_khbZ674p, 1, m, &cIf_khbZ674p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7DfV1pTi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_8cYYgz8N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wR1H3YHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Zaf1eyW0, 0, m, &cIf_Zaf1eyW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1oSv3f4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZOAwYyUt, HV_BINOP_POW, 1, m, &cBinop_ZOAwYyUt_sendMessage);
  cMsg_apzh0ABR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Zaf1eyW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LIQFwB92_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_co7BmypX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rtx7921h, 1, m, &cIf_Rtx7921h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jK2MiDux_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GKE6SOhg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_52X6je8O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d4n3aa3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lHJsMjTY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UXYxOiNj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I6rGkXMp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Zaf1eyW0, 1, m, &cIf_Zaf1eyW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nkNG3usH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2wKZteMB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2wKZteMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_LIQFwB92_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_K0C6yxuQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_d4n3aa3d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GKE6SOhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkNG3usH, HV_BINOP_EQ, 1, m, &cBinop_nkNG3usH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_52X6je8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I6rGkXMp, HV_BINOP_GREATER_THAN, 1, m, &cBinop_I6rGkXMp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dWmPQleE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Fu2LmynN, 0, m, &cVar_Fu2LmynN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4c5GOKGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_I6rGkXMp, HV_BINOP_GREATER_THAN, 0, m, &cBinop_I6rGkXMp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dngVU6yH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nkNG3usH, HV_BINOP_EQ, 0, m, &cBinop_nkNG3usH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TOuYYeVM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K0C6yxuQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_dNWvkJdP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LhCcDCpr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PjFc48IY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yTm5Hjne, 0, m, &cSlice_yTm5Hjne_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BQQiLu40_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_yTm5Hjne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GxktwAW5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GxktwAW5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nM24sZTx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GxktwAW5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_GxktwAW5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vlkKGr3V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BQQiLu40_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_MWKlmICT, 0, m, &cSlice_MWKlmICT_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q4e1tXw3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_MWKlmICT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_CfPA1JqT_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_CfPA1JqT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_KmJueRo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CfPA1JqT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_CfPA1JqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Pxdrq2Ev_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4UOYSmov_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4fCfRRsn, 0, m, &cSlice_4fCfRRsn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wyoyPSqK_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4fCfRRsn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NQRzaTVc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NQRzaTVc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GZUqHJN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NQRzaTVc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NQRzaTVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hzxOqVe2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wyoyPSqK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pEv6yhdf, 0, m, &cSlice_pEv6yhdf_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pEv6yhdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8P0oxWxl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8P0oxWxl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Om6pUeqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8P0oxWxl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8P0oxWxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_URmIZkZc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HBE4DfjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YtZgQT4O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9X8XYakj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DDscuPlK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wNCqiiLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Qq0cSRym, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7FU1zahI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iORoK5K4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Cvpicw7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UUagzppM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_RFlsZfWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7gtCLx5B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_7gtCLx5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sBSpjc08, HV_BINOP_DIVIDE, 1, m, &cBinop_sBSpjc08_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A682jNUP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_hr01p3u4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lo9hlVLk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DfPT2WuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hr01p3u4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lo9hlVLk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sBSpjc08, HV_BINOP_DIVIDE, 0, m, &cBinop_sBSpjc08_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A682jNUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DfPT2WuR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sBSpjc08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XN2rmmUo, HV_BINOP_MULTIPLY, 1, m, &cBinop_XN2rmmUo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XN2rmmUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qr6nECqW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ydRCb7Kn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_2lm6f2cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LrRa8F38_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_gjwKhWQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Pmq3ckBx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rsjWlESd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Pab5NEyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pab5NEyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XN2rmmUo, HV_BINOP_MULTIPLY, 0, m, &cBinop_XN2rmmUo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_995IVc2P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_LZgUZMwh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LZgUZMwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aNQkdVmM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_rEoxyKxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0w6hGGef, 1, m, &cVar_0w6hGGef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_0w6hGGef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cyhj5K0I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ihUTAgCc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zeQIcUnl, HV_BINOP_MULTIPLY, 1, m, &cBinop_zeQIcUnl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RvqPRKp4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ihUTAgCc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hrW1Jrok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_QPvomIYb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QPvomIYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9XGHrdRI, HV_BINOP_MULTIPLY, 1, m, &cBinop_9XGHrdRI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EVvCoVLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9ckmXFs, HV_BINOP_MULTIPLY, 1, m, &cBinop_l9ckmXFs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YHcTvvDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_EVvCoVLU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UH3KAy9H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2r8oIsQB, HV_BINOP_MULTIPLY, 1, m, &cBinop_2r8oIsQB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Oe3gDVG2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8sMnXXpc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8sMnXXpc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPkEQf3r, HV_BINOP_MULTIPLY, 1, m, &cBinop_pPkEQf3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_WtTLrH5T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XkihqhDx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_rsjWlESd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_o0D9rTcC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_VUf5KScP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_995IVc2P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ydRCb7Kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_gjwKhWQH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qr6nECqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_2lm6f2cj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_LrRa8F38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GqD03T1z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Pmq3ckBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AvEzp8rn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aZkP9r3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BS6BACjK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aNQkdVmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_D6OjjoQC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D6OjjoQC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qu8uTKyQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qu8uTKyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qu8uTKyQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oDCZsTCY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oDCZsTCY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aZkP9r3B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cyhj5K0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qFEGveKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qFEGveKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zktthKND_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vIAiiRCz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tCZIjONX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ahsHK0SJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0VkkRMn5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ouY1bL99_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zeQIcUnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HBE4DfjK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_9XGHrdRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9X8XYakj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_l9ckmXFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wNCqiiLg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_2r8oIsQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7FU1zahI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_pPkEQf3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cvpicw7h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_D5ahRuQX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VUf5KScP, 1, m, &cVar_VUf5KScP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R8BFCejh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WtTLrH5T, 0, m, &cVar_WtTLrH5T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0VkkRMn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9XGHrdRI, HV_BINOP_MULTIPLY, 0, m, &cBinop_9XGHrdRI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zktthKND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_vIAiiRCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPkEQf3r, HV_BINOP_MULTIPLY, 0, m, &cBinop_pPkEQf3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tCZIjONX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2r8oIsQB, HV_BINOP_MULTIPLY, 0, m, &cBinop_2r8oIsQB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ahsHK0SJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l9ckmXFs, HV_BINOP_MULTIPLY, 0, m, &cBinop_l9ckmXFs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ouY1bL99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zeQIcUnl, HV_BINOP_MULTIPLY, 0, m, &cBinop_zeQIcUnl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XkihqhDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VUf5KScP, 0, m, &cVar_VUf5KScP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_o0D9rTcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0w6hGGef, 0, m, &cVar_0w6hGGef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kprzQDZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6iY1H8Kd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_kvF3JIeJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cjEFPaVo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9MGOshpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PZUJhcZk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tuXIonMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lWkhNk3t, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4etSKqg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_9L90qIPw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_9L90qIPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f8jMHcOF, HV_BINOP_DIVIDE, 1, m, &cBinop_f8jMHcOF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rzpyzaUh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_RRoJtTPT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Rt1icn0p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5DLIfI5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_RRoJtTPT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Rt1icn0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f8jMHcOF, HV_BINOP_DIVIDE, 0, m, &cBinop_f8jMHcOF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rzpyzaUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5DLIfI5z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_f8jMHcOF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O9dHDrT3, HV_BINOP_MULTIPLY, 1, m, &cBinop_O9dHDrT3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O9dHDrT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ONbWTIc5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Gbta7EK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_nMU8Mthh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pjnlURi6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_jyBe8BhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9PVb3Pa1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_N9oi5Rrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_STjhDKwZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_STjhDKwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O9dHDrT3, HV_BINOP_MULTIPLY, 0, m, &cBinop_O9dHDrT3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7hZUKfuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UVj89luV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UVj89luV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CQsJjqF6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_R7SmGEb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_btVAoJqr, HV_BINOP_MULTIPLY, 1, m, &cBinop_btVAoJqr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EzFhyldx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iLNMx7Dx, 1, m, &cVar_iLNMx7Dx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yy1JoCkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hmWQMXN3, HV_BINOP_MULTIPLY, 1, m, &cBinop_hmWQMXN3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_02bsHDhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_urgD7aWe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_urgD7aWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ng7KAZqT, HV_BINOP_MULTIPLY, 1, m, &cBinop_ng7KAZqT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_iLNMx7Dx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QoDBIoOM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Mho8f2UX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Rc4vXjrT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_N9oi5Rrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8W2j38UQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_xvcOlvrR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_7hZUKfuB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ONbWTIc5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_nMU8Mthh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8Gbta7EK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jyBe8BhU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_pjnlURi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IqXDorA9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_9PVb3Pa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_a8EUIwAb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5rzbxzBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_z2yMyDJj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CQsJjqF6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3SrU4P7G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3SrU4P7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZBzaPd9, HV_BINOP_MULTIPLY, 1, m, &cBinop_oZBzaPd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oZBzaPd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_49JNjEPI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_49JNjEPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5rzbxzBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QoDBIoOM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_2gWcwFvF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2gWcwFvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wXYik38a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WuY05ZtY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7Ah56rI2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZNTrrCzl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N7StKpq8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kprzQDZg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_btVAoJqr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kvF3JIeJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_hmWQMXN3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9MGOshpU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ng7KAZqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tuXIonMi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KdQ2A6eA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xvcOlvrR, 1, m, &cVar_xvcOlvrR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vMoULiZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mho8f2UX, 0, m, &cVar_Mho8f2UX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Rc4vXjrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xvcOlvrR, 0, m, &cVar_xvcOlvrR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8W2j38UQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_iLNMx7Dx, 0, m, &cVar_iLNMx7Dx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Ah56rI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_btVAoJqr, HV_BINOP_MULTIPLY, 0, m, &cBinop_btVAoJqr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WuY05ZtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hmWQMXN3, HV_BINOP_MULTIPLY, 0, m, &cBinop_hmWQMXN3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wXYik38a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ng7KAZqT, HV_BINOP_MULTIPLY, 0, m, &cBinop_ng7KAZqT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZNTrrCzl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N7StKpq8, HV_BINOP_MULTIPLY, 0, m, &cBinop_N7StKpq8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s9aiPJXT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LLrVIbIJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3GKpOxeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PvYeXCpk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BuIr6v4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kBsVJ50Q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_iwuAuqbd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b1AdTQDL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QbSLocPv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9SDkS5Mb, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_A7fPKVDP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jnIz2Qoa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_jnIz2Qoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NM0uYUTO, HV_BINOP_DIVIDE, 1, m, &cBinop_NM0uYUTO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ULXTwam_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_77yij53a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_rY3MAUHI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zWFrCaSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_77yij53a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rY3MAUHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NM0uYUTO, HV_BINOP_DIVIDE, 0, m, &cBinop_NM0uYUTO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6ULXTwam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zWFrCaSN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NM0uYUTO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lS1zKVnh, HV_BINOP_MULTIPLY, 1, m, &cBinop_lS1zKVnh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lS1zKVnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qzXbtm5s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sLuN8sRD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_8QtT1NsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_h1rX555X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_FEA8JbeU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1lsSeuTj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_83ZEoI7e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_p4Wk5lnw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p4Wk5lnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lS1zKVnh, HV_BINOP_MULTIPLY, 0, m, &cBinop_lS1zKVnh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mg2Rtrv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_f8BebsGk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f8BebsGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZCbV0Ou2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4yqnz59M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jWCW0czV, HV_BINOP_MULTIPLY, 1, m, &cBinop_jWCW0czV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RdsmhSs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_VL2Nmx6x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VL2Nmx6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4yqnz59M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R0REf1UB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_EeEoj9wW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EeEoj9wW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBYDr03m, HV_BINOP_MULTIPLY, 1, m, &cBinop_JBYDr03m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UiKvsGB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3yKcyG9l, HV_BINOP_MULTIPLY, 1, m, &cBinop_3yKcyG9l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fmIn6LBl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Yd0EYHFG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Yd0EYHFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UiKvsGB3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IHPOcEJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_idJ4f5fV, 1, m, &cVar_idJ4f5fV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_07zBXabU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P9LjaGkb, HV_BINOP_MULTIPLY, 1, m, &cBinop_P9LjaGkb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gGespWi8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xqigsXhD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xqigsXhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jv2uEc1N, HV_BINOP_MULTIPLY, 1, m, &cBinop_jv2uEc1N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_idJ4f5fV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_70zZdpBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CpgAvpV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kaznj0aJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_83ZEoI7e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n5yl9D4M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vmAlKlKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mg2Rtrv4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qzXbtm5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_8QtT1NsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sLuN8sRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FEA8JbeU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_h1rX555X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n4MlYepK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1lsSeuTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_koDzYlI6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_36EX74mA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bWNWbxuY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZCbV0Ou2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_BtCLRJNF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BtCLRJNF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bNsRH78T, HV_BINOP_MULTIPLY, 1, m, &cBinop_bNsRH78T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bNsRH78T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_OzsvcaVX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OzsvcaVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_36EX74mA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_70zZdpBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_iM2B855M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iM2B855M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2OYTlgTd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_decQZhA9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aMbe9YCO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jpHbJ1Kt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rtoD3DZb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xXgyIH8N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jWCW0czV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s9aiPJXT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JBYDr03m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3GKpOxeq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3yKcyG9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BuIr6v4K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_P9LjaGkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iwuAuqbd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jv2uEc1N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QbSLocPv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_adHJhFy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CpgAvpV8, 0, m, &cVar_CpgAvpV8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eqKmifbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vmAlKlKg, 1, m, &cVar_vmAlKlKg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2OYTlgTd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_aMbe9YCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_P9LjaGkb, HV_BINOP_MULTIPLY, 0, m, &cBinop_P9LjaGkb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_decQZhA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jv2uEc1N, HV_BINOP_MULTIPLY, 0, m, &cBinop_jv2uEc1N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rtoD3DZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_JBYDr03m, HV_BINOP_MULTIPLY, 0, m, &cBinop_JBYDr03m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jpHbJ1Kt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3yKcyG9l, HV_BINOP_MULTIPLY, 0, m, &cBinop_3yKcyG9l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xXgyIH8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jWCW0czV, HV_BINOP_MULTIPLY, 0, m, &cBinop_jWCW0czV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kaznj0aJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vmAlKlKg, 0, m, &cVar_vmAlKlKg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n5yl9D4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_idJ4f5fV, 0, m, &cVar_idJ4f5fV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZRlZlWtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dNWvkJdP, 1, m, &cIf_dNWvkJdP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pWiaqFlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_LhCcDCpr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_H2EF7Z3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pWiaqFlR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_tHCe6MPN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dNWvkJdP, 0, m, &cIf_dNWvkJdP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0asyETrU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7xxPHLLZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LhCcDCpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hQFqWAMI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LIQFwB92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o1AaAOB1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VJBvy2uo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZRlZlWtE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H2EF7Z3U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SaYtOrA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_tHCe6MPN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_TUVSE99b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6YAHVeIF, HV_BINOP_DIVIDE, 0, m, &cBinop_6YAHVeIF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_CdpVa0K8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhqFYBtJ, HV_BINOP_DIVIDE, 1, m, &cBinop_GhqFYBtJ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6YAHVeIF, HV_BINOP_DIVIDE, 1, m, &cBinop_6YAHVeIF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_SlbNZumm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYZm4cAL, HV_BINOP_DIVIDE, 0, m, &cBinop_nYZm4cAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Qc2VJaVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nYZm4cAL, HV_BINOP_DIVIDE, 1, m, &cBinop_nYZm4cAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wKfezIAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GhqFYBtJ, HV_BINOP_DIVIDE, 0, m, &cBinop_GhqFYBtJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2dkcGHO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TUVSE99b, 0, m, &cVar_TUVSE99b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VUKEqqP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CdpVa0K8, 0, m, &cVar_CdpVa0K8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GhqFYBtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_SlbNZumm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6YAHVeIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_Qc2VJaVy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nYZm4cAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_7zQVaf6u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_2Zn7cIp0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_eIiqyFcF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MK4JwYqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_jFpZA3ZL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7zQVaf6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_MK4JwYqR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jFpZA3ZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_2Zn7cIp0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eIiqyFcF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ryCzoY4I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zd6L1uXp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gNDrEag9, 0, m, &cSlice_gNDrEag9_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_gNDrEag9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_XETLos1F_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_XETLos1F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_BjRVFyB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_XETLos1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_XETLos1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SYVexDWb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Vx6spxHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_qPPbIDGJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qPPbIDGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_lIgSkjy5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lIgSkjy5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PWI4qRX0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PWI4qRX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mesBDE5K_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TMdhm3nS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TMdhm3nS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6n9x2noj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mesBDE5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_i4qdjZuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_i4qdjZuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_4cOt8WBU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6n9x2noj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1Did2I25_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1Did2I25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_k8bPaU3r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4cOt8WBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gL2KdRgM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_k8bPaU3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_frpySype_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gL2KdRgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xQHU0Epf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_frpySype_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pY30rcy8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_kLmapVVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UqWbllvl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_wCTnGY5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zYxZAOl2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1UC6ektG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vRQN8CbO_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ILz0ML21_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JUpUZLOR_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3N11zDdF_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bMCWAn3c_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T3UKdgtn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_vRQN8CbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GqEPing0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ILz0ML21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n1UGoc1a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_JUpUZLOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DcgWfYyg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3N11zDdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XMGgQCiC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bMCWAn3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5LpOdgXL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_T3UKdgtn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NoY0ktuS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_LXgIr118_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s8ZrrdSl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XD8Pux4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GIh39M3K_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iqhGgfJL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gqPgtqAl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gqPgtqAl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5xry2IVt, 1, m, &cDelay_5xry2IVt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gkKWHlM2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5xry2IVt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5xry2IVt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_LXgIr118, 0, m, &cIf_LXgIr118_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gqPgtqAl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5xry2IVt, 0, m, &cDelay_5xry2IVt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gkKWHlM2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5xry2IVt, 0, m, &cDelay_5xry2IVt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QBJr7MFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VMcJy2bg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uksXu3yL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y1MQb617_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XfywvPM0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xMjhRt24_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XfywvPM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LXgIr118, 1, m, &cIf_LXgIr118_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xMjhRt24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iqhGgfJL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uksXu3yL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XD8Pux4S, 0, m, &cIf_XD8Pux4S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VMcJy2bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XD8Pux4S, 1, m, &cIf_XD8Pux4S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GIh39M3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zEks98oB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s8ZrrdSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zEks98oB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FYIK6d8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KdkiqdJo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vDgnMp2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5NOHSuxI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PkbXKxdj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jeYlRiJb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jeYlRiJb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BGLvIW0v, 1, m, &cDelay_BGLvIW0v_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RcfAwBJM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BGLvIW0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BGLvIW0v, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FYIK6d8J, 0, m, &cIf_FYIK6d8J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jeYlRiJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BGLvIW0v, 0, m, &cDelay_BGLvIW0v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RcfAwBJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BGLvIW0v, 0, m, &cDelay_BGLvIW0v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CypFWbFO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zVqrezfi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zesXQzjB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_niFIimkD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6mgmfDhS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tlfTcXzB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tlfTcXzB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PkbXKxdj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6mgmfDhS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FYIK6d8J, 1, m, &cIf_FYIK6d8J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zVqrezfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vDgnMp2I, 1, m, &cIf_vDgnMp2I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zesXQzjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vDgnMp2I, 0, m, &cIf_vDgnMp2I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5NOHSuxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2fBuFhsA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KdkiqdJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2fBuFhsA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_pSesjkxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7vhAHZf5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_JN7FuLkA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0ZFtL0yv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gZ6qrxFh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_eGtuShuw_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_eGtuShuw_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PcQteLG8, 1, m, &cDelay_PcQteLG8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d8TDhl6l_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_PcQteLG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PcQteLG8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_pSesjkxK, 0, m, &cIf_pSesjkxK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eGtuShuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PcQteLG8, 0, m, &cDelay_PcQteLG8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d8TDhl6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PcQteLG8, 0, m, &cDelay_PcQteLG8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_r7HMHuNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rhjbp9lk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tu27Uzeu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8y9IBYnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kWHuCQYC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d407vORZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kWHuCQYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pSesjkxK, 1, m, &cIf_pSesjkxK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_d407vORZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gZ6qrxFh_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rhjbp9lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JN7FuLkA, 1, m, &cIf_JN7FuLkA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tu27Uzeu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JN7FuLkA, 0, m, &cIf_JN7FuLkA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0ZFtL0yv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zDS0866T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7vhAHZf5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zDS0866T, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ylEcGGIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_v5f8Bukh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_aochpmOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cNMjfePg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7jUQemZX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_TrwWnPJf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_TrwWnPJf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JXkOEiHL, 1, m, &cDelay_JXkOEiHL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UWTahTG1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JXkOEiHL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JXkOEiHL, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ylEcGGIf, 0, m, &cIf_ylEcGGIf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TrwWnPJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JXkOEiHL, 0, m, &cDelay_JXkOEiHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UWTahTG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JXkOEiHL, 0, m, &cDelay_JXkOEiHL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bfonUnu2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7vW7qIqc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iNar5sIU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7pjBbuF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kWngTwk5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eV5OShsY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eV5OShsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7jUQemZX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kWngTwk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ylEcGGIf, 1, m, &cIf_ylEcGGIf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iNar5sIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aochpmOq, 0, m, &cIf_aochpmOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7vW7qIqc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aochpmOq, 1, m, &cIf_aochpmOq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cNMjfePg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M8CCoqfr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_v5f8Bukh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M8CCoqfr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Io36skL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_F6uUOAVf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Aq1Roz4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_copy1gST_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_k6DJVB7W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bRiCFI35_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bRiCFI35_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5vDSjL7U, 1, m, &cDelay_5vDSjL7U_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k6LFuFex_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5vDSjL7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5vDSjL7U, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Io36skL5, 0, m, &cIf_Io36skL5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bRiCFI35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5vDSjL7U, 0, m, &cDelay_5vDSjL7U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k6LFuFex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5vDSjL7U, 0, m, &cDelay_5vDSjL7U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_erZCTR0T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B0H1ya45_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zIDWDPIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RaDMMbnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6Ft8X4fq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1FCiDjDu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Ft8X4fq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Io36skL5, 1, m, &cIf_Io36skL5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1FCiDjDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_k6DJVB7W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_B0H1ya45_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aq1Roz4O, 1, m, &cIf_Aq1Roz4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zIDWDPIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Aq1Roz4O, 0, m, &cIf_Aq1Roz4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_copy1gST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zG2tIeqh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F6uUOAVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zG2tIeqh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GrUvTtgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DuJZ8qvn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eo8pngWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YW0JPwm3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qX2gq5Ij_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_DiAOKIFT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_DiAOKIFT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VwPj0rZs, 1, m, &cDelay_VwPj0rZs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mqLVT2QV_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VwPj0rZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VwPj0rZs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GrUvTtgd, 0, m, &cIf_GrUvTtgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DiAOKIFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VwPj0rZs, 0, m, &cDelay_VwPj0rZs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mqLVT2QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VwPj0rZs, 0, m, &cDelay_VwPj0rZs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WjlNbfwG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eWCF6D6s_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s3xn5I3x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dzVkbnn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cKchcIZ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6Hg3utSO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6Hg3utSO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qX2gq5Ij_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cKchcIZ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GrUvTtgd, 1, m, &cIf_GrUvTtgd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eWCF6D6s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eo8pngWF, 1, m, &cIf_eo8pngWF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s3xn5I3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eo8pngWF, 0, m, &cIf_eo8pngWF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YW0JPwm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZUn0YUQJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DuJZ8qvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZUn0YUQJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RH6H0Tlh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pM3Bxezz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bVrdHTNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JH6sdjRM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kzUOcGPN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Rp34lULE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Rp34lULE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Uu9MoxRQ, 1, m, &cDelay_Uu9MoxRQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6LChiTx9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Uu9MoxRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Uu9MoxRQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RH6H0Tlh, 0, m, &cIf_RH6H0Tlh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Rp34lULE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Uu9MoxRQ, 0, m, &cDelay_Uu9MoxRQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6LChiTx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Uu9MoxRQ, 0, m, &cDelay_Uu9MoxRQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NbO1ObBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tPjR0UjV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3VZMLTfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cZyvSybq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rizqXa4n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_moo0DuS2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rizqXa4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RH6H0Tlh, 1, m, &cIf_RH6H0Tlh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_moo0DuS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kzUOcGPN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3VZMLTfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bVrdHTNk, 0, m, &cIf_bVrdHTNk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tPjR0UjV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bVrdHTNk, 1, m, &cIf_bVrdHTNk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JH6sdjRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MRRdV0yh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pM3Bxezz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MRRdV0yh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4PEZSVja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TCJ8Za1f_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WJAIQG8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ok1e16ae_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wxhWh5Xt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5uMlelxh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5uMlelxh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uCjV1YyZ, 1, m, &cDelay_uCjV1YyZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8brdfTS2_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uCjV1YyZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uCjV1YyZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4PEZSVja, 0, m, &cIf_4PEZSVja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5uMlelxh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uCjV1YyZ, 0, m, &cDelay_uCjV1YyZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8brdfTS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uCjV1YyZ, 0, m, &cDelay_uCjV1YyZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tl75Vv9d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7cOQTdkG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jgzkKl36_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DJjslWMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BKbFU2LQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RmCMAn2d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RmCMAn2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wxhWh5Xt_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BKbFU2LQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4PEZSVja, 1, m, &cIf_4PEZSVja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7cOQTdkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WJAIQG8f, 1, m, &cIf_WJAIQG8f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jgzkKl36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WJAIQG8f, 0, m, &cIf_WJAIQG8f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ok1e16ae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yHlGqKyB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_TCJ8Za1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yHlGqKyB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_JVIE7IuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7GRqsJDO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_I6hpGPSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xLMhKUNk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Tuh71k41_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lm0Od9sI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lm0Od9sI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UWj1zzfW, 1, m, &cDelay_UWj1zzfW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HuMKHYlj_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UWj1zzfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UWj1zzfW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_JVIE7IuY, 0, m, &cIf_JVIE7IuY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lm0Od9sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UWj1zzfW, 0, m, &cDelay_UWj1zzfW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HuMKHYlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UWj1zzfW, 0, m, &cDelay_UWj1zzfW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IPpWPUOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fu1nNXKE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eOb3AcOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nVnNl2sB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wkBtw9mV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tXw8gXJt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tXw8gXJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Tuh71k41_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wkBtw9mV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_JVIE7IuY, 1, m, &cIf_JVIE7IuY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Fu1nNXKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I6hpGPSJ, 1, m, &cIf_I6hpGPSJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eOb3AcOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I6hpGPSJ, 0, m, &cIf_I6hpGPSJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xLMhKUNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hkYgUgXE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7GRqsJDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hkYgUgXE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6X7y7xZa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WqIa8BqU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3bdgz8FA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_l2ROSXJV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hI3hfdDp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0iFXJ4Ic_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0iFXJ4Ic_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gkIg8k8c, 1, m, &cDelay_gkIg8k8c_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KANVBNV5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gkIg8k8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gkIg8k8c, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6X7y7xZa, 0, m, &cIf_6X7y7xZa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0iFXJ4Ic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gkIg8k8c, 0, m, &cDelay_gkIg8k8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KANVBNV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gkIg8k8c, 0, m, &cDelay_gkIg8k8c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_REtZ9GJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DyjLVoOY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jL0KGHbU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LuApEjQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yyLr65zN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TI5s9o7H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TI5s9o7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hI3hfdDp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_yyLr65zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6X7y7xZa, 1, m, &cIf_6X7y7xZa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DyjLVoOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3bdgz8FA, 1, m, &cIf_3bdgz8FA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jL0KGHbU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3bdgz8FA, 0, m, &cIf_3bdgz8FA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l2ROSXJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8BOBNoKg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WqIa8BqU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8BOBNoKg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_5KC5ZTJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_16dknRqf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XZKFupAz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_2YzqHsdm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UBUEuAaR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_M2kON53V_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_M2kON53V_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_n3xcXKHA, 1, m, &cDelay_n3xcXKHA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cLrgqtY7_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_n3xcXKHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_n3xcXKHA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5KC5ZTJN, 0, m, &cIf_5KC5ZTJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M2kON53V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_n3xcXKHA, 0, m, &cDelay_n3xcXKHA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cLrgqtY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_n3xcXKHA, 0, m, &cDelay_n3xcXKHA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NDznPj2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XJyZeOEV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vUXr8jV8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_BodUYSFm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_76bdC1V0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nhJdZhus_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nhJdZhus_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UBUEuAaR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_76bdC1V0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5KC5ZTJN, 1, m, &cIf_5KC5ZTJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XJyZeOEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XZKFupAz, 1, m, &cIf_XZKFupAz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vUXr8jV8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XZKFupAz, 0, m, &cIf_XZKFupAz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2YzqHsdm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qYrhfA9V, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_16dknRqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qYrhfA9V, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_I0KuHJkj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZKaVBQsS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_s2yCBeKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uXKW5U0n_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wa5ydhai_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4yHDCA51_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4yHDCA51_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cOZQPj4s, 1, m, &cDelay_cOZQPj4s_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mVcYoOyF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cOZQPj4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cOZQPj4s, m);
  cIf_onMessage(_c, &Context(_c)->cIf_I0KuHJkj, 0, m, &cIf_I0KuHJkj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4yHDCA51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOZQPj4s, 0, m, &cDelay_cOZQPj4s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mVcYoOyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cOZQPj4s, 0, m, &cDelay_cOZQPj4s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4Ta4WO60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YyKrajN8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pk2vsdVY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6WLQA35g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l7Vk9d3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wr2sk0lJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l7Vk9d3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_I0KuHJkj, 1, m, &cIf_I0KuHJkj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wr2sk0lJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_wa5ydhai_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pk2vsdVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s2yCBeKZ, 0, m, &cIf_s2yCBeKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YyKrajN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s2yCBeKZ, 1, m, &cIf_s2yCBeKZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uXKW5U0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rv7q04gf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZKaVBQsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rv7q04gf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GqEPing0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_Gey5sQIp_sendMessage(_c, 0, m);
  cMsg_Q662R6t6_sendMessage(_c, 0, m);
  cMsg_nU2UTEq0_sendMessage(_c, 0, m);
  cMsg_O2SGHAIu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n1UGoc1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_Gey5sQIp_sendMessage(_c, 0, m);
  cMsg_qP1awNkw_sendMessage(_c, 0, m);
  cMsg_lUnnlhCU_sendMessage(_c, 0, m);
  cMsg_EqspBIVS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DcgWfYyg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_dUsp3BYx_sendMessage(_c, 0, m);
  cMsg_qP1awNkw_sendMessage(_c, 0, m);
  cMsg_O2SGHAIu_sendMessage(_c, 0, m);
  cMsg_PHod9KOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XMGgQCiC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_dUsp3BYx_sendMessage(_c, 0, m);
  cMsg_yn1ULPZx_sendMessage(_c, 0, m);
  cMsg_nU2UTEq0_sendMessage(_c, 0, m);
  cMsg_fbiHpER2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5LpOdgXL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_284sW3Em_sendMessage(_c, 0, m);
  cMsg_EqspBIVS_sendMessage(_c, 0, m);
  cMsg_ikDqlOp7_sendMessage(_c, 0, m);
  cMsg_nU2UTEq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NoY0ktuS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_284sW3Em_sendMessage(_c, 0, m);
  cMsg_fbiHpER2_sendMessage(_c, 0, m);
  cMsg_qP1awNkw_sendMessage(_c, 0, m);
  cMsg_Lx49476e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7HrmKQOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y1MQb617_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QBJr7MFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dfEPA9qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_y1MQb617_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QBJr7MFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NP6qdTBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_niFIimkD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CypFWbFO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OPDhFU7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_niFIimkD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CypFWbFO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B72mvoKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8y9IBYnm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_r7HMHuNA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qYl1juwn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8y9IBYnm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_r7HMHuNA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Gey5sQIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_7HrmKQOr_sendMessage(_c, 0, m);
  cMsg_OPDhFU7K_sendMessage(_c, 0, m);
  cMsg_qYl1juwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dUsp3BYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_dfEPA9qt_sendMessage(_c, 0, m);
  cMsg_NP6qdTBg_sendMessage(_c, 0, m);
  cMsg_qYl1juwn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_284sW3Em_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_dfEPA9qt_sendMessage(_c, 0, m);
  cMsg_OPDhFU7K_sendMessage(_c, 0, m);
  cMsg_B72mvoKS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rbqthDPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7pjBbuF9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bfonUnu2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dUSHjYT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7pjBbuF9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bfonUnu2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5nWbmmoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RaDMMbnq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_erZCTR0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1NRBq1RO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_RaDMMbnq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_erZCTR0T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3MVtc3na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dzVkbnn5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WjlNbfwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zWB4zXtg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dzVkbnn5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WjlNbfwG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qP1awNkw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_dUSHjYT0_sendMessage(_c, 0, m);
  cMsg_1NRBq1RO_sendMessage(_c, 0, m);
  cMsg_zWB4zXtg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q662R6t6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_dUSHjYT0_sendMessage(_c, 0, m);
  cMsg_5nWbmmoW_sendMessage(_c, 0, m);
  cMsg_3MVtc3na_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yn1ULPZx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_rbqthDPx_sendMessage(_c, 0, m);
  cMsg_1NRBq1RO_sendMessage(_c, 0, m);
  cMsg_3MVtc3na_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VhnCy0Xn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LuApEjQm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_REtZ9GJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FSM71Srj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LuApEjQm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_REtZ9GJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CNSSrm9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BodUYSFm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NDznPj2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pSeIHsmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BodUYSFm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NDznPj2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RYt1iX3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6WLQA35g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4Ta4WO60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fIsjUgwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6WLQA35g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4Ta4WO60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fbiHpER2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_VhnCy0Xn_sendMessage(_c, 0, m);
  cMsg_pSeIHsmU_sendMessage(_c, 0, m);
  cMsg_fIsjUgwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EqspBIVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_FSM71Srj_sendMessage(_c, 0, m);
  cMsg_CNSSrm9v_sendMessage(_c, 0, m);
  cMsg_fIsjUgwt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_O2SGHAIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_FSM71Srj_sendMessage(_c, 0, m);
  cMsg_pSeIHsmU_sendMessage(_c, 0, m);
  cMsg_RYt1iX3Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gCqYyylx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cZyvSybq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NbO1ObBZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cse7SV28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cZyvSybq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NbO1ObBZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U42Uvl4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DJjslWMQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tl75Vv9d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GGxiwvA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DJjslWMQ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tl75Vv9d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_odhKojFe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nVnNl2sB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IPpWPUOj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QOaVlNFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nVnNl2sB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IPpWPUOj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nU2UTEq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_cse7SV28_sendMessage(_c, 0, m);
  cMsg_GGxiwvA8_sendMessage(_c, 0, m);
  cMsg_QOaVlNFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lUnnlhCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_cse7SV28_sendMessage(_c, 0, m);
  cMsg_U42Uvl4S_sendMessage(_c, 0, m);
  cMsg_odhKojFe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Lx49476e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_gCqYyylx_sendMessage(_c, 0, m);
  cMsg_U42Uvl4S_sendMessage(_c, 0, m);
  cMsg_QOaVlNFi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ikDqlOp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_rbqthDPx_sendMessage(_c, 0, m);
  cMsg_5nWbmmoW_sendMessage(_c, 0, m);
  cMsg_zWB4zXtg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PHod9KOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_gCqYyylx_sendMessage(_c, 0, m);
  cMsg_GGxiwvA8_sendMessage(_c, 0, m);
  cMsg_odhKojFe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_IJNhhYMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2taw9nGA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VEm2ZWvT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n1gbj6q6, 0, m, &cSlice_n1gbj6q6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_s81DeZdf_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_n1gbj6q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_T4u5HyJm_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_T4u5HyJm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_W8YE5yJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_T4u5HyJm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_T4u5HyJm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aci8luP9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fRPGCpMW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mldim5Gx, 0, m, &cSlice_mldim5Gx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Xehn8ax4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mldim5Gx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_A8mNQrpR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_A8mNQrpR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PnnM8CbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_A8mNQrpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_A8mNQrpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KCpHR8bu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xehn8ax4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rmPdGS04, 0, m, &cSlice_rmPdGS04_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VEm2ZWvT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rmPdGS04_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_W297DtGo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_W297DtGo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TS6pQRih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W297DtGo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_W297DtGo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gJMmQPOv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_s81DeZdf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VVml5aIs, 0, m, &cSlice_VVml5aIs_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PYJFQL2c_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VVml5aIs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ayS3snU5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ayS3snU5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ul0MPTVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ayS3snU5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ayS3snU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jEgHlgTf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PYJFQL2c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_I33pyIzK, 0, m, &cSlice_I33pyIzK_sendMessage);
      break;
    }
    default: {
      cSwitchcase_VKpUIvw6_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_I33pyIzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_z2hSOFgA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_z2hSOFgA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ovACBqFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_z2hSOFgA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_z2hSOFgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cXIVHbqt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_V0gudBUx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lqV5vTrJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lqV5vTrJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Zn2MNaO3, 1, m, &cDelay_Zn2MNaO3_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gW8ZYFpC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Zn2MNaO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Zn2MNaO3, m);
  cMsg_mv04Xm9E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lqV5vTrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Zn2MNaO3, 0, m, &cDelay_Zn2MNaO3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gW8ZYFpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Zn2MNaO3, 0, m, &cDelay_Zn2MNaO3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4UQ6OPaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yC0mzxOY, HV_BINOP_SUBTRACT, 0, m, &cBinop_yC0mzxOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_PWuKZ2Uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XfRTpc0h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_axopUEjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XfRTpc0h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_GgxBQ18X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4UQ6OPaA, 0, m, &cVar_4UQ6OPaA_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_rrgeOUly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DgLNmWzT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_voCzxVjy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IOT6Xehy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yC0mzxOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_elr0dccb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_elr0dccb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_UjGXhnDl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UjGXhnDl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Ps6GwFRc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d0HHSZXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8KlgFHYF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v3E86sjS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8KlgFHYF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PWuKZ2Uu, 1, m, &cIf_PWuKZ2Uu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v3E86sjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TQ1sa2dJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_851ahAXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_axopUEjQ, 1, m, &cIf_axopUEjQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TQ1sa2dJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_PWuKZ2Uu, 0, m, &cIf_PWuKZ2Uu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ps6GwFRc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_axopUEjQ, 0, m, &cIf_axopUEjQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IOT6Xehy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4UQ6OPaA, 0, m, &cVar_4UQ6OPaA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DgLNmWzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_voCzxVjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yC0mzxOY, HV_BINOP_SUBTRACT, 1, m, &cBinop_yC0mzxOY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XfRTpc0h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wqpsTZL8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VKpUIvw6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qRV5TOqy, 0, m, &cSlice_qRV5TOqy_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_qRV5TOqy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0vew1oxl_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0vew1oxl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ji9ULSjz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0vew1oxl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0vew1oxl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_D0WYEijN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UqWbllvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xo0QmQVi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zYxZAOl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ebb8WwMA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ZldRKBAc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wCTnGY5w, 0, m, &cVar_wCTnGY5w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2taw9nGA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FhWVJ0zi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mYU5EGCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HKr5rE5N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GFYSDhpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_V0gudBUx_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mv04Xm9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2fOMXUgw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HKr5rE5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2fOMXUgw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BfyWXQzb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_J0OMgr59_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_J0OMgr59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M7wVD54X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M7wVD54X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b6Qfohmy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_6Qn9NPUQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wP3CqRN1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_INwKtGV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wuWaZhn6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_bNIw97ch_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aqBupoOx_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dknmor6y_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wx0IWgh2_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YpOE3cX2_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_241Azegs_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ODJe1xHT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_aqBupoOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xSDBzqKv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_dknmor6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ukGtyhBf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Wx0IWgh2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WyxU1ZcE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YpOE3cX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7rMq10CH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_241Azegs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B3qloes1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ODJe1xHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cUMAnRbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_s503L93z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zX5s7GEe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Nkq8ipRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SnsWg3HO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KRl9q3Yu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NwYBCk5U_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NwYBCk5U_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rYwA5Wn5, 1, m, &cDelay_rYwA5Wn5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lN1AHFiM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rYwA5Wn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rYwA5Wn5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_s503L93z, 0, m, &cIf_s503L93z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NwYBCk5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rYwA5Wn5, 0, m, &cDelay_rYwA5Wn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lN1AHFiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rYwA5Wn5, 0, m, &cDelay_rYwA5Wn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kTd9V2Ki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KWe4ytqW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qpqENt0y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LU69q75b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B8L4itge_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3kScCJsc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B8L4itge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s503L93z, 1, m, &cIf_s503L93z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3kScCJsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KRl9q3Yu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qpqENt0y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nkq8ipRh, 0, m, &cIf_Nkq8ipRh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KWe4ytqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Nkq8ipRh, 1, m, &cIf_Nkq8ipRh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SnsWg3HO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YyQEh9u7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zX5s7GEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YyQEh9u7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ebUBStIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nbQO2pBu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Rwi9ffCU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CNYfmuMb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6HnNcoWT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0Q6FD6pc_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0Q6FD6pc_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OYJyH31z, 1, m, &cDelay_OYJyH31z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gURu5Kjw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OYJyH31z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OYJyH31z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ebUBStIr, 0, m, &cIf_ebUBStIr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Q6FD6pc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OYJyH31z, 0, m, &cDelay_OYJyH31z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gURu5Kjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OYJyH31z, 0, m, &cDelay_OYJyH31z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZddSxmRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2HrhFK8r_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E91LEruL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WYlyrbfk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WvnzCC5p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EijRxJmQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EijRxJmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6HnNcoWT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WvnzCC5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ebUBStIr, 1, m, &cIf_ebUBStIr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E91LEruL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rwi9ffCU, 0, m, &cIf_Rwi9ffCU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2HrhFK8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Rwi9ffCU, 1, m, &cIf_Rwi9ffCU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CNYfmuMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Mt26uGm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nbQO2pBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6Mt26uGm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_KscKAAYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FOv02Kwt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yY5LxH17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eSiIlZw3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WSBS2l7O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_iEW3rmEM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_iEW3rmEM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_s5bTPOg6, 1, m, &cDelay_s5bTPOg6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xGjt4wjM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_s5bTPOg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_s5bTPOg6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_KscKAAYl, 0, m, &cIf_KscKAAYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iEW3rmEM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_s5bTPOg6, 0, m, &cDelay_s5bTPOg6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xGjt4wjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_s5bTPOg6, 0, m, &cDelay_s5bTPOg6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wkFKEQyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4MP7OwKN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NTQkvDLY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PUIWqwBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LCaMLV4G_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YpqjjNaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YpqjjNaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_WSBS2l7O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LCaMLV4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KscKAAYl, 1, m, &cIf_KscKAAYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4MP7OwKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yY5LxH17, 1, m, &cIf_yY5LxH17_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NTQkvDLY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yY5LxH17, 0, m, &cIf_yY5LxH17_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eSiIlZw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eDgg0PwA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FOv02Kwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eDgg0PwA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9xRkGhBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uo0Yf0ZY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LkqnKe3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M5OeGjjY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_LZ60m6lA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_McwPydV7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_McwPydV7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_X7odDqaO, 1, m, &cDelay_X7odDqaO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pUmv1Juu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_X7odDqaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_X7odDqaO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9xRkGhBa, 0, m, &cIf_9xRkGhBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_McwPydV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_X7odDqaO, 0, m, &cDelay_X7odDqaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pUmv1Juu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_X7odDqaO, 0, m, &cDelay_X7odDqaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F0KX1yAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SqOtMEoW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sml7K26W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5s8CppIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rnpKsnX5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tQxLW4xc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tQxLW4xc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_LZ60m6lA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rnpKsnX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9xRkGhBa, 1, m, &cIf_9xRkGhBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SqOtMEoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LkqnKe3z, 1, m, &cIf_LkqnKe3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sml7K26W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LkqnKe3z, 0, m, &cIf_LkqnKe3z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M5OeGjjY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f1E1Uy1W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uo0Yf0ZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f1E1Uy1W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_0lKputYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ai56lu5a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Ij77rBXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bl7twqnK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UnatPGYX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5Jbzsryv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5Jbzsryv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vmQWWGwk, 1, m, &cDelay_vmQWWGwk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NtXKI5Ew_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vmQWWGwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vmQWWGwk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_0lKputYa, 0, m, &cIf_0lKputYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5Jbzsryv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vmQWWGwk, 0, m, &cDelay_vmQWWGwk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NtXKI5Ew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vmQWWGwk, 0, m, &cDelay_vmQWWGwk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mjOGhtTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nhV3uHLc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O7kGNJPA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dayoAJA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B2beTbZ7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_acgYVwKd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_acgYVwKd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UnatPGYX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_B2beTbZ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0lKputYa, 1, m, &cIf_0lKputYa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O7kGNJPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ij77rBXw, 0, m, &cIf_Ij77rBXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nhV3uHLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ij77rBXw, 1, m, &cIf_Ij77rBXw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bl7twqnK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I5DCrMpQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ai56lu5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_I5DCrMpQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PHkgRQwE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jeJELmHO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_KnEryivx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gKBoLjsG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9SVKXssa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0WqWDy4L_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0WqWDy4L_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0DAikkpV, 1, m, &cDelay_0DAikkpV_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OsXOm7Po_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0DAikkpV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0DAikkpV, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PHkgRQwE, 0, m, &cIf_PHkgRQwE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0WqWDy4L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0DAikkpV, 0, m, &cDelay_0DAikkpV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OsXOm7Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0DAikkpV, 0, m, &cDelay_0DAikkpV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NhWOWAyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ExlYIdE9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iTqfWTSb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iAmaAMOw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rL6zQ4GU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XaB1LoUE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rL6zQ4GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PHkgRQwE, 1, m, &cIf_PHkgRQwE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XaB1LoUE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9SVKXssa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ExlYIdE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KnEryivx, 1, m, &cIf_KnEryivx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iTqfWTSb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_KnEryivx, 0, m, &cIf_KnEryivx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gKBoLjsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pxW1SLgH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jeJELmHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pxW1SLgH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_48LYflo7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_shw8dvhQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MdOnbrAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sQRPLR1z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0CXH1uui_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_u6455kK7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_u6455kK7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_HRdHTaVY, 1, m, &cDelay_HRdHTaVY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gnl1z9CM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_HRdHTaVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_HRdHTaVY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_48LYflo7, 0, m, &cIf_48LYflo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u6455kK7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_HRdHTaVY, 0, m, &cDelay_HRdHTaVY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gnl1z9CM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_HRdHTaVY, 0, m, &cDelay_HRdHTaVY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PFtdJm7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AgcH6EPf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DOmoDqYG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SurSiVhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CxCUnGST_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dYcQ1ZuD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CxCUnGST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_48LYflo7, 1, m, &cIf_48LYflo7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dYcQ1ZuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0CXH1uui_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_AgcH6EPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MdOnbrAO, 1, m, &cIf_MdOnbrAO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DOmoDqYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MdOnbrAO, 0, m, &cIf_MdOnbrAO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sQRPLR1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HsoUeM5i, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_shw8dvhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HsoUeM5i, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_OPahWzgp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nklQF8yA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RBRIcDkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8sFEePlo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sSSlZjsX_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ObDfMtHP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ObDfMtHP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_2ZfYabiM, 1, m, &cDelay_2ZfYabiM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N5sYghKH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_2ZfYabiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_2ZfYabiM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_OPahWzgp, 0, m, &cIf_OPahWzgp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ObDfMtHP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ZfYabiM, 0, m, &cDelay_2ZfYabiM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N5sYghKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_2ZfYabiM, 0, m, &cDelay_2ZfYabiM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jKHuVKI2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x6PzsftK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XAF2iuon_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0MS7MIoB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dKk8bOZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wjior0k6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dKk8bOZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OPahWzgp, 1, m, &cIf_OPahWzgp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wjior0k6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_sSSlZjsX_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XAF2iuon_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RBRIcDkL, 0, m, &cIf_RBRIcDkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x6PzsftK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RBRIcDkL, 1, m, &cIf_RBRIcDkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8sFEePlo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ck43FXAX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nklQF8yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ck43FXAX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VvrU071w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_teDIpJ9Q_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yNvwLR3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d4p3sKkz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_AnTxoIfR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2ZPkEBWk_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2ZPkEBWk_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_RstYMjV5, 1, m, &cDelay_RstYMjV5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_04kosVqu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_RstYMjV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_RstYMjV5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VvrU071w, 0, m, &cIf_VvrU071w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2ZPkEBWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_RstYMjV5, 0, m, &cDelay_RstYMjV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_04kosVqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_RstYMjV5, 0, m, &cDelay_RstYMjV5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Sg1ombt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vnXF1u6Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5BRFKbp3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0MaKMnmY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mb1cnvLp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ABPMDtQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mb1cnvLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VvrU071w, 1, m, &cIf_VvrU071w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6ABPMDtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_AnTxoIfR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_5BRFKbp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yNvwLR3t, 0, m, &cIf_yNvwLR3t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vnXF1u6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yNvwLR3t, 1, m, &cIf_yNvwLR3t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d4p3sKkz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BHHkwTaM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_teDIpJ9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BHHkwTaM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CNR9X6In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aBoNkXc4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZjRNBeHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_d7aI7mbx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h5vNk5FS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_x275dGue_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_x275dGue_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YjlgwysW, 1, m, &cDelay_YjlgwysW_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PUjT54PA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YjlgwysW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YjlgwysW, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CNR9X6In, 0, m, &cIf_CNR9X6In_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x275dGue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YjlgwysW, 0, m, &cDelay_YjlgwysW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PUjT54PA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YjlgwysW, 0, m, &cDelay_YjlgwysW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pmN77b4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TxsA0A2k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1ZuCcA2s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TZeHBzCn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_z1vrACo9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AhsXuDY6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AhsXuDY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_h5vNk5FS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_z1vrACo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CNR9X6In, 1, m, &cIf_CNR9X6In_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TxsA0A2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZjRNBeHa, 1, m, &cIf_ZjRNBeHa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1ZuCcA2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZjRNBeHa, 0, m, &cIf_ZjRNBeHa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d7aI7mbx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o8SlLqDS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aBoNkXc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o8SlLqDS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_PkQyXTvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OeGacAuc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XqnnOlWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xG9Ez6Jm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u2FTQ2Ff_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4DIyNjuj_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4DIyNjuj_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_irOK2fEz, 1, m, &cDelay_irOK2fEz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CjGQED0G_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_irOK2fEz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_irOK2fEz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_PkQyXTvp, 0, m, &cIf_PkQyXTvp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4DIyNjuj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_irOK2fEz, 0, m, &cDelay_irOK2fEz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CjGQED0G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_irOK2fEz, 0, m, &cDelay_irOK2fEz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MTknD0sX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cSE10QuE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j9pflSgI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QPQ3Yti0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5BturBQB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nQd4VZJE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5BturBQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PkQyXTvp, 1, m, &cIf_PkQyXTvp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nQd4VZJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u2FTQ2Ff_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_j9pflSgI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqnnOlWP, 0, m, &cIf_XqnnOlWP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cSE10QuE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XqnnOlWP, 1, m, &cIf_XqnnOlWP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xG9Ez6Jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oMK9TRn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OeGacAuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oMK9TRn3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3sxFNgh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IUyXz52Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sQULVl1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RkeaRiRw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_h6RWqE62_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Yzzk8YwP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Yzzk8YwP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EM8cyfD8, 1, m, &cDelay_EM8cyfD8_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1CMGCEAt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EM8cyfD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EM8cyfD8, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3sxFNgh6, 0, m, &cIf_3sxFNgh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Yzzk8YwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EM8cyfD8, 0, m, &cDelay_EM8cyfD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1CMGCEAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EM8cyfD8, 0, m, &cDelay_EM8cyfD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w0VnBuPY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qVxFMosj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JllBRTq2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TpmqBO5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cjwMEa4I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WPMjhgcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WPMjhgcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_h6RWqE62_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cjwMEa4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3sxFNgh6, 1, m, &cIf_3sxFNgh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JllBRTq2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sQULVl1o, 0, m, &cIf_sQULVl1o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qVxFMosj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sQULVl1o, 1, m, &cIf_sQULVl1o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RkeaRiRw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x6RgB9WE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IUyXz52Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x6RgB9WE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xSDBzqKv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_rUiSiGwH_sendMessage(_c, 0, m);
  cMsg_FlQqhu1J_sendMessage(_c, 0, m);
  cMsg_Liggq43a_sendMessage(_c, 0, m);
  cMsg_V333tiOe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ukGtyhBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_rUiSiGwH_sendMessage(_c, 0, m);
  cMsg_dWwX5yrM_sendMessage(_c, 0, m);
  cMsg_bBSq1H38_sendMessage(_c, 0, m);
  cMsg_aQiteDC0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WyxU1ZcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_9PvnsNQG_sendMessage(_c, 0, m);
  cMsg_dWwX5yrM_sendMessage(_c, 0, m);
  cMsg_V333tiOe_sendMessage(_c, 0, m);
  cMsg_zEcRVMaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7rMq10CH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_9PvnsNQG_sendMessage(_c, 0, m);
  cMsg_SE1LRUhJ_sendMessage(_c, 0, m);
  cMsg_Liggq43a_sendMessage(_c, 0, m);
  cMsg_z5iojEJE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B3qloes1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_4HGJxwhH_sendMessage(_c, 0, m);
  cMsg_aQiteDC0_sendMessage(_c, 0, m);
  cMsg_nhQB4tyu_sendMessage(_c, 0, m);
  cMsg_Liggq43a_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cUMAnRbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_4HGJxwhH_sendMessage(_c, 0, m);
  cMsg_z5iojEJE_sendMessage(_c, 0, m);
  cMsg_dWwX5yrM_sendMessage(_c, 0, m);
  cMsg_zYcu5wnQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Ve9DcVJo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LU69q75b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kTd9V2Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_R9NDe2GN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LU69q75b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kTd9V2Ki_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aD8oW25F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WYlyrbfk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZddSxmRq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2GpsISmZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_WYlyrbfk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZddSxmRq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kyhjpX7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PUIWqwBU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wkFKEQyO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BTr4uqEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PUIWqwBU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wkFKEQyO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rUiSiGwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_Ve9DcVJo_sendMessage(_c, 0, m);
  cMsg_2GpsISmZ_sendMessage(_c, 0, m);
  cMsg_BTr4uqEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9PvnsNQG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_R9NDe2GN_sendMessage(_c, 0, m);
  cMsg_aD8oW25F_sendMessage(_c, 0, m);
  cMsg_BTr4uqEe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4HGJxwhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_R9NDe2GN_sendMessage(_c, 0, m);
  cMsg_2GpsISmZ_sendMessage(_c, 0, m);
  cMsg_kyhjpX7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uaE4BUFk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5s8CppIC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_F0KX1yAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sXbP6iFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5s8CppIC_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_F0KX1yAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JxBvX7JY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dayoAJA2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mjOGhtTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jwOKz020_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_dayoAJA2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_mjOGhtTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lOundeEj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iAmaAMOw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NhWOWAyb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N7MK2SQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iAmaAMOw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NhWOWAyb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dWwX5yrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_sXbP6iFd_sendMessage(_c, 0, m);
  cMsg_jwOKz020_sendMessage(_c, 0, m);
  cMsg_N7MK2SQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FlQqhu1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_sXbP6iFd_sendMessage(_c, 0, m);
  cMsg_JxBvX7JY_sendMessage(_c, 0, m);
  cMsg_lOundeEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SE1LRUhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_uaE4BUFk_sendMessage(_c, 0, m);
  cMsg_jwOKz020_sendMessage(_c, 0, m);
  cMsg_lOundeEj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TvDg3JZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TZeHBzCn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pmN77b4U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o9CeuCdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TZeHBzCn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pmN77b4U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gPLGSrue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QPQ3Yti0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MTknD0sX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_veQT3szT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QPQ3Yti0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MTknD0sX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SmkoHVwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TpmqBO5b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w0VnBuPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CdhrRHOY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TpmqBO5b_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_w0VnBuPY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_z5iojEJE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_TvDg3JZm_sendMessage(_c, 0, m);
  cMsg_veQT3szT_sendMessage(_c, 0, m);
  cMsg_CdhrRHOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aQiteDC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_o9CeuCdy_sendMessage(_c, 0, m);
  cMsg_gPLGSrue_sendMessage(_c, 0, m);
  cMsg_CdhrRHOY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V333tiOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_o9CeuCdy_sendMessage(_c, 0, m);
  cMsg_veQT3szT_sendMessage(_c, 0, m);
  cMsg_SmkoHVwK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iMm1K3VN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SurSiVhJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PFtdJm7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XWEfWOi3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SurSiVhJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PFtdJm7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SPknZy8E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0MS7MIoB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jKHuVKI2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4cBTQRhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0MS7MIoB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jKHuVKI2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uqX14ATE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0MaKMnmY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Sg1ombt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kAvMkref_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0MaKMnmY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Sg1ombt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Liggq43a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_XWEfWOi3_sendMessage(_c, 0, m);
  cMsg_4cBTQRhW_sendMessage(_c, 0, m);
  cMsg_kAvMkref_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bBSq1H38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_XWEfWOi3_sendMessage(_c, 0, m);
  cMsg_SPknZy8E_sendMessage(_c, 0, m);
  cMsg_uqX14ATE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zYcu5wnQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_iMm1K3VN_sendMessage(_c, 0, m);
  cMsg_SPknZy8E_sendMessage(_c, 0, m);
  cMsg_kAvMkref_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nhQB4tyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_uaE4BUFk_sendMessage(_c, 0, m);
  cMsg_JxBvX7JY_sendMessage(_c, 0, m);
  cMsg_N7MK2SQi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zEcRVMaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_iMm1K3VN_sendMessage(_c, 0, m);
  cMsg_4cBTQRhW_sendMessage(_c, 0, m);
  cMsg_uqX14ATE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1NWRpcQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HIezQ33p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_eBC8TEh3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_kFW6LQLc, 0, m, &cSlice_kFW6LQLc_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g45WMCep_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_kFW6LQLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_5qGy9l7W_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_5qGy9l7W_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yzhsnxr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_5qGy9l7W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_5qGy9l7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VSJBwof0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6i1WTZ2P_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_L6p1ucos, 0, m, &cSlice_L6p1ucos_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ut5qFn1I_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_L6p1ucos_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Pdoum6Sj_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Pdoum6Sj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_I0wGVO4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Pdoum6Sj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Pdoum6Sj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AAejjQgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ut5qFn1I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YiHGyg1Y, 0, m, &cSlice_YiHGyg1Y_sendMessage);
      break;
    }
    default: {
      cSwitchcase_eBC8TEh3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YiHGyg1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_IDmq97fB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_IDmq97fB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_x4gtU1xv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_IDmq97fB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_IDmq97fB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_BEZZKpmg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_g45WMCep_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Mh0thIAL, 0, m, &cSlice_Mh0thIAL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PNp8qZwP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Mh0thIAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aaEu9KyM_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aaEu9KyM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WZkWRE5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aaEu9KyM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aaEu9KyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_GoQSXUaH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PNp8qZwP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IoBqvO5r, 0, m, &cSlice_IoBqvO5r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_m0QOBlH7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_IoBqvO5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hNOrrRwI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hNOrrRwI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_kBbkJEa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hNOrrRwI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hNOrrRwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9Gnu0cJ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TxhD24ZB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lrNvjDMi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lrNvjDMi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fRmO0YoL, 1, m, &cDelay_fRmO0YoL_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9AHJZYXb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fRmO0YoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fRmO0YoL, m);
  cMsg_34MeWh0R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lrNvjDMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fRmO0YoL, 0, m, &cDelay_fRmO0YoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9AHJZYXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fRmO0YoL, 0, m, &cDelay_fRmO0YoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FG5RXmCw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWhpUlpB, HV_BINOP_SUBTRACT, 0, m, &cBinop_cWhpUlpB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_V8nGcuTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OwY4WmIo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3kxrrLyN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OwY4WmIo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_erGK5Qki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FG5RXmCw, 0, m, &cVar_FG5RXmCw_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_7ILklKDO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ADf8ATUJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MgFSrYnO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xa0AG7Oa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cWhpUlpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fhk8gGYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Fhk8gGYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_fREmdNEe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fREmdNEe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Ewr9F2MA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NaK3G62I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ugmVTb1B_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0GQQDY4B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0GQQDY4B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QF6402mW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ugmVTb1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_V8nGcuTn, 1, m, &cIf_V8nGcuTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TXssnfiF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3kxrrLyN, 1, m, &cIf_3kxrrLyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QF6402mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_V8nGcuTn, 0, m, &cIf_V8nGcuTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ewr9F2MA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3kxrrLyN, 0, m, &cIf_3kxrrLyN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ADf8ATUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_xa0AG7Oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FG5RXmCw, 0, m, &cVar_FG5RXmCw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MgFSrYnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cWhpUlpB, HV_BINOP_SUBTRACT, 1, m, &cBinop_cWhpUlpB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OwY4WmIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gfm3mWj8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m0QOBlH7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_H7IjoDsz, 0, m, &cSlice_H7IjoDsz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_H7IjoDsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rPGc3VGe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rPGc3VGe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_PQV3UZge_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rPGc3VGe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rPGc3VGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UpoWkETq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wP3CqRN1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dNucvAGq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_wuWaZhn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Lezhu0b1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_sVjRXECF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_INwKtGV9, 0, m, &cVar_INwKtGV9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HIezQ33p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UGLpcDgt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Cl5K8Oh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_TxhD24ZB_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_D8WEBMQf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_US7pmqX8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_34MeWh0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_92HnC1Vy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_US7pmqX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_92HnC1Vy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SxFFhPP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_pdWRCVGZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pdWRCVGZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1nk4wZwY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1nk4wZwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PWnysAH7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_8trWV5Be_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XirIbTfe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_AKUGMb8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pwuW1vq0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8QjcTkCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NX9GyhCM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_MLugZl8h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u3WKWto3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bHBLs69x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5JThlayv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_9geuDKnv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ui6KNDYo_sendMessage);
  cMsg_dRgodUTn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ui6KNDYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9geuDKnv, 1, m, &cVar_9geuDKnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2fQ6u9ZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NHh2s4Jo_sendMessage(_c, 0, m);
  cMsg_DLz1DNEs_sendMessage(_c, 0, m);
  cMsg_NWvKLewm_sendMessage(_c, 0, m);
  cMsg_FiTv4jMA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_r5sFwmWy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fEDoNUSj, 0, m, &cSlice_fEDoNUSj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fEDoNUSj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pVu1Q6yo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pVu1Q6yo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Hoy6B2JM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pVu1Q6yo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pVu1Q6yo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eH6F7lT7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8cfHnNAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_To9fjAwH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_To9fjAwH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_pnHV3aLm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pnHV3aLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_XmjeaC38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XmjeaC38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3I1fWKfx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n7tqkdN2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n7tqkdN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XYksvsRk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_3I1fWKfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_JkdE1nx6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JkdE1nx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_argv4A5M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XYksvsRk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bsCXquGI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bsCXquGI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_QDvTKEb5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_argv4A5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Fiu8APYA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_QDvTKEb5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ibZEBNcB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Fiu8APYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHFDXA5G, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ibZEBNcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_3xmGkRcs, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_LTh5dVCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iFAQNvvw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ueAyOBYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NbVOJNu4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_g7MV9OUy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KygpFzgn_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4n4D81qC_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f7gmAJwj_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZrzYVqub_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_d7nPFCRA_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_P1EhnCCt_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_KygpFzgn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tFxmFKL8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4n4D81qC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xxhJJgql_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_f7gmAJwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nSNND35Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZrzYVqub_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OmUsffn8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_d7nPFCRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LtiUx0a6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_P1EhnCCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EMioh4jb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_FTt80AdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qpdmrQpQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wfoHo3hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gOstGaAb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1NLcSd9Y_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_UkNQ2qLr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_UkNQ2qLr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_i2HmqcaH, 1, m, &cDelay_i2HmqcaH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6PnstuaB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_i2HmqcaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_i2HmqcaH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FTt80AdF, 0, m, &cIf_FTt80AdF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UkNQ2qLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_i2HmqcaH, 0, m, &cDelay_i2HmqcaH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6PnstuaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_i2HmqcaH, 0, m, &cDelay_i2HmqcaH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C0XnQMPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E4u5lWAQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4d1arAHe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XImlWtvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oRMlsCfj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YMQcA0Sh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YMQcA0Sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1NLcSd9Y_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oRMlsCfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FTt80AdF, 1, m, &cIf_FTt80AdF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E4u5lWAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wfoHo3hD, 1, m, &cIf_wfoHo3hD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4d1arAHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wfoHo3hD, 0, m, &cIf_wfoHo3hD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gOstGaAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHjPO0HH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qpdmrQpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHjPO0HH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aCDHeEQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_70k7Prxu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RHU5zGfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_x7aQpotQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_poytnYks_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yYNmTol7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yYNmTol7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cBRFgD2Q, 1, m, &cDelay_cBRFgD2Q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jSms97UC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cBRFgD2Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cBRFgD2Q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aCDHeEQ4, 0, m, &cIf_aCDHeEQ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yYNmTol7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cBRFgD2Q, 0, m, &cDelay_cBRFgD2Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jSms97UC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cBRFgD2Q, 0, m, &cDelay_cBRFgD2Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZkOHVYXu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8ov3a4Sd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k6r5NscR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pqhsK8eV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rkm0MMgK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VzWbmtNM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rkm0MMgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCDHeEQ4, 1, m, &cIf_aCDHeEQ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VzWbmtNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_poytnYks_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_k6r5NscR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RHU5zGfx, 0, m, &cIf_RHU5zGfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8ov3a4Sd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RHU5zGfx, 1, m, &cIf_RHU5zGfx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x7aQpotQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Oc8aIfMv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_70k7Prxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Oc8aIfMv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6UB0NIGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_X7R2d9Ex_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QaoPNXuI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lGqa1LZ3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oiXrZVTk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OJTbiuYS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OJTbiuYS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b95Gjwvi, 1, m, &cDelay_b95Gjwvi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SfWvaLVo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_b95Gjwvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b95Gjwvi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6UB0NIGL, 0, m, &cIf_6UB0NIGL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OJTbiuYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b95Gjwvi, 0, m, &cDelay_b95Gjwvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SfWvaLVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b95Gjwvi, 0, m, &cDelay_b95Gjwvi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Sl7k2hVz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_69ptiudd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eSKuiSKX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B6GnGRKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FMcha8tt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N3d93q7q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N3d93q7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oiXrZVTk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FMcha8tt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6UB0NIGL, 1, m, &cIf_6UB0NIGL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_69ptiudd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaoPNXuI, 1, m, &cIf_QaoPNXuI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eSKuiSKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QaoPNXuI, 0, m, &cIf_QaoPNXuI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lGqa1LZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IN6LGc5O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_X7R2d9Ex_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IN6LGc5O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_dKUnFiSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1G4Cg9w3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_UPs1E6iz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_cXofUV5M_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UPqN1oKD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZYA5PWw1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZYA5PWw1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jpbUKDa7, 1, m, &cDelay_jpbUKDa7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZQjclBZL_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jpbUKDa7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jpbUKDa7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_dKUnFiSx, 0, m, &cIf_dKUnFiSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZYA5PWw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jpbUKDa7, 0, m, &cDelay_jpbUKDa7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZQjclBZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jpbUKDa7, 0, m, &cDelay_jpbUKDa7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2YpK7zk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qXiRX1Ep_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_55VLzJa0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9YxlmbiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YPLtEUHF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JgB5d0y8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YPLtEUHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dKUnFiSx, 1, m, &cIf_dKUnFiSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JgB5d0y8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UPqN1oKD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_55VLzJa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UPs1E6iz, 0, m, &cIf_UPs1E6iz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qXiRX1Ep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UPs1E6iz, 1, m, &cIf_UPs1E6iz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cXofUV5M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4NevKAYw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1G4Cg9w3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4NevKAYw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_prvkHJBT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AlsJ7jk7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_P41nkP8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jscamHtW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_N212aKae_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oBUiFK2u_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oBUiFK2u_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rope0W4d, 1, m, &cDelay_rope0W4d_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DguESdVh_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rope0W4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rope0W4d, m);
  cIf_onMessage(_c, &Context(_c)->cIf_prvkHJBT, 0, m, &cIf_prvkHJBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oBUiFK2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rope0W4d, 0, m, &cDelay_rope0W4d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DguESdVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rope0W4d, 0, m, &cDelay_rope0W4d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_laMQz1b4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_52Wjk8vz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Zb4i7lhU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eXVWVhRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wKVZpY3l_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IVPLi1JZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IVPLi1JZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_N212aKae_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_wKVZpY3l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_prvkHJBT, 1, m, &cIf_prvkHJBT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_52Wjk8vz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P41nkP8m, 1, m, &cIf_P41nkP8m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Zb4i7lhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_P41nkP8m, 0, m, &cIf_P41nkP8m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jscamHtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cebGtGv0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AlsJ7jk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cebGtGv0, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Jk2z5xha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bDmdSqvK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_yHz6yS3T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g9BYB66y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kpHVYuAy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8mpRLU9T_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8mpRLU9T_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Whr32zxF, 1, m, &cDelay_Whr32zxF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_exRCLpJ1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Whr32zxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Whr32zxF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Jk2z5xha, 0, m, &cIf_Jk2z5xha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8mpRLU9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Whr32zxF, 0, m, &cDelay_Whr32zxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_exRCLpJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Whr32zxF, 0, m, &cDelay_Whr32zxF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bLKQxw7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lTB7Twne_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jH3Ws4Ja_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EAkBebuh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uG6JgB54_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X16iRBJw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_X16iRBJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kpHVYuAy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uG6JgB54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jk2z5xha, 1, m, &cIf_Jk2z5xha_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jH3Ws4Ja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yHz6yS3T, 0, m, &cIf_yHz6yS3T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lTB7Twne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_yHz6yS3T, 1, m, &cIf_yHz6yS3T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g9BYB66y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f1H87OMH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bDmdSqvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f1H87OMH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_okQUsXUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aXnSsMlt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_b5WZ7bow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oJWvB27x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fNGyup4T_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rxgJQsNZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rxgJQsNZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pTluTa7t, 1, m, &cDelay_pTluTa7t_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nkuqnPAM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pTluTa7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pTluTa7t, m);
  cIf_onMessage(_c, &Context(_c)->cIf_okQUsXUD, 0, m, &cIf_okQUsXUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rxgJQsNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pTluTa7t, 0, m, &cDelay_pTluTa7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nkuqnPAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pTluTa7t, 0, m, &cDelay_pTluTa7t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DYHALUaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rjLFxpr3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZiER2Lob_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LGQLce97_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WkxUy5o6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4eKouPsR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4eKouPsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fNGyup4T_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WkxUy5o6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_okQUsXUD, 1, m, &cIf_okQUsXUD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZiER2Lob_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b5WZ7bow, 0, m, &cIf_b5WZ7bow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rjLFxpr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b5WZ7bow, 1, m, &cIf_b5WZ7bow_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oJWvB27x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qgWseyf9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aXnSsMlt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qgWseyf9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2uwd28ww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dBD34NH7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_8Jtnoyaz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xp3jD8wv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9UZ1vq7j_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bUyFiLs7_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bUyFiLs7_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PR544wjn, 1, m, &cDelay_PR544wjn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FGU8e5C4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_PR544wjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PR544wjn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2uwd28ww, 0, m, &cIf_2uwd28ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bUyFiLs7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PR544wjn, 0, m, &cDelay_PR544wjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FGU8e5C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PR544wjn, 0, m, &cDelay_PR544wjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_h9Vbm9PT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_r3TPq9yJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CURi0lea_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t5eC4I3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mTy461Fm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bJ1S4P8w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mTy461Fm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2uwd28ww, 1, m, &cIf_2uwd28ww_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bJ1S4P8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9UZ1vq7j_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CURi0lea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Jtnoyaz, 0, m, &cIf_8Jtnoyaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r3TPq9yJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Jtnoyaz, 1, m, &cIf_8Jtnoyaz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xp3jD8wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PAbkkNZ5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dBD34NH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PAbkkNZ5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_R1GVz8Oj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p7aaRFYv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pdHzwBkS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uEbJTuhQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vojjd3XH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oltLGPVO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oltLGPVO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uo7ynn3L, 1, m, &cDelay_uo7ynn3L_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UNBfMR4f_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uo7ynn3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uo7ynn3L, m);
  cIf_onMessage(_c, &Context(_c)->cIf_R1GVz8Oj, 0, m, &cIf_R1GVz8Oj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oltLGPVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uo7ynn3L, 0, m, &cDelay_uo7ynn3L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UNBfMR4f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uo7ynn3L, 0, m, &cDelay_uo7ynn3L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oa3Ut44r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y1Lka4wD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KUMKJvRM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kcCXdd8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6kJrGkK5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Finw0cTz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Finw0cTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vojjd3XH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6kJrGkK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R1GVz8Oj, 1, m, &cIf_R1GVz8Oj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y1Lka4wD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pdHzwBkS, 1, m, &cIf_pdHzwBkS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KUMKJvRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pdHzwBkS, 0, m, &cIf_pdHzwBkS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uEbJTuhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cS8NfZw1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_p7aaRFYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cS8NfZw1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ed9RT6pX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xOwjXcSH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_hY3FnE4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BQBce6aD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_R9Tu0HCO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N1uJLGL1_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N1uJLGL1_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oTXKH104, 1, m, &cDelay_oTXKH104_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nUE2TWo8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oTXKH104_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oTXKH104, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ed9RT6pX, 0, m, &cIf_Ed9RT6pX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N1uJLGL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oTXKH104, 0, m, &cDelay_oTXKH104_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nUE2TWo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oTXKH104, 0, m, &cDelay_oTXKH104_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_owrmzyHn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eEWoNyoK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tsjLKJlk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E3NUtonY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pPjhDSR8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hBkIgEiG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pPjhDSR8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ed9RT6pX, 1, m, &cIf_Ed9RT6pX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hBkIgEiG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R9Tu0HCO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_eEWoNyoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hY3FnE4l, 1, m, &cIf_hY3FnE4l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tsjLKJlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hY3FnE4l, 0, m, &cIf_hY3FnE4l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BQBce6aD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ajge1EVh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xOwjXcSH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ajge1EVh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_EU2v8Q9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Y1iY9a7X_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ge5NXkKF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VJGqu9Y3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nwQL0Rsg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hkLcxiw2_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hkLcxiw2_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_riZjIgRA, 1, m, &cDelay_riZjIgRA_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_avNKowrt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_riZjIgRA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_riZjIgRA, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EU2v8Q9N, 0, m, &cIf_EU2v8Q9N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hkLcxiw2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_riZjIgRA, 0, m, &cDelay_riZjIgRA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_avNKowrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_riZjIgRA, 0, m, &cDelay_riZjIgRA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_P0suTL3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LItQyLG1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iVWXaeYu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MxsUQP2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SOs0yIUo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1dMBuDty_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SOs0yIUo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EU2v8Q9N, 1, m, &cIf_EU2v8Q9N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1dMBuDty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nwQL0Rsg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_iVWXaeYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ge5NXkKF, 0, m, &cIf_ge5NXkKF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LItQyLG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ge5NXkKF, 1, m, &cIf_ge5NXkKF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VJGqu9Y3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSRmXzF8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Y1iY9a7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xSRmXzF8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_1WHHJINk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DUnW6KAB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BLyDNZnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DIxEjAPC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IYyWd5iS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_h3ZXRzrY_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_h3ZXRzrY_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IiUPsKKi, 1, m, &cDelay_IiUPsKKi_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dPEpyfjb_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IiUPsKKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IiUPsKKi, m);
  cIf_onMessage(_c, &Context(_c)->cIf_1WHHJINk, 0, m, &cIf_1WHHJINk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h3ZXRzrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IiUPsKKi, 0, m, &cDelay_IiUPsKKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dPEpyfjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IiUPsKKi, 0, m, &cDelay_IiUPsKKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0U8eVmXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_d28LkYAi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cQMbH5Of_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Qf9fOJQA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K85b13EF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2e98piHN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K85b13EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1WHHJINk, 1, m, &cIf_1WHHJINk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2e98piHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_IYyWd5iS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_d28LkYAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BLyDNZnY, 1, m, &cIf_BLyDNZnY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cQMbH5Of_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BLyDNZnY, 0, m, &cIf_BLyDNZnY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DIxEjAPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8CLskRsg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DUnW6KAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8CLskRsg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tFxmFKL8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_3jymyZDI_sendMessage(_c, 0, m);
  cMsg_9wIZeqWB_sendMessage(_c, 0, m);
  cMsg_ZNMuOsyF_sendMessage(_c, 0, m);
  cMsg_Rpcnw5d9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xxhJJgql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_3jymyZDI_sendMessage(_c, 0, m);
  cMsg_NQt3yqiK_sendMessage(_c, 0, m);
  cMsg_NZRN1tx6_sendMessage(_c, 0, m);
  cMsg_LnXRXER9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nSNND35Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_QYpqBSsG_sendMessage(_c, 0, m);
  cMsg_NQt3yqiK_sendMessage(_c, 0, m);
  cMsg_Rpcnw5d9_sendMessage(_c, 0, m);
  cMsg_ycYD3res_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OmUsffn8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_QYpqBSsG_sendMessage(_c, 0, m);
  cMsg_juUdndfK_sendMessage(_c, 0, m);
  cMsg_ZNMuOsyF_sendMessage(_c, 0, m);
  cMsg_uc6Pawtc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LtiUx0a6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_JOXZNnYA_sendMessage(_c, 0, m);
  cMsg_LnXRXER9_sendMessage(_c, 0, m);
  cMsg_2cOYkESD_sendMessage(_c, 0, m);
  cMsg_ZNMuOsyF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EMioh4jb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_JOXZNnYA_sendMessage(_c, 0, m);
  cMsg_uc6Pawtc_sendMessage(_c, 0, m);
  cMsg_NQt3yqiK_sendMessage(_c, 0, m);
  cMsg_p05pECyn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_a2cF7e10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XImlWtvK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C0XnQMPg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_40RTNBUw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_XImlWtvK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_C0XnQMPg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j2S2iwyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pqhsK8eV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZkOHVYXu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DYSmlH0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pqhsK8eV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ZkOHVYXu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ccFTa0Zf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B6GnGRKN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Sl7k2hVz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uQh2Pka1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_B6GnGRKN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Sl7k2hVz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3jymyZDI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_a2cF7e10_sendMessage(_c, 0, m);
  cMsg_DYSmlH0H_sendMessage(_c, 0, m);
  cMsg_uQh2Pka1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QYpqBSsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_40RTNBUw_sendMessage(_c, 0, m);
  cMsg_j2S2iwyx_sendMessage(_c, 0, m);
  cMsg_uQh2Pka1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JOXZNnYA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_40RTNBUw_sendMessage(_c, 0, m);
  cMsg_DYSmlH0H_sendMessage(_c, 0, m);
  cMsg_ccFTa0Zf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lTQspDO4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9YxlmbiO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2YpK7zk5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n3HlSgJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9YxlmbiO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2YpK7zk5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Jmslt7cA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eXVWVhRg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_laMQz1b4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HME95ZEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_eXVWVhRg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_laMQz1b4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xILPpO1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EAkBebuh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bLKQxw7K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vzal2RF7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_EAkBebuh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bLKQxw7K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NQt3yqiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_n3HlSgJt_sendMessage(_c, 0, m);
  cMsg_HME95ZEk_sendMessage(_c, 0, m);
  cMsg_vzal2RF7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9wIZeqWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_n3HlSgJt_sendMessage(_c, 0, m);
  cMsg_Jmslt7cA_sendMessage(_c, 0, m);
  cMsg_xILPpO1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_juUdndfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_lTQspDO4_sendMessage(_c, 0, m);
  cMsg_HME95ZEk_sendMessage(_c, 0, m);
  cMsg_xILPpO1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ar1dMQCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E3NUtonY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_owrmzyHn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cyxyJbAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E3NUtonY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_owrmzyHn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qsRcBQ27_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MxsUQP2j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P0suTL3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LFzk8ziy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MxsUQP2j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_P0suTL3a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WEez05b8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qf9fOJQA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0U8eVmXB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_59fRzy5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Qf9fOJQA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_0U8eVmXB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uc6Pawtc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_ar1dMQCu_sendMessage(_c, 0, m);
  cMsg_LFzk8ziy_sendMessage(_c, 0, m);
  cMsg_59fRzy5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LnXRXER9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_cyxyJbAF_sendMessage(_c, 0, m);
  cMsg_qsRcBQ27_sendMessage(_c, 0, m);
  cMsg_59fRzy5b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Rpcnw5d9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_cyxyJbAF_sendMessage(_c, 0, m);
  cMsg_LFzk8ziy_sendMessage(_c, 0, m);
  cMsg_WEez05b8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uS1yNVdD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LGQLce97_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DYHALUaX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_emqaPDRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_LGQLce97_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DYHALUaX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5CQNFoPA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t5eC4I3L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_h9Vbm9PT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_38Ek7vAC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_t5eC4I3L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_h9Vbm9PT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JbGn9LrD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kcCXdd8c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oa3Ut44r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2stxMoDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kcCXdd8c_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oa3Ut44r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZNMuOsyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_emqaPDRD_sendMessage(_c, 0, m);
  cMsg_38Ek7vAC_sendMessage(_c, 0, m);
  cMsg_2stxMoDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NZRN1tx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_emqaPDRD_sendMessage(_c, 0, m);
  cMsg_5CQNFoPA_sendMessage(_c, 0, m);
  cMsg_JbGn9LrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p05pECyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_uS1yNVdD_sendMessage(_c, 0, m);
  cMsg_5CQNFoPA_sendMessage(_c, 0, m);
  cMsg_2stxMoDj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2cOYkESD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_lTQspDO4_sendMessage(_c, 0, m);
  cMsg_Jmslt7cA_sendMessage(_c, 0, m);
  cMsg_vzal2RF7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ycYD3res_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_uS1yNVdD_sendMessage(_c, 0, m);
  cMsg_38Ek7vAC_sendMessage(_c, 0, m);
  cMsg_JbGn9LrD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_1971RmlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r1SXXC8A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mMSTqJeC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_h6aFU9N6, 0, m, &cSlice_h6aFU9N6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_G8YLWrBq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_h6aFU9N6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_pmMAS39I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_pmMAS39I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_hcm46hWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pmMAS39I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pmMAS39I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KZgk1hX0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z9WLXEF8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_fVwcyA2Z, 0, m, &cSlice_fVwcyA2Z_sendMessage);
      break;
    }
    default: {
      cSwitchcase_l7PyJm4d_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_fVwcyA2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zc5itQpp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zc5itQpp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_jJ7jhHrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zc5itQpp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Zc5itQpp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_suRHW43E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_l7PyJm4d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_icIl4YIa, 0, m, &cSlice_icIl4YIa_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mMSTqJeC_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_icIl4YIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Z4Mm0hNA_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Z4Mm0hNA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_tqZVNR8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Z4Mm0hNA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Z4Mm0hNA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uy5RmBRx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_G8YLWrBq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Vxbw8KLz, 0, m, &cSlice_Vxbw8KLz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_48VAhzAe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Vxbw8KLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SHyO2pAW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SHyO2pAW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_mpJkPYs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SHyO2pAW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SHyO2pAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yNRczHMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_48VAhzAe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_tWBZtZgz, 0, m, &cSlice_tWBZtZgz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_e7igzmUp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_tWBZtZgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7y7gS0UW_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7y7gS0UW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_GTBB6NiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7y7gS0UW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7y7gS0UW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_aCJAnbdz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Z5disDHA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kUtQt5B8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kUtQt5B8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jrSCE2ga, 1, m, &cDelay_jrSCE2ga_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3JmtW3pM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jrSCE2ga_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jrSCE2ga, m);
  cMsg_cGLVdqcv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kUtQt5B8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jrSCE2ga, 0, m, &cDelay_jrSCE2ga_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3JmtW3pM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jrSCE2ga, 0, m, &cDelay_jrSCE2ga_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4cyjsivu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w8LOIpHV, HV_BINOP_SUBTRACT, 0, m, &cBinop_w8LOIpHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_HodXXODV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_puGDXfdp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_rxdCsvpT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_puGDXfdp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_jHkLDs2A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4cyjsivu, 0, m, &cVar_4cyjsivu_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_M1ztaHkP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2x5dytcW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aN1MCLlg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ieCnTA92_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w8LOIpHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YLDNtdd4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YLDNtdd4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_f7RYjaOc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f7RYjaOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SIhIssgN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k2He1sMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S3HpKAdF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Owf4bRz5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_S3HpKAdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HodXXODV, 1, m, &cIf_HodXXODV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Owf4bRz5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3NVr2l6N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4t30uJ7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rxdCsvpT, 1, m, &cIf_rxdCsvpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3NVr2l6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HodXXODV, 0, m, &cIf_HodXXODV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SIhIssgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rxdCsvpT, 0, m, &cIf_rxdCsvpT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aN1MCLlg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_w8LOIpHV, HV_BINOP_SUBTRACT, 1, m, &cBinop_w8LOIpHV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ieCnTA92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4cyjsivu, 0, m, &cVar_4cyjsivu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2x5dytcW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cMsg_puGDXfdp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cs1Tkt1O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e7igzmUp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5azkhrQl, 0, m, &cSlice_5azkhrQl_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5azkhrQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_mfGfUIE8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_mfGfUIE8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_IzOwrsre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mfGfUIE8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_mfGfUIE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kiR8H1iF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iFAQNvvw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UY8DMc2t, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NbVOJNu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BVRin6cN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_wos4fw5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ueAyOBYN, 0, m, &cVar_ueAyOBYN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r1SXXC8A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V8ZGuZjh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NZI0vmke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Z5disDHA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3O4SByHV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bz2Thozr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cGLVdqcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nayA95MO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_bz2Thozr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nayA95MO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_o1c9EmSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Fjgu3JEh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fjgu3JEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_viN4K5nm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_viN4K5nm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YCcuSv6S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_GqqfnJHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iN8hCjFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ODxMZeIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2IY2Q0MI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DlhQVYex_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BuvsP7sW_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4He4ewry_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mgva85E1_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8xfRcQ6k_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h85OgXHT_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zOUtLatu_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_BuvsP7sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mpaAAeUA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_4He4ewry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QBvl9SIH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Mgva85E1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CsjaPIJr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8xfRcQ6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XrKG9qmF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_h85OgXHT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ymhYRhlI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zOUtLatu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AMSRo58L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_vctzvvm2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_pPUUTasN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HbpBtOuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gd6et0eI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PFLaOVrm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_u1ydAVAH_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_u1ydAVAH_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mfuksUY9, 1, m, &cDelay_mfuksUY9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OunC6l1K_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mfuksUY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mfuksUY9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vctzvvm2, 0, m, &cIf_vctzvvm2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_u1ydAVAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mfuksUY9, 0, m, &cDelay_mfuksUY9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OunC6l1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mfuksUY9, 0, m, &cDelay_mfuksUY9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lMuNl3JP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9qcoOoxj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v8vwcrVX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0YnL0cxY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aU34mq3d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VW0EjVRb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VW0EjVRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PFLaOVrm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_aU34mq3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vctzvvm2, 1, m, &cIf_vctzvvm2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9qcoOoxj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HbpBtOuX, 1, m, &cIf_HbpBtOuX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v8vwcrVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HbpBtOuX, 0, m, &cIf_HbpBtOuX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gd6et0eI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lj11PxgX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pPUUTasN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lj11PxgX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZLtEqhWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5DBdPqgT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2cuMDk9h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_48Tyg8cO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2LatABER_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2UCPkpbD_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2UCPkpbD_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_z7QWSAwp, 1, m, &cDelay_z7QWSAwp_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H7MZsOrM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_z7QWSAwp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_z7QWSAwp, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZLtEqhWY, 0, m, &cIf_ZLtEqhWY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2UCPkpbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_z7QWSAwp, 0, m, &cDelay_z7QWSAwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H7MZsOrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_z7QWSAwp, 0, m, &cDelay_z7QWSAwp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uVZBMS50_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WX8g7uEX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W83ZQO55_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aSteM7a8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TXM2PWS5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iWT1C7oW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TXM2PWS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZLtEqhWY, 1, m, &cIf_ZLtEqhWY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iWT1C7oW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2LatABER_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WX8g7uEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2cuMDk9h, 1, m, &cIf_2cuMDk9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_W83ZQO55_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2cuMDk9h, 0, m, &cIf_2cuMDk9h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_48Tyg8cO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nt5YWIPu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5DBdPqgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nt5YWIPu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AqVTslyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9fsNSgJx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nLWqbYlj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O5ZM9ZeG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u136hSYW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3xdJQSbP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3xdJQSbP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_040kHwGK, 1, m, &cDelay_040kHwGK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qshfjPs6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_040kHwGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_040kHwGK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AqVTslyn, 0, m, &cIf_AqVTslyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3xdJQSbP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_040kHwGK, 0, m, &cDelay_040kHwGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qshfjPs6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_040kHwGK, 0, m, &cDelay_040kHwGK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c5yJSgJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EuXFYr8m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2Qw412n5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N4DInFCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y0zSCeLW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VvtZM9Pg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VvtZM9Pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u136hSYW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_y0zSCeLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AqVTslyn, 1, m, &cIf_AqVTslyn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EuXFYr8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nLWqbYlj, 1, m, &cIf_nLWqbYlj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2Qw412n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nLWqbYlj, 0, m, &cIf_nLWqbYlj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O5ZM9ZeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5TgBz0pp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9fsNSgJx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5TgBz0pp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FMFVPc4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HNpLQyhn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CuK4oRWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SH0M7vYP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zYrndFSq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_arL9akrt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_arL9akrt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_C85TNyry, 1, m, &cDelay_C85TNyry_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PGuwUDSN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_C85TNyry_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C85TNyry, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FMFVPc4Q, 0, m, &cIf_FMFVPc4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_arL9akrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C85TNyry, 0, m, &cDelay_C85TNyry_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PGuwUDSN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C85TNyry, 0, m, &cDelay_C85TNyry_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DiQptB8C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A3qOH4xM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_liWwMYke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kHuJWH7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PIooWzWc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xy9aOtdt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PIooWzWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FMFVPc4Q, 1, m, &cIf_FMFVPc4Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xy9aOtdt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zYrndFSq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_liWwMYke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CuK4oRWV, 0, m, &cIf_CuK4oRWV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A3qOH4xM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CuK4oRWV, 1, m, &cIf_CuK4oRWV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SH0M7vYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hWSIOwf6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HNpLQyhn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hWSIOwf6, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_kmRHFZ8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rbJgv86H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QTrNik2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rJOPUJPG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_uuC5UcHs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_n3jquTYZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_n3jquTYZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_c66xZ3hv, 1, m, &cDelay_c66xZ3hv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F6sBZ09y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_c66xZ3hv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_c66xZ3hv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_kmRHFZ8B, 0, m, &cIf_kmRHFZ8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n3jquTYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_c66xZ3hv, 0, m, &cDelay_c66xZ3hv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F6sBZ09y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_c66xZ3hv, 0, m, &cDelay_c66xZ3hv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NSGBSFRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GdEpPIxE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WII9JHYm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9Y6gr6du_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TehRvtA0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XGHzljJO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TehRvtA0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kmRHFZ8B, 1, m, &cIf_kmRHFZ8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XGHzljJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_uuC5UcHs_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WII9JHYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QTrNik2j, 0, m, &cIf_QTrNik2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GdEpPIxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QTrNik2j, 1, m, &cIf_QTrNik2j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rJOPUJPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fs1yZxSE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rbJgv86H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Fs1yZxSE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ApZvOYn5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7eJLlZOW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Na1r44Gs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_h9Yfho5y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NA3PEQKI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oTj8XYZr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oTj8XYZr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jMBBAiiZ, 1, m, &cDelay_jMBBAiiZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v8Wabax6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jMBBAiiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jMBBAiiZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ApZvOYn5, 0, m, &cIf_ApZvOYn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oTj8XYZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMBBAiiZ, 0, m, &cDelay_jMBBAiiZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v8Wabax6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jMBBAiiZ, 0, m, &cDelay_jMBBAiiZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4vKbawmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_U9RQFlzr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dTpHNZ9D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MBrpnPE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WgB0YJQj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wR7YHKRb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wR7YHKRb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NA3PEQKI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WgB0YJQj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ApZvOYn5, 1, m, &cIf_ApZvOYn5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dTpHNZ9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Na1r44Gs, 0, m, &cIf_Na1r44Gs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U9RQFlzr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Na1r44Gs, 1, m, &cIf_Na1r44Gs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h9Yfho5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SGgnbdf8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7eJLlZOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SGgnbdf8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_gKXqp8up_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FLXRQIG6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_g7STWyg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_s9Y3up5e_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7FmFxP5g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ix2g7kIo_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ix2g7kIo_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6Kn0Q47B, 1, m, &cDelay_6Kn0Q47B_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5UzcqY1y_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6Kn0Q47B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6Kn0Q47B, m);
  cIf_onMessage(_c, &Context(_c)->cIf_gKXqp8up, 0, m, &cIf_gKXqp8up_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ix2g7kIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Kn0Q47B, 0, m, &cDelay_6Kn0Q47B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5UzcqY1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6Kn0Q47B, 0, m, &cDelay_6Kn0Q47B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lNRAOTWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cdU5SlkU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mt7wKvCV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tF5iHz7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cMppnnH6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gVbuG32d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gVbuG32d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_7FmFxP5g_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cMppnnH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gKXqp8up, 1, m, &cIf_gKXqp8up_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cdU5SlkU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g7STWyg7, 1, m, &cIf_g7STWyg7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mt7wKvCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g7STWyg7, 0, m, &cIf_g7STWyg7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s9Y3up5e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wzTPAB9p, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FLXRQIG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wzTPAB9p, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sn7iPe2T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ch4a2rZi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_khtDOyGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FMLeXrzX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BT8HeeZd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Smr55h4a_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Smr55h4a_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Z2yeIwo5, 1, m, &cDelay_Z2yeIwo5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v5tooJ15_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Z2yeIwo5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Z2yeIwo5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sn7iPe2T, 0, m, &cIf_sn7iPe2T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Smr55h4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z2yeIwo5, 0, m, &cDelay_Z2yeIwo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v5tooJ15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Z2yeIwo5, 0, m, &cDelay_Z2yeIwo5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XJvlJeb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VrczzoAR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sJwjHiqK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_E5STJiy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YkHPyg8d_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GI4p5AGT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GI4p5AGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BT8HeeZd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YkHPyg8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sn7iPe2T, 1, m, &cIf_sn7iPe2T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sJwjHiqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_khtDOyGF, 0, m, &cIf_khtDOyGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VrczzoAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_khtDOyGF, 1, m, &cIf_khtDOyGF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FMLeXrzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0sqKPS0W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ch4a2rZi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0sqKPS0W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fKwHHaGV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_S26AGFwL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_HgEyxOvS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8hNB52TY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DB9oONwz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_B2UtBpE8_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_B2UtBpE8_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Kw4lcnYv, 1, m, &cDelay_Kw4lcnYv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jKnPDin4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Kw4lcnYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Kw4lcnYv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fKwHHaGV, 0, m, &cIf_fKwHHaGV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_B2UtBpE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kw4lcnYv, 0, m, &cDelay_Kw4lcnYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jKnPDin4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kw4lcnYv, 0, m, &cDelay_Kw4lcnYv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2gpQguMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_w5wsO9Um_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yBV6rXxG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V3k7lqgw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HfSurF8P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u0nhGW9z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HfSurF8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKwHHaGV, 1, m, &cIf_fKwHHaGV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u0nhGW9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DB9oONwz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_w5wsO9Um_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HgEyxOvS, 1, m, &cIf_HgEyxOvS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yBV6rXxG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HgEyxOvS, 0, m, &cIf_HgEyxOvS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8hNB52TY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9tt20iza, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_S26AGFwL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9tt20iza, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CHRgQhVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7gXhqoM8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_A9DdOgSv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_e0wRrrJW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5T17sWyW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gH91qDL3_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gH91qDL3_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_AhzPuMQs, 1, m, &cDelay_AhzPuMQs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GOMGnbkZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_AhzPuMQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_AhzPuMQs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CHRgQhVC, 0, m, &cIf_CHRgQhVC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gH91qDL3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_AhzPuMQs, 0, m, &cDelay_AhzPuMQs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GOMGnbkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_AhzPuMQs, 0, m, &cDelay_AhzPuMQs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WHOkvyY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wWys6pib_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mEFbjv1D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7inE8AUd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NKEyHDCF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Me7mSmG6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Me7mSmG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5T17sWyW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NKEyHDCF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CHRgQhVC, 1, m, &cIf_CHRgQhVC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mEFbjv1D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A9DdOgSv, 0, m, &cIf_A9DdOgSv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wWys6pib_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A9DdOgSv, 1, m, &cIf_A9DdOgSv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e0wRrrJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_atYrB240, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7gXhqoM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_atYrB240, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_rZtSS3Hk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3OfrP4D0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LeQ1gvtW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_GWzqkGqG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_epY7RrcC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_EIa43cDg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_EIa43cDg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_l4wEVtPZ, 1, m, &cDelay_l4wEVtPZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aCvcrJtl_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_l4wEVtPZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_l4wEVtPZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_rZtSS3Hk, 0, m, &cIf_rZtSS3Hk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EIa43cDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_l4wEVtPZ, 0, m, &cDelay_l4wEVtPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aCvcrJtl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_l4wEVtPZ, 0, m, &cDelay_l4wEVtPZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UN3xBrU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pv6uhXzy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8X8YTAev_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FoBwwbBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1w06TUU3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_En9k7lz8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1w06TUU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_rZtSS3Hk, 1, m, &cIf_rZtSS3Hk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_En9k7lz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_epY7RrcC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pv6uhXzy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeQ1gvtW, 1, m, &cIf_LeQ1gvtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8X8YTAev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LeQ1gvtW, 0, m, &cIf_LeQ1gvtW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GWzqkGqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Chh7glFY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3OfrP4D0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Chh7glFY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_szyqVBFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HADK45Md_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mtRFv95U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_07HhQhoL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_P1X4V2wK_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_H1hTAYcK_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_H1hTAYcK_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_uVYPSUQr, 1, m, &cDelay_uVYPSUQr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6dVt4PU6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_uVYPSUQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_uVYPSUQr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_szyqVBFT, 0, m, &cIf_szyqVBFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H1hTAYcK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_uVYPSUQr, 0, m, &cDelay_uVYPSUQr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6dVt4PU6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_uVYPSUQr, 0, m, &cDelay_uVYPSUQr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gh1h03Mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sZLlsQC1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lOxEJ4lr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CTs99bDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8RsvEhK3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kAfbX6KV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8RsvEhK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_szyqVBFT, 1, m, &cIf_szyqVBFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kAfbX6KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_P1X4V2wK_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_lOxEJ4lr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mtRFv95U, 0, m, &cIf_mtRFv95U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sZLlsQC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mtRFv95U, 1, m, &cIf_mtRFv95U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_07HhQhoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r9UnceFd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HADK45Md_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r9UnceFd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mpaAAeUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_TLztCB24_sendMessage(_c, 0, m);
  cMsg_qPGqJLk7_sendMessage(_c, 0, m);
  cMsg_1QvaGaRU_sendMessage(_c, 0, m);
  cMsg_dERn8fAS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QBvl9SIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_TLztCB24_sendMessage(_c, 0, m);
  cMsg_ugkY5v1r_sendMessage(_c, 0, m);
  cMsg_ZE5WPNhL_sendMessage(_c, 0, m);
  cMsg_1PBvWQbM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CsjaPIJr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_bHhXMOC3_sendMessage(_c, 0, m);
  cMsg_ugkY5v1r_sendMessage(_c, 0, m);
  cMsg_dERn8fAS_sendMessage(_c, 0, m);
  cMsg_LM2cfz5E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_XrKG9qmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_bHhXMOC3_sendMessage(_c, 0, m);
  cMsg_LAF88ImA_sendMessage(_c, 0, m);
  cMsg_1QvaGaRU_sendMessage(_c, 0, m);
  cMsg_qw9HDt7O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ymhYRhlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_I98RgHqk_sendMessage(_c, 0, m);
  cMsg_1PBvWQbM_sendMessage(_c, 0, m);
  cMsg_ccL5qWvI_sendMessage(_c, 0, m);
  cMsg_1QvaGaRU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AMSRo58L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_I98RgHqk_sendMessage(_c, 0, m);
  cMsg_qw9HDt7O_sendMessage(_c, 0, m);
  cMsg_ugkY5v1r_sendMessage(_c, 0, m);
  cMsg_HSp6xjJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_23lnvrOx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0YnL0cxY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lMuNl3JP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3a3ZX6tw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_0YnL0cxY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lMuNl3JP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3x5W2ugX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aSteM7a8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uVZBMS50_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QEduhuS9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aSteM7a8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uVZBMS50_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iIW4gk2w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N4DInFCg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_c5yJSgJ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oqzMM5CM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_N4DInFCg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_c5yJSgJ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TLztCB24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_23lnvrOx_sendMessage(_c, 0, m);
  cMsg_QEduhuS9_sendMessage(_c, 0, m);
  cMsg_oqzMM5CM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bHhXMOC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_3a3ZX6tw_sendMessage(_c, 0, m);
  cMsg_3x5W2ugX_sendMessage(_c, 0, m);
  cMsg_oqzMM5CM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I98RgHqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_3a3ZX6tw_sendMessage(_c, 0, m);
  cMsg_QEduhuS9_sendMessage(_c, 0, m);
  cMsg_iIW4gk2w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GB5aQvve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kHuJWH7o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DiQptB8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_inHeshUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_kHuJWH7o_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DiQptB8C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nnot5RLc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9Y6gr6du_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NSGBSFRs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W5tOKW0I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9Y6gr6du_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NSGBSFRs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AFzsY3Tr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MBrpnPE0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4vKbawmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_im7s7wXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_MBrpnPE0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4vKbawmF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ugkY5v1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_inHeshUu_sendMessage(_c, 0, m);
  cMsg_W5tOKW0I_sendMessage(_c, 0, m);
  cMsg_im7s7wXM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qPGqJLk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_inHeshUu_sendMessage(_c, 0, m);
  cMsg_nnot5RLc_sendMessage(_c, 0, m);
  cMsg_AFzsY3Tr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LAF88ImA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_GB5aQvve_sendMessage(_c, 0, m);
  cMsg_W5tOKW0I_sendMessage(_c, 0, m);
  cMsg_AFzsY3Tr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3Z20oz0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7inE8AUd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WHOkvyY1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uiwJIEic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_7inE8AUd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WHOkvyY1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_53fQjI39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FoBwwbBY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UN3xBrU1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yumHUn53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FoBwwbBY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UN3xBrU1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zwbKnB3n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CTs99bDh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gh1h03Mo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9HcrzK1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CTs99bDh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gh1h03Mo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qw9HDt7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_3Z20oz0Q_sendMessage(_c, 0, m);
  cMsg_yumHUn53_sendMessage(_c, 0, m);
  cMsg_9HcrzK1J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1PBvWQbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_uiwJIEic_sendMessage(_c, 0, m);
  cMsg_53fQjI39_sendMessage(_c, 0, m);
  cMsg_9HcrzK1J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dERn8fAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_uiwJIEic_sendMessage(_c, 0, m);
  cMsg_yumHUn53_sendMessage(_c, 0, m);
  cMsg_zwbKnB3n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xCPdzMMY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tF5iHz7A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lNRAOTWi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ymzoeD2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tF5iHz7A_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_lNRAOTWi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bcVvDdUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E5STJiy9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XJvlJeb0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_we92Fi1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_E5STJiy9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_XJvlJeb0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_b0CKiAN2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V3k7lqgw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2gpQguMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_55lPg8Kp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_V3k7lqgw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_2gpQguMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1QvaGaRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_ymzoeD2C_sendMessage(_c, 0, m);
  cMsg_we92Fi1U_sendMessage(_c, 0, m);
  cMsg_55lPg8Kp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZE5WPNhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_ymzoeD2C_sendMessage(_c, 0, m);
  cMsg_bcVvDdUh_sendMessage(_c, 0, m);
  cMsg_b0CKiAN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HSp6xjJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_xCPdzMMY_sendMessage(_c, 0, m);
  cMsg_bcVvDdUh_sendMessage(_c, 0, m);
  cMsg_55lPg8Kp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ccL5qWvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_GB5aQvve_sendMessage(_c, 0, m);
  cMsg_nnot5RLc_sendMessage(_c, 0, m);
  cMsg_im7s7wXM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LM2cfz5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_xCPdzMMY_sendMessage(_c, 0, m);
  cMsg_we92Fi1U_sendMessage(_c, 0, m);
  cMsg_b0CKiAN2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_oGE9u2C5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xnGEfGXX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vqRP3sVu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_V7gpMFGz, 0, m, &cSlice_V7gpMFGz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n7JTIo5g_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_V7gpMFGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UxFCRTbp_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UxFCRTbp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8n9384mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UxFCRTbp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UxFCRTbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_duR5cfRu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_t7hkZ48H_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UpogBaD3, 0, m, &cSlice_UpogBaD3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zs33jdDy_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UpogBaD3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0vb8sIRe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0vb8sIRe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WhETMERJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0vb8sIRe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0vb8sIRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A2FK1ODP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zs33jdDy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Xjlq2LDi, 0, m, &cSlice_Xjlq2LDi_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vqRP3sVu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Xjlq2LDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7QzarTDt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7QzarTDt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Maw2L9fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7QzarTDt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7QzarTDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gpfBI8BS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n7JTIo5g_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wgmbAToX, 0, m, &cSlice_wgmbAToX_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6Cu6KOuY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wgmbAToX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iyPFn88S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iyPFn88S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_E2jOiNms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iyPFn88S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iyPFn88S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iI2XUKFE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6Cu6KOuY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_lqMWGPBV, 0, m, &cSlice_lqMWGPBV_sendMessage);
      break;
    }
    default: {
      cSwitchcase_DvNGC3ov_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_lqMWGPBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_dc6RLbuL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_dc6RLbuL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SSYtOPBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_dc6RLbuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_dc6RLbuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QveBqcDq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hrGOeEaQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yDZI7lCa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yDZI7lCa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Ro69sD4e, 1, m, &cDelay_Ro69sD4e_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_F2hxc9J8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Ro69sD4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Ro69sD4e, m);
  cMsg_2b8ioNS2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yDZI7lCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ro69sD4e, 0, m, &cDelay_Ro69sD4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F2hxc9J8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Ro69sD4e, 0, m, &cDelay_Ro69sD4e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_qRCvqwoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sX5ry2Ax, HV_BINOP_SUBTRACT, 0, m, &cBinop_sX5ry2Ax_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_MunECurI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0jP2fYEy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2p5SdT3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0jP2fYEy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_Aw4s6Ktc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qRCvqwoE, 0, m, &cVar_qRCvqwoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_6nZ2nBEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_p6JoKts7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t6R6xnwo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H0SIMD0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sX5ry2Ax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h64kr6wb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_h64kr6wb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WWrV1Meb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WWrV1Meb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_UFwizzrA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nfHgL6Yz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hBRp0o40_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dvKWJava_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hBRp0o40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MunECurI, 1, m, &cIf_MunECurI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dvKWJava_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7IEoud4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_vEzqxXun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2p5SdT3R, 1, m, &cIf_2p5SdT3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7IEoud4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MunECurI, 0, m, &cIf_MunECurI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UFwizzrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2p5SdT3R, 0, m, &cIf_2p5SdT3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H0SIMD0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_qRCvqwoE, 0, m, &cVar_qRCvqwoE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p6JoKts7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_t6R6xnwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sX5ry2Ax, HV_BINOP_SUBTRACT, 1, m, &cBinop_sX5ry2Ax_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0jP2fYEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uHp4Nza9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DvNGC3ov_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ejxfdgiZ, 0, m, &cSlice_ejxfdgiZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ejxfdgiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_wPQDCN6U_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_wPQDCN6U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_kmQvQPPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wPQDCN6U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wPQDCN6U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_l9JGzCyB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iN8hCjFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ebwkwDcR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2IY2Q0MI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_db3rgKYx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ZhbnMsuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ODxMZeIh, 0, m, &cVar_ODxMZeIh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xnGEfGXX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RjI3XPcd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xWkVb3sC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hrGOeEaQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_agygZshf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tla8OyaP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2b8ioNS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dSRJfNfn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Tla8OyaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dSRJfNfn, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dC3BC2lW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_xjVzooT6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xjVzooT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GZ900OBY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GZ900OBY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_p4jwr0K8, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_FVrlnGwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qFzbgAr2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_diChbwFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0xNFUowu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_isXZ5kbl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7TaHn0VL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_EED9v9Tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ss1JTRHw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_5zgOyVQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6IROini1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_sX8KNmK8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uLKzHM5O_sendMessage);
  cMsg_YX3amzw7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uLKzHM5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sX8KNmK8, 1, m, &cVar_sX8KNmK8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1K1AHZAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2TznE6r8_sendMessage(_c, 0, m);
  cMsg_71x1OPNT_sendMessage(_c, 0, m);
  cMsg_2K9PiSCT_sendMessage(_c, 0, m);
  cMsg_P6NuhA4t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PetB1rTE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_x9Q5DgWX, 0, m, &cSlice_x9Q5DgWX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_x9Q5DgWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AERujudv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AERujudv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ckMqw03o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AERujudv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AERujudv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NMQgjnvi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_oC7OUAzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_n9vNMBTt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n9vNMBTt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_JKeKM0t6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JKeKM0t6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_UtT0k94W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UtT0k94W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lCHwHxHa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_s3V7TuWK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s3V7TuWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W2DHd4Pd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lCHwHxHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_uSNgp7xf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uSNgp7xf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hWZpXrhI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W2DHd4Pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ajr8On6v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ajr8On6v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_TXB93EMX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hWZpXrhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Oj1y5qI4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_TXB93EMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BCQIiiag_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Oj1y5qI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_n51eMeqk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BCQIiiag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9GagYI1W, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_KQ6SCaMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZqSCyip7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_utdLUcWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Wv8LpBlq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jRsTWqBV_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ahhoKWh_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZaHm4kxt_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WWhjfuh5_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jxxVfyEx_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fZJxwO6q_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VxrJtRQs_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_7ahhoKWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L1BaMmSr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZaHm4kxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dDFbJwXQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_WWhjfuh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OX8oADDV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jxxVfyEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ai2T0qLt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_fZJxwO6q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nqD0m4YO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VxrJtRQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KdgI9BGi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_QvgzZUN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UTEhXRkI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G2sobD90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eiOZTWDE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ArPJL3Uu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_g9H5Nq9v_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_g9H5Nq9v_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_h91gsYxk, 1, m, &cDelay_h91gsYxk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oZiyQp9I_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_h91gsYxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h91gsYxk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QvgzZUN5, 0, m, &cIf_QvgzZUN5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_g9H5Nq9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h91gsYxk, 0, m, &cDelay_h91gsYxk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oZiyQp9I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h91gsYxk, 0, m, &cDelay_h91gsYxk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n4hot9GG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_krlFvjSk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qGRpaXUT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yKsGRozy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rmLru3ky_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5lmJJiSd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5lmJJiSd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ArPJL3Uu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rmLru3ky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QvgzZUN5, 1, m, &cIf_QvgzZUN5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_krlFvjSk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G2sobD90, 1, m, &cIf_G2sobD90_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qGRpaXUT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G2sobD90, 0, m, &cIf_G2sobD90_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eiOZTWDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h56eAOdX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UTEhXRkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_h56eAOdX, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HD3ChczU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jNOMg1n5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dBW6fSK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8qlZ4lVJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fkb4mYYc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MJgXPt8I_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MJgXPt8I_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_59N0DHYb, 1, m, &cDelay_59N0DHYb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SRwuUs8x_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_59N0DHYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_59N0DHYb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HD3ChczU, 0, m, &cIf_HD3ChczU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MJgXPt8I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_59N0DHYb, 0, m, &cDelay_59N0DHYb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SRwuUs8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_59N0DHYb, 0, m, &cDelay_59N0DHYb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eYe8A5AQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gxoBKUj8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ULFA07qC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GYUfuwcZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uE8WQz81_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kz1Cobme_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kz1Cobme_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fkb4mYYc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_uE8WQz81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HD3ChczU, 1, m, &cIf_HD3ChczU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gxoBKUj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dBW6fSK1, 1, m, &cIf_dBW6fSK1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ULFA07qC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dBW6fSK1, 0, m, &cIf_dBW6fSK1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8qlZ4lVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lElvWhTQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jNOMg1n5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lElvWhTQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Dqbw5iCX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i7EZdehL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DV50H71B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H5bR4ZZ2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_twzg69vP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_gVw1gjtz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_gVw1gjtz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_TchCPR6c, 1, m, &cDelay_TchCPR6c_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xPMsiVbN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_TchCPR6c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_TchCPR6c, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Dqbw5iCX, 0, m, &cIf_Dqbw5iCX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gVw1gjtz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_TchCPR6c, 0, m, &cDelay_TchCPR6c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xPMsiVbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_TchCPR6c, 0, m, &cDelay_TchCPR6c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IjXlFsq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ub48Z6P0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1FB8Qk6h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5x6WJAqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PSky6MUa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xBsv6ygK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PSky6MUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Dqbw5iCX, 1, m, &cIf_Dqbw5iCX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xBsv6ygK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_twzg69vP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1FB8Qk6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DV50H71B, 0, m, &cIf_DV50H71B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ub48Z6P0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DV50H71B, 1, m, &cIf_DV50H71B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H5bR4ZZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tR4OpRre, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i7EZdehL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tR4OpRre, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xqjlDy0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hMw1mcPO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_RT5uIUkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KvPRjKor_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DmWUGXcg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QhZ4pyhW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QhZ4pyhW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JuSIdCJc, 1, m, &cDelay_JuSIdCJc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hdO1Ratq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JuSIdCJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JuSIdCJc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xqjlDy0u, 0, m, &cIf_xqjlDy0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QhZ4pyhW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JuSIdCJc, 0, m, &cDelay_JuSIdCJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hdO1Ratq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JuSIdCJc, 0, m, &cDelay_JuSIdCJc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AsHHJe7h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ORQC1RzS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eCFFxruQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jvsrGjvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GrenwPig_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dHTCskBM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GrenwPig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xqjlDy0u, 1, m, &cIf_xqjlDy0u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dHTCskBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DmWUGXcg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ORQC1RzS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RT5uIUkR, 1, m, &cIf_RT5uIUkR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eCFFxruQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RT5uIUkR, 0, m, &cIf_RT5uIUkR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KvPRjKor_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4D4GoHrf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_hMw1mcPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4D4GoHrf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_7AtDllpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rE7SZSNx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_eGhLOpft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8CVyP9yI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YhU8sB3J_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FPpFh4pg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FPpFh4pg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_CpPpBjZq, 1, m, &cDelay_CpPpBjZq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_sr9x7A1K_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_CpPpBjZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_CpPpBjZq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_7AtDllpC, 0, m, &cIf_7AtDllpC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FPpFh4pg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_CpPpBjZq, 0, m, &cDelay_CpPpBjZq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sr9x7A1K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_CpPpBjZq, 0, m, &cDelay_CpPpBjZq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6a8aHxuf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hfXeyqwI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a0VuNCfg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9nQZPztI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OwAv26j1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x4HoCMWh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x4HoCMWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YhU8sB3J_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OwAv26j1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7AtDllpC, 1, m, &cIf_7AtDllpC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a0VuNCfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eGhLOpft, 0, m, &cIf_eGhLOpft_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hfXeyqwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eGhLOpft, 1, m, &cIf_eGhLOpft_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8CVyP9yI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BNiOG6Z4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rE7SZSNx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BNiOG6Z4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Qc1OHQuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_f0gKfhcr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_00r5pg9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_haYxonFQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rBg2pvxf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_i4WmtSez_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_i4WmtSez_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_IZtVFmZE, 1, m, &cDelay_IZtVFmZE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Hahk08Z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_IZtVFmZE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_IZtVFmZE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Qc1OHQuu, 0, m, &cIf_Qc1OHQuu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i4WmtSez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZtVFmZE, 0, m, &cDelay_IZtVFmZE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Hahk08Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_IZtVFmZE, 0, m, &cDelay_IZtVFmZE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LNXYoiAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DfDbgGEw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ksV2wwIz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L63kxIhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RNSrYG7M_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x6SLs9kX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x6SLs9kX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rBg2pvxf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RNSrYG7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qc1OHQuu, 1, m, &cIf_Qc1OHQuu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ksV2wwIz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_00r5pg9a, 0, m, &cIf_00r5pg9a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DfDbgGEw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_00r5pg9a, 1, m, &cIf_00r5pg9a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_haYxonFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pl8jjA4C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_f0gKfhcr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_pl8jjA4C, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_iQcNMcqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nb1ADFZ4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U0YaaeEV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_x8i55VPU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_2LH848VA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_v0Jr0pNb_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_v0Jr0pNb_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FnBhPmlO, 1, m, &cDelay_FnBhPmlO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mnBTVK3V_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FnBhPmlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FnBhPmlO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_iQcNMcqb, 0, m, &cIf_iQcNMcqb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_v0Jr0pNb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnBhPmlO, 0, m, &cDelay_FnBhPmlO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mnBTVK3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FnBhPmlO, 0, m, &cDelay_FnBhPmlO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ITMzCzte_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oInv2WiY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_n4jfEPgF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9fSLOh5s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jeZCrvAF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UzCSdbeL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jeZCrvAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_iQcNMcqb, 1, m, &cIf_iQcNMcqb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UzCSdbeL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_2LH848VA_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oInv2WiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U0YaaeEV, 1, m, &cIf_U0YaaeEV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_n4jfEPgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U0YaaeEV, 0, m, &cIf_U0YaaeEV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_x8i55VPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vci09NfC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Nb1ADFZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vci09NfC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_eYUBL4FT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yin3OtPK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_3haB47a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ycvLqFIq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_O7KEQOyZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rvbNbaSQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rvbNbaSQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xym5tHfB, 1, m, &cDelay_xym5tHfB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kyOSaq8T_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xym5tHfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xym5tHfB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_eYUBL4FT, 0, m, &cIf_eYUBL4FT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rvbNbaSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xym5tHfB, 0, m, &cDelay_xym5tHfB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kyOSaq8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xym5tHfB, 0, m, &cDelay_xym5tHfB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_oxHeJ6K0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_igsEIP0H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UqOW8j0A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Y1cCWOpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3siSsH1f_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AlTSRNTy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AlTSRNTy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_O7KEQOyZ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3siSsH1f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eYUBL4FT, 1, m, &cIf_eYUBL4FT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UqOW8j0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3haB47a2, 0, m, &cIf_3haB47a2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_igsEIP0H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3haB47a2, 1, m, &cIf_3haB47a2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ycvLqFIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vj9jdnTJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yin3OtPK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vj9jdnTJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_4vAVCxYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_gwPqYl9t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2sspKRuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xnLq3jhX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gQVVoXop_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_CX5vNo1P_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_CX5vNo1P_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8jrMcMl9, 1, m, &cDelay_8jrMcMl9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xetTIPtE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8jrMcMl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8jrMcMl9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4vAVCxYl, 0, m, &cIf_4vAVCxYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CX5vNo1P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8jrMcMl9, 0, m, &cDelay_8jrMcMl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xetTIPtE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8jrMcMl9, 0, m, &cDelay_8jrMcMl9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_e1cMnnnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_61YqnOxz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kJRyouRB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gV1eeJJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PHLUxukH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iIgpKVt0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PHLUxukH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4vAVCxYl, 1, m, &cIf_4vAVCxYl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iIgpKVt0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gQVVoXop_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kJRyouRB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2sspKRuL, 0, m, &cIf_2sspKRuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_61YqnOxz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2sspKRuL, 1, m, &cIf_2sspKRuL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xnLq3jhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UKq8yFOZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gwPqYl9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UKq8yFOZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9NZjIHXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UgBcauUk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_a1QO8k5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EJ3D1upU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5F79QDPd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_w9TJKASW_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_w9TJKASW_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EEPAWvmw, 1, m, &cDelay_EEPAWvmw_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a20wqV1W_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EEPAWvmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EEPAWvmw, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9NZjIHXO, 0, m, &cIf_9NZjIHXO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w9TJKASW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EEPAWvmw, 0, m, &cDelay_EEPAWvmw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a20wqV1W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EEPAWvmw, 0, m, &cDelay_EEPAWvmw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1Vhgf6qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rtvdHjAg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H3doW0qL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pM3POON4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pNldUItY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RrajNZZs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RrajNZZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_5F79QDPd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pNldUItY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9NZjIHXO, 1, m, &cIf_9NZjIHXO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rtvdHjAg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a1QO8k5m, 1, m, &cIf_a1QO8k5m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H3doW0qL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_a1QO8k5m, 0, m, &cIf_a1QO8k5m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EJ3D1upU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MEFmCGvh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UgBcauUk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MEFmCGvh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_29BF93v7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fGfhUbeo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Fgn9Elxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XZ3B1a9s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DLy4ZtNu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nCNjGkeB_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nCNjGkeB_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BFvtu0un, 1, m, &cDelay_BFvtu0un_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HaZPrXvf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BFvtu0un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BFvtu0un, m);
  cIf_onMessage(_c, &Context(_c)->cIf_29BF93v7, 0, m, &cIf_29BF93v7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nCNjGkeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BFvtu0un, 0, m, &cDelay_BFvtu0un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HaZPrXvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BFvtu0un, 0, m, &cDelay_BFvtu0un_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m3cvCdUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_npL6xRvU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdw4w6Z3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1iMODpXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_raJMMaKE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ID9FNxNZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_raJMMaKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_29BF93v7, 1, m, &cIf_29BF93v7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ID9FNxNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DLy4ZtNu_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kdw4w6Z3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fgn9Elxu, 0, m, &cIf_Fgn9Elxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_npL6xRvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Fgn9Elxu, 1, m, &cIf_Fgn9Elxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XZ3B1a9s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JUxH14t1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fGfhUbeo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JUxH14t1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MVVeCGQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eVGXZA3H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q7QqbBYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4nBLaGOI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1Pec1EEk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_m18QJb7C_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_m18QJb7C_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1vOzGwVq, 1, m, &cDelay_1vOzGwVq_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wMGymSMC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1vOzGwVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1vOzGwVq, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MVVeCGQJ, 0, m, &cIf_MVVeCGQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m18QJb7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1vOzGwVq, 0, m, &cDelay_1vOzGwVq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wMGymSMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1vOzGwVq, 0, m, &cDelay_1vOzGwVq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T7GhDM5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SbXCK9Sh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_axaiwVBq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_26ayDHbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BXW88Lqa_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BKWCgpt7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BXW88Lqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MVVeCGQJ, 1, m, &cIf_MVVeCGQJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BKWCgpt7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1Pec1EEk_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_SbXCK9Sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q7QqbBYG, 1, m, &cIf_q7QqbBYG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_axaiwVBq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q7QqbBYG, 0, m, &cIf_q7QqbBYG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4nBLaGOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yh34iFsi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_eVGXZA3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yh34iFsi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_L1BaMmSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_qtHQwYgT_sendMessage(_c, 0, m);
  cMsg_781UwTy9_sendMessage(_c, 0, m);
  cMsg_rj56EdvK_sendMessage(_c, 0, m);
  cMsg_rzmmo7rC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dDFbJwXQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_qtHQwYgT_sendMessage(_c, 0, m);
  cMsg_T90DtyZB_sendMessage(_c, 0, m);
  cMsg_yW544x8F_sendMessage(_c, 0, m);
  cMsg_n2cXCvOU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OX8oADDV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_m810kz64_sendMessage(_c, 0, m);
  cMsg_T90DtyZB_sendMessage(_c, 0, m);
  cMsg_rzmmo7rC_sendMessage(_c, 0, m);
  cMsg_NpfnqjfE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ai2T0qLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_m810kz64_sendMessage(_c, 0, m);
  cMsg_IgETWOAe_sendMessage(_c, 0, m);
  cMsg_rj56EdvK_sendMessage(_c, 0, m);
  cMsg_RQ8hBWlN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nqD0m4YO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_CaHplxJs_sendMessage(_c, 0, m);
  cMsg_n2cXCvOU_sendMessage(_c, 0, m);
  cMsg_cv3zUNdB_sendMessage(_c, 0, m);
  cMsg_rj56EdvK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KdgI9BGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_CaHplxJs_sendMessage(_c, 0, m);
  cMsg_RQ8hBWlN_sendMessage(_c, 0, m);
  cMsg_T90DtyZB_sendMessage(_c, 0, m);
  cMsg_bS7piX7K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SzT1uaJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yKsGRozy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n4hot9GG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lfw6LI6E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_yKsGRozy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_n4hot9GG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HWNNulT6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GYUfuwcZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eYe8A5AQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j5Af0F0a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GYUfuwcZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_eYe8A5AQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GJev4r6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5x6WJAqh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IjXlFsq1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HUR62IqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_5x6WJAqh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IjXlFsq1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qtHQwYgT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_SzT1uaJu_sendMessage(_c, 0, m);
  cMsg_j5Af0F0a_sendMessage(_c, 0, m);
  cMsg_HUR62IqA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_m810kz64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_lfw6LI6E_sendMessage(_c, 0, m);
  cMsg_HWNNulT6_sendMessage(_c, 0, m);
  cMsg_HUR62IqA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_CaHplxJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_lfw6LI6E_sendMessage(_c, 0, m);
  cMsg_j5Af0F0a_sendMessage(_c, 0, m);
  cMsg_GJev4r6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kUA0Qcxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jvsrGjvI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AsHHJe7h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eeF4DQmS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_jvsrGjvI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_AsHHJe7h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nS9faDIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9nQZPztI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6a8aHxuf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vnKeXh6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9nQZPztI_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_6a8aHxuf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7HHXo3Rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_L63kxIhY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LNXYoiAQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d7TlZaMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_L63kxIhY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LNXYoiAQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T90DtyZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_eeF4DQmS_sendMessage(_c, 0, m);
  cMsg_vnKeXh6B_sendMessage(_c, 0, m);
  cMsg_d7TlZaMl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_781UwTy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_eeF4DQmS_sendMessage(_c, 0, m);
  cMsg_nS9faDIJ_sendMessage(_c, 0, m);
  cMsg_7HHXo3Rr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IgETWOAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_kUA0Qcxg_sendMessage(_c, 0, m);
  cMsg_vnKeXh6B_sendMessage(_c, 0, m);
  cMsg_7HHXo3Rr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YLNd5bmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pM3POON4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1Vhgf6qT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ffNoIPik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pM3POON4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1Vhgf6qT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wisQubL4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1iMODpXM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m3cvCdUS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YHJkIPRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1iMODpXM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m3cvCdUS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_P7V3aKES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_26ayDHbD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T7GhDM5u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_T8vf5IBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_26ayDHbD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T7GhDM5u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RQ8hBWlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_YLNd5bmT_sendMessage(_c, 0, m);
  cMsg_YHJkIPRq_sendMessage(_c, 0, m);
  cMsg_T8vf5IBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_n2cXCvOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ffNoIPik_sendMessage(_c, 0, m);
  cMsg_wisQubL4_sendMessage(_c, 0, m);
  cMsg_T8vf5IBs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rzmmo7rC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ffNoIPik_sendMessage(_c, 0, m);
  cMsg_YHJkIPRq_sendMessage(_c, 0, m);
  cMsg_P7V3aKES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_igRo50xA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9fSLOh5s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ITMzCzte_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rmz71Clx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9fSLOh5s_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ITMzCzte_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JDmb4JaW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Y1cCWOpg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oxHeJ6K0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BAFRsUIa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Y1cCWOpg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_oxHeJ6K0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JVnjPSJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gV1eeJJ1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e1cMnnnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7vfmpZcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_gV1eeJJ1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_e1cMnnnW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rj56EdvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_rmz71Clx_sendMessage(_c, 0, m);
  cMsg_BAFRsUIa_sendMessage(_c, 0, m);
  cMsg_7vfmpZcp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_yW544x8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_rmz71Clx_sendMessage(_c, 0, m);
  cMsg_JDmb4JaW_sendMessage(_c, 0, m);
  cMsg_JVnjPSJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bS7piX7K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_igRo50xA_sendMessage(_c, 0, m);
  cMsg_JDmb4JaW_sendMessage(_c, 0, m);
  cMsg_7vfmpZcp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_cv3zUNdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_kUA0Qcxg_sendMessage(_c, 0, m);
  cMsg_nS9faDIJ_sendMessage(_c, 0, m);
  cMsg_d7TlZaMl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NpfnqjfE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_igRo50xA_sendMessage(_c, 0, m);
  cMsg_BAFRsUIa_sendMessage(_c, 0, m);
  cMsg_JVnjPSJC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ecqVXXSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dTdMTZKp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MDBNiMMp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b7Gm3n5j, 0, m, &cSlice_b7Gm3n5j_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TX3mmwVl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_b7Gm3n5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gcFpzwec_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gcFpzwec_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FyQTiD4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gcFpzwec_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_gcFpzwec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R0v8YieQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_aPCUZvk1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_nx8aqolL, 0, m, &cSlice_nx8aqolL_sendMessage);
      break;
    }
    default: {
      cSwitchcase_kiBRlvHe_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_nx8aqolL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7Z9j42j9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7Z9j42j9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pF2IPUHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7Z9j42j9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7Z9j42j9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PfjCDOXA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kiBRlvHe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_AZRDZAcN, 0, m, &cSlice_AZRDZAcN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MDBNiMMp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_AZRDZAcN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3Z1YlyuP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3Z1YlyuP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_qPWYcVBN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3Z1YlyuP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3Z1YlyuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_oYOf0XBm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TX3mmwVl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XnpqPA7b, 0, m, &cSlice_XnpqPA7b_sendMessage);
      break;
    }
    default: {
      cSwitchcase_d67eC6Xx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XnpqPA7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AFhjBgYn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AFhjBgYn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_nxxCnwoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AFhjBgYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AFhjBgYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HEv3ahud_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_d67eC6Xx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_cAzlESYP, 0, m, &cSlice_cAzlESYP_sendMessage);
      break;
    }
    default: {
      cSwitchcase_52xS8W4p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_cAzlESYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_weSUkxBS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_weSUkxBS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9TtqVedg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_weSUkxBS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_weSUkxBS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_AIypy3CX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XcmDZfgc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_WbHC3yXg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_WbHC3yXg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mCev2zxQ, 1, m, &cDelay_mCev2zxQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U9Bo8aQB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mCev2zxQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mCev2zxQ, m);
  cMsg_nPL6jhZe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WbHC3yXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mCev2zxQ, 0, m, &cDelay_mCev2zxQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U9Bo8aQB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mCev2zxQ, 0, m, &cDelay_mCev2zxQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_AeIQCzxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhrFh2VJ, HV_BINOP_SUBTRACT, 0, m, &cBinop_hhrFh2VJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_AbyXUaR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O41gKWIq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1OqQCDxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_O41gKWIq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_aLJxoS6L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AeIQCzxH, 0, m, &cVar_AeIQCzxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_qKAlHCz7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fzrZw8Vq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_45uXnYVW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_x4letVmC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hhrFh2VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u15S4dhA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u15S4dhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_vj7ZAgMo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vj7ZAgMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_As30HLFf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Cs7TQqi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lwf9bXUC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7dgPYC7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7dgPYC7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KqrqkO15_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Lwf9bXUC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AbyXUaR5, 1, m, &cIf_AbyXUaR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x7S6KyPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1OqQCDxK, 1, m, &cIf_1OqQCDxK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KqrqkO15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_AbyXUaR5, 0, m, &cIf_AbyXUaR5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_As30HLFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1OqQCDxK, 0, m, &cIf_1OqQCDxK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_45uXnYVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hhrFh2VJ, HV_BINOP_SUBTRACT, 1, m, &cBinop_hhrFh2VJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fzrZw8Vq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_x4letVmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AeIQCzxH, 0, m, &cVar_AeIQCzxH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_O41gKWIq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AfVr09VM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_52xS8W4p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1A0Xwgyn, 0, m, &cSlice_1A0Xwgyn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_1A0Xwgyn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VI7uRF8Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VI7uRF8Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_4AtlXus5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VI7uRF8Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_VI7uRF8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LunKUzOm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZqSCyip7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_y1rWFdUu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Wv8LpBlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZznukeWS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_n6NvvY5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_utdLUcWg, 0, m, &cVar_utdLUcWg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dTdMTZKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mPHkToZa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_a1bloxQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_XcmDZfgc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qIC9gFqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1zejPTPC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nPL6jhZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PGQhgIhc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1zejPTPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PGQhgIhc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_febq9D5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_L4EBxdbZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L4EBxdbZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HoGelE9m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HoGelE9m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_H1gR5cIP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_3ce3BwXr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jkauN78I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_8KOaKqxu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OW3VbY1m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_RsTwFR0t_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qBiGDT5w_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AjXkK1lL_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_adR1VlA8_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QPXejaJ7_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1mIxC79Q_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wv1gUZo6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_qBiGDT5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P93jrOjv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AjXkK1lL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w9JYzMRe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_adR1VlA8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Wf4oOYw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QPXejaJ7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WzoPFRzT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_1mIxC79Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DycW4dSf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_wv1gUZo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JhSH8RTH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_R9hblzXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ZHvpfA9Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dwzKfUmh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OZOfB71c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_oHRMPPev_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_FZ1Igwb0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_FZ1Igwb0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_belbq5m9, 1, m, &cDelay_belbq5m9_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NCMXlCSG_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_belbq5m9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_belbq5m9, m);
  cIf_onMessage(_c, &Context(_c)->cIf_R9hblzXm, 0, m, &cIf_R9hblzXm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FZ1Igwb0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_belbq5m9, 0, m, &cDelay_belbq5m9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NCMXlCSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_belbq5m9, 0, m, &cDelay_belbq5m9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5kuTyKON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7dwopA3Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wqlze7OB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GBvJDm7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FkpXGVsq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XtDbJzFy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XtDbJzFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_oHRMPPev_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FkpXGVsq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R9hblzXm, 1, m, &cIf_R9hblzXm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7dwopA3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dwzKfUmh, 1, m, &cIf_dwzKfUmh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wqlze7OB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dwzKfUmh, 0, m, &cIf_dwzKfUmh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OZOfB71c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oq5JqRbj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZHvpfA9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oq5JqRbj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_daXC27vR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z3dkLbkg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5dyovFen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UTQt7hQl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0XU3gFA2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rhymtdgl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rhymtdgl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_pdu4UXqP, 1, m, &cDelay_pdu4UXqP_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ebxSUdN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_pdu4UXqP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_pdu4UXqP, m);
  cIf_onMessage(_c, &Context(_c)->cIf_daXC27vR, 0, m, &cIf_daXC27vR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rhymtdgl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_pdu4UXqP, 0, m, &cDelay_pdu4UXqP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ebxSUdN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_pdu4UXqP, 0, m, &cDelay_pdu4UXqP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WQrW4QZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FhFxltoC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YigfOXsZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DJZpp3FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wihk8o0m_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u2a1VMxq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wihk8o0m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_daXC27vR, 1, m, &cIf_daXC27vR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u2a1VMxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0XU3gFA2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_FhFxltoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5dyovFen, 1, m, &cIf_5dyovFen_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YigfOXsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5dyovFen, 0, m, &cIf_5dyovFen_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UTQt7hQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NWPIlSaB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_z3dkLbkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NWPIlSaB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xMYU6TFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DA66nwBA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Q4r45IkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Q99eFVGd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jNYxc9Hr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QGjZlL49_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QGjZlL49_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_C1zEVmUS, 1, m, &cDelay_C1zEVmUS_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YLnacpaJ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_C1zEVmUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_C1zEVmUS, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xMYU6TFB, 0, m, &cIf_xMYU6TFB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QGjZlL49_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_C1zEVmUS, 0, m, &cDelay_C1zEVmUS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YLnacpaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_C1zEVmUS, 0, m, &cDelay_C1zEVmUS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CcQxsWan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BXXlaabb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kbh3uqUF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iApewQD2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ite8MX3c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5N16R0k2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ite8MX3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xMYU6TFB, 1, m, &cIf_xMYU6TFB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5N16R0k2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jNYxc9Hr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BXXlaabb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q4r45IkW, 1, m, &cIf_Q4r45IkW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kbh3uqUF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q4r45IkW, 0, m, &cIf_Q4r45IkW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Q99eFVGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TqENmSrB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DA66nwBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TqENmSrB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AVSNamY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yEPgL1Oy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DKV1xND5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WxI2fOzK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_slksoSV5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_6YekJXAU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_6YekJXAU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_oST4NIoh, 1, m, &cDelay_oST4NIoh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VenMNxgE_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_oST4NIoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_oST4NIoh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AVSNamY4, 0, m, &cIf_AVSNamY4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6YekJXAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_oST4NIoh, 0, m, &cDelay_oST4NIoh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VenMNxgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_oST4NIoh, 0, m, &cDelay_oST4NIoh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rCpZVfmI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0pLbdSfH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HVDoOdZO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C8URDtr8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DIipXnpX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I1Rx5uC2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I1Rx5uC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_slksoSV5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_DIipXnpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AVSNamY4, 1, m, &cIf_AVSNamY4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0pLbdSfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DKV1xND5, 1, m, &cIf_DKV1xND5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HVDoOdZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DKV1xND5, 0, m, &cIf_DKV1xND5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WxI2fOzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kb37IWWA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yEPgL1Oy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kb37IWWA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_NIXhJGWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W4wnzsRC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0hroPjhO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_giXNkXEs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ePQaxubQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xLqgVpNE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xLqgVpNE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8qF3Bd4t, 1, m, &cDelay_8qF3Bd4t_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KCK6SZg3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8qF3Bd4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8qF3Bd4t, m);
  cIf_onMessage(_c, &Context(_c)->cIf_NIXhJGWL, 0, m, &cIf_NIXhJGWL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xLqgVpNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8qF3Bd4t, 0, m, &cDelay_8qF3Bd4t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KCK6SZg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8qF3Bd4t, 0, m, &cDelay_8qF3Bd4t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jELwvfg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1deEMCWR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LEyLc51Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sBEwOErw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3gVxcfqX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0SHIJGW2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0SHIJGW2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_ePQaxubQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3gVxcfqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NIXhJGWL, 1, m, &cIf_NIXhJGWL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1deEMCWR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0hroPjhO, 1, m, &cIf_0hroPjhO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LEyLc51Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0hroPjhO, 0, m, &cIf_0hroPjhO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_giXNkXEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Km2eSX9z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_W4wnzsRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Km2eSX9z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aPGjyKqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9yqmt0IX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5DTIzfoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IkgvsVXg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6StUXoOj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2MjhbiqI_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2MjhbiqI_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_WRuqEYgk, 1, m, &cDelay_WRuqEYgk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ObjYnesn_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_WRuqEYgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_WRuqEYgk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aPGjyKqM, 0, m, &cIf_aPGjyKqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2MjhbiqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_WRuqEYgk, 0, m, &cDelay_WRuqEYgk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ObjYnesn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_WRuqEYgk, 0, m, &cDelay_WRuqEYgk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nqBpyMM4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y4PQg7tu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jkFWc8j0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZT2ahIw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OSJPGpix_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9vTiBPON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OSJPGpix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aPGjyKqM, 1, m, &cIf_aPGjyKqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9vTiBPON_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6StUXoOj_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jkFWc8j0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5DTIzfoY, 0, m, &cIf_5DTIzfoY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_y4PQg7tu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5DTIzfoY, 1, m, &cIf_5DTIzfoY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IkgvsVXg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yn7gINbm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9yqmt0IX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yn7gINbm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_F0Pr3G6M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lksJEWty_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_pyBJCfJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WgYVMAMN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n3uxySse_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Hltxi1In_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Hltxi1In_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_4cJDDfvn, 1, m, &cDelay_4cJDDfvn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HrNzklzZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_4cJDDfvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_4cJDDfvn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_F0Pr3G6M, 0, m, &cIf_F0Pr3G6M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Hltxi1In_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_4cJDDfvn, 0, m, &cDelay_4cJDDfvn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_HrNzklzZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_4cJDDfvn, 0, m, &cDelay_4cJDDfvn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iqEmiDrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AgMOSNm6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xB5bhnif_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vVJKGutk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CjTEUiC1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_U3JOq38j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_U3JOq38j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_n3uxySse_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CjTEUiC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F0Pr3G6M, 1, m, &cIf_F0Pr3G6M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AgMOSNm6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pyBJCfJ6, 1, m, &cIf_pyBJCfJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xB5bhnif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pyBJCfJ6, 0, m, &cIf_pyBJCfJ6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WgYVMAMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EhzHw3xI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lksJEWty_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EhzHw3xI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jQ6ZgSnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H1FdBP9o_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oSM8srbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_RvUd4Fo3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HTjy0tZn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_jC1lYfGU_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_jC1lYfGU_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6rZgGBfX, 1, m, &cDelay_6rZgGBfX_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mK4VkLtQ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6rZgGBfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6rZgGBfX, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jQ6ZgSnm, 0, m, &cIf_jQ6ZgSnm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jC1lYfGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rZgGBfX, 0, m, &cDelay_6rZgGBfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mK4VkLtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6rZgGBfX, 0, m, &cDelay_6rZgGBfX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ChKmX9mt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5b8VnhoY_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0jNf9c9B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mLfJpYEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1QBr9gU7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WkI3MMb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1QBr9gU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jQ6ZgSnm, 1, m, &cIf_jQ6ZgSnm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WkI3MMb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HTjy0tZn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0jNf9c9B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oSM8srbh, 0, m, &cIf_oSM8srbh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5b8VnhoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oSM8srbh, 1, m, &cIf_oSM8srbh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RvUd4Fo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_27HAHVZx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H1FdBP9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_27HAHVZx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qAmOgJBF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jMAyNg0d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_q8Lbrrhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_kvwfkK40_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L5utmUMi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XeexyOsL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XeexyOsL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Anm6lByl, 1, m, &cDelay_Anm6lByl_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GGwCvfSP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Anm6lByl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Anm6lByl, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qAmOgJBF, 0, m, &cIf_qAmOgJBF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XeexyOsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Anm6lByl, 0, m, &cDelay_Anm6lByl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GGwCvfSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Anm6lByl, 0, m, &cDelay_Anm6lByl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_caUzlGJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_84y62tVI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uji7NaQd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tHI7GUcv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9piNbjgv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qtwN37jj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qtwN37jj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_L5utmUMi_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9piNbjgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qAmOgJBF, 1, m, &cIf_qAmOgJBF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_84y62tVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q8Lbrrhw, 1, m, &cIf_q8Lbrrhw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uji7NaQd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_q8Lbrrhw, 0, m, &cIf_q8Lbrrhw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kvwfkK40_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W81k2cl1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jMAyNg0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W81k2cl1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tKe3ZR8S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i7Ei9T7w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Vp8UE44f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_8SpYjk3r_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hv6fk9Zd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5rBNYx3m_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5rBNYx3m_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9iEZI6mE, 1, m, &cDelay_9iEZI6mE_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_872F5A8P_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9iEZI6mE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9iEZI6mE, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tKe3ZR8S, 0, m, &cIf_tKe3ZR8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5rBNYx3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9iEZI6mE, 0, m, &cDelay_9iEZI6mE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_872F5A8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9iEZI6mE, 0, m, &cDelay_9iEZI6mE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GmwS9mis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E4bCyLzg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WdGDgjTL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_w0676Y6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6LPbNrP2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1g9WkcTw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1g9WkcTw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hv6fk9Zd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_6LPbNrP2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tKe3ZR8S, 1, m, &cIf_tKe3ZR8S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WdGDgjTL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vp8UE44f, 0, m, &cIf_Vp8UE44f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E4bCyLzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Vp8UE44f, 1, m, &cIf_Vp8UE44f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8SpYjk3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QSV7jF2H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i7Ei9T7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QSV7jF2H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_mDS9s5kJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0biwQZ8F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_MxJQpHzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_XIJjvglb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YiwkU4vD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0XcgquWq_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0XcgquWq_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ZVglQOX6, 1, m, &cDelay_ZVglQOX6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gadUlmfC_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ZVglQOX6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ZVglQOX6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_mDS9s5kJ, 0, m, &cIf_mDS9s5kJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0XcgquWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZVglQOX6, 0, m, &cDelay_ZVglQOX6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gadUlmfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ZVglQOX6, 0, m, &cDelay_ZVglQOX6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IVcMobpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9n0dmP66_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NxpX9cD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TrTnGnjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ogPVfOes_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fqK0ob7N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ogPVfOes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mDS9s5kJ, 1, m, &cIf_mDS9s5kJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fqK0ob7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_YiwkU4vD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9n0dmP66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MxJQpHzA, 1, m, &cIf_MxJQpHzA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NxpX9cD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MxJQpHzA, 0, m, &cIf_MxJQpHzA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XIJjvglb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VBzNERzf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0biwQZ8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VBzNERzf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bjvD5pzo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zxvG6ary_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2MDvYOKJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Dfxe6YxP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kPVm8A7S_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ySmrDTjZ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ySmrDTjZ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7qHktjYJ, 1, m, &cDelay_7qHktjYJ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pNtVMTnW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7qHktjYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7qHktjYJ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bjvD5pzo, 0, m, &cIf_bjvD5pzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ySmrDTjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7qHktjYJ, 0, m, &cDelay_7qHktjYJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pNtVMTnW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7qHktjYJ, 0, m, &cDelay_7qHktjYJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EyYIsNfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gdp05Jz8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hu9sMwfu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZWtJ47lS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TvcObVbL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_p26bhQmX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TvcObVbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bjvD5pzo, 1, m, &cIf_bjvD5pzo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_p26bhQmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kPVm8A7S_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_gdp05Jz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2MDvYOKJ, 1, m, &cIf_2MDvYOKJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Hu9sMwfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2MDvYOKJ, 0, m, &cIf_2MDvYOKJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Dfxe6YxP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G7K66R7F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zxvG6ary_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_G7K66R7F, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_P93jrOjv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_xaGEhgsS_sendMessage(_c, 0, m);
  cMsg_8oKf7MCR_sendMessage(_c, 0, m);
  cMsg_X0S5Cz6b_sendMessage(_c, 0, m);
  cMsg_l4JmHxu0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w9JYzMRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_xaGEhgsS_sendMessage(_c, 0, m);
  cMsg_NX4sjDUa_sendMessage(_c, 0, m);
  cMsg_waXptsB0_sendMessage(_c, 0, m);
  cMsg_jnDqwxZO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7Wf4oOYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_QmiJMMoi_sendMessage(_c, 0, m);
  cMsg_NX4sjDUa_sendMessage(_c, 0, m);
  cMsg_l4JmHxu0_sendMessage(_c, 0, m);
  cMsg_z94pG6D2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WzoPFRzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_QmiJMMoi_sendMessage(_c, 0, m);
  cMsg_QH4j23wk_sendMessage(_c, 0, m);
  cMsg_X0S5Cz6b_sendMessage(_c, 0, m);
  cMsg_d0TC2CzG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DycW4dSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_fhuK8kYC_sendMessage(_c, 0, m);
  cMsg_jnDqwxZO_sendMessage(_c, 0, m);
  cMsg_VRrBEaRe_sendMessage(_c, 0, m);
  cMsg_X0S5Cz6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JhSH8RTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_fhuK8kYC_sendMessage(_c, 0, m);
  cMsg_d0TC2CzG_sendMessage(_c, 0, m);
  cMsg_NX4sjDUa_sendMessage(_c, 0, m);
  cMsg_ozTZZHaJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OEwGLjQk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GBvJDm7k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5kuTyKON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ChgnTYNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_GBvJDm7k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5kuTyKON_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XCG2Wdt9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DJZpp3FX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WQrW4QZ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QB14IaWI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DJZpp3FX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WQrW4QZ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QMTC2usi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iApewQD2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CcQxsWan_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cht3h17D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iApewQD2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CcQxsWan_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xaGEhgsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_OEwGLjQk_sendMessage(_c, 0, m);
  cMsg_QB14IaWI_sendMessage(_c, 0, m);
  cMsg_cht3h17D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QmiJMMoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_ChgnTYNz_sendMessage(_c, 0, m);
  cMsg_XCG2Wdt9_sendMessage(_c, 0, m);
  cMsg_cht3h17D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fhuK8kYC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_ChgnTYNz_sendMessage(_c, 0, m);
  cMsg_QB14IaWI_sendMessage(_c, 0, m);
  cMsg_QMTC2usi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_2cpUuWO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C8URDtr8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rCpZVfmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4r4fipk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C8URDtr8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rCpZVfmI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gLZx1ku8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sBEwOErw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jELwvfg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zJvisBcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sBEwOErw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jELwvfg1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iOz0azIk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZT2ahIw0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nqBpyMM4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GGwRx3He_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZT2ahIw0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nqBpyMM4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NX4sjDUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_4r4fipk5_sendMessage(_c, 0, m);
  cMsg_zJvisBcE_sendMessage(_c, 0, m);
  cMsg_GGwRx3He_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8oKf7MCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_4r4fipk5_sendMessage(_c, 0, m);
  cMsg_gLZx1ku8_sendMessage(_c, 0, m);
  cMsg_iOz0azIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QH4j23wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_2cpUuWO1_sendMessage(_c, 0, m);
  cMsg_zJvisBcE_sendMessage(_c, 0, m);
  cMsg_iOz0azIk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EyFqgNZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w0676Y6n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GmwS9mis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UDTxbeI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_w0676Y6n_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GmwS9mis_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8qjldHn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TrTnGnjK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IVcMobpI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NhabYzjr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TrTnGnjK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_IVcMobpI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7ljPNnq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZWtJ47lS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EyYIsNfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wmmRmj1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZWtJ47lS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EyYIsNfH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_d0TC2CzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_EyFqgNZ1_sendMessage(_c, 0, m);
  cMsg_NhabYzjr_sendMessage(_c, 0, m);
  cMsg_wmmRmj1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jnDqwxZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_UDTxbeI9_sendMessage(_c, 0, m);
  cMsg_8qjldHn1_sendMessage(_c, 0, m);
  cMsg_wmmRmj1y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_l4JmHxu0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_UDTxbeI9_sendMessage(_c, 0, m);
  cMsg_NhabYzjr_sendMessage(_c, 0, m);
  cMsg_7ljPNnq6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xKx7rxev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vVJKGutk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iqEmiDrY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hWUjhkri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vVJKGutk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iqEmiDrY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pDKtvHqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mLfJpYEr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ChKmX9mt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8rstBSyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mLfJpYEr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ChKmX9mt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nPG8vIDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tHI7GUcv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_caUzlGJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_opMIkBHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_tHI7GUcv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_caUzlGJZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X0S5Cz6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_hWUjhkri_sendMessage(_c, 0, m);
  cMsg_8rstBSyH_sendMessage(_c, 0, m);
  cMsg_opMIkBHM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_waXptsB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_hWUjhkri_sendMessage(_c, 0, m);
  cMsg_pDKtvHqK_sendMessage(_c, 0, m);
  cMsg_nPG8vIDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ozTZZHaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_xKx7rxev_sendMessage(_c, 0, m);
  cMsg_pDKtvHqK_sendMessage(_c, 0, m);
  cMsg_opMIkBHM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_VRrBEaRe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_2cpUuWO1_sendMessage(_c, 0, m);
  cMsg_gLZx1ku8_sendMessage(_c, 0, m);
  cMsg_GGwRx3He_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_z94pG6D2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_xKx7rxev_sendMessage(_c, 0, m);
  cMsg_8rstBSyH_sendMessage(_c, 0, m);
  cMsg_nPG8vIDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_P1QL84Ba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V9JANMLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_m56BQJje_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_szTAJL7Q, 0, m, &cSlice_szTAJL7Q_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MVeo9Qaa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_szTAJL7Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_1ef1Udl2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_1ef1Udl2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_wHMFqTiz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1ef1Udl2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_1ef1Udl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wEYLFMR3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_i8BdvX1n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_68rd1tyf, 0, m, &cSlice_68rd1tyf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0zt3nuFs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_68rd1tyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f8Sz0P7v_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f8Sz0P7v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_x6bIDSh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f8Sz0P7v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f8Sz0P7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3je2GmWY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0zt3nuFs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_RtfqXZRh, 0, m, &cSlice_RtfqXZRh_sendMessage);
      break;
    }
    default: {
      cSwitchcase_m56BQJje_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_RtfqXZRh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fbFjka7H_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fbFjka7H_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_TfZTuRjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fbFjka7H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fbFjka7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LlhZ5U3D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MVeo9Qaa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_uP2nxlFY, 0, m, &cSlice_uP2nxlFY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ClDPrXul_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_uP2nxlFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bg3TnxVV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bg3TnxVV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pks8Tx2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bg3TnxVV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_bg3TnxVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zGJBmRbb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ClDPrXul_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q0otuQlk, 0, m, &cSlice_q0otuQlk_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5MaMlo26_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_q0otuQlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_KJTCc7fI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_KJTCc7fI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Lu7se2NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KJTCc7fI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_KJTCc7fI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_p6wgRulk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Su0LAuER_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7gVtlA88_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7gVtlA88_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_09g6TlNs, 1, m, &cDelay_09g6TlNs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PwFMpt18_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_09g6TlNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_09g6TlNs, m);
  cMsg_5Lcb9lHJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7gVtlA88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_09g6TlNs, 0, m, &cDelay_09g6TlNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PwFMpt18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_09g6TlNs, 0, m, &cDelay_09g6TlNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_ZDY7xU5a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ilX497I3, HV_BINOP_SUBTRACT, 0, m, &cBinop_ilX497I3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_2RJRKEI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p9TBWNnE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_QUHuOKPq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p9TBWNnE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_rdO8K1Wn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZDY7xU5a, 0, m, &cVar_ZDY7xU5a_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_pARMQSOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZaFMKCYP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mL63FaKR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SbXzJNSJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ilX497I3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zmlMRyZe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zmlMRyZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yo7vWP60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yo7vWP60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_MXcdOQfV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4Xdlcem8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mlxUGUnq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ZamEps2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mlxUGUnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2RJRKEI0, 1, m, &cIf_2RJRKEI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9ZamEps2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sQ7PaS08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BGxDHvj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QUHuOKPq, 1, m, &cIf_QUHuOKPq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sQ7PaS08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_2RJRKEI0, 0, m, &cIf_2RJRKEI0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MXcdOQfV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QUHuOKPq, 0, m, &cIf_QUHuOKPq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SbXzJNSJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZDY7xU5a, 0, m, &cVar_ZDY7xU5a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZaFMKCYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_mL63FaKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ilX497I3, HV_BINOP_SUBTRACT, 1, m, &cBinop_ilX497I3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_p9TBWNnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZLv5Oz5S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_5MaMlo26_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HmXhKBuT, 0, m, &cSlice_HmXhKBuT_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HmXhKBuT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JH4exaqD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JH4exaqD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3Ib33IVH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JH4exaqD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_JH4exaqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Wld2ApVS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jkauN78I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MaiJM1Ul, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OW3VbY1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_e0qFycQ2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_P8FC9txX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8KOaKqxu, 0, m, &cVar_8KOaKqxu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_V9JANMLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ysdqPJbW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_e9RmWFlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Su0LAuER_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_KgNX1WjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c7fSA3ZS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5Lcb9lHJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EHB8fYs2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_c7fSA3ZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EHB8fYs2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ccPDkSHY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_yJvD9GQ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yJvD9GQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_skxRM7bk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_skxRM7bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UmUlPt9H, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_UEkV0KYU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j17kBKO3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6dnXM9ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jv48CbCv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_AgfrkVZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2EQzk9zq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GHugsdU8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8uJ8JjAs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_Uv43SMhJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hnlavMnv, 0, m, &cVar_hnlavMnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bCMBxmdZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YGwYQj0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MTy3uzGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jGGqHBwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_dq9SGiVh, 0, m, &cVar_dq9SGiVh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sIGJ5JNk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_5wID3qSA, 0, m, &cVar_5wID3qSA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_T20VTnHs, 0, m, &cVar_T20VTnHs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WUyZb1WY, 0, m, &cVar_WUyZb1WY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W2mimA4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Uv43SMhJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rXf2F1mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oY0HoT85_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PjFc48IY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nEKweOm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oY0HoT85_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PjFc48IY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XqGncrDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oY0HoT85_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PjFc48IY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HNvaJQYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oY0HoT85_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PjFc48IY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ryCzoY4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_oY0HoT85_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_PjFc48IY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Uciz3Fyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_pgsemKKD, 0, m, &cVar_pgsemKKD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K4z8Tpwe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_mRKCC2EJ, 0, m, &cVar_mRKCC2EJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KhcheFgM, 0, m, &cVar_KhcheFgM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_r0UQmc3K, 0, m, &cVar_r0UQmc3K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xXRPZnpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_XirIbTfe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_u3WKWto3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_XJOD8dFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AKUGMb8s, 0, m, &cVar_AKUGMb8s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NX9GyhCM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5JThlayv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dRgodUTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NHh2s4Jo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_MLugZl8h, 0, m, &cVar_MLugZl8h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DLz1DNEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_8QjcTkCA, 0, m, &cVar_8QjcTkCA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bHBLs69x, 0, m, &cVar_bHBLs69x_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9geuDKnv, 0, m, &cVar_9geuDKnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NWvKLewm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XJOD8dFn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pwuW1vq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qFzbgAr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ss1JTRHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_w41tvi7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_diChbwFY, 0, m, &cVar_diChbwFY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7TaHn0VL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6IROini1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YX3amzw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2TznE6r8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_EED9v9Tb, 0, m, &cVar_EED9v9Tb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_71x1OPNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_isXZ5kbl, 0, m, &cVar_isXZ5kbl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5zgOyVQm, 0, m, &cVar_5zgOyVQm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sX8KNmK8, 0, m, &cVar_sX8KNmK8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2K9PiSCT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_w41tvi7v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0xNFUowu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_obWoEtcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_UEkV0KYU, 0, m, &cVar_UEkV0KYU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j17kBKO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_zd6L1uXp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_fRPGCpMW_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_6i1WTZ2P_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FiTv4jMA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_6dnXM9ij, 0, m, &cVar_6dnXM9ij_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Jv48CbCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_r5sFwmWy_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Z9WLXEF8_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_t7hkZ48H_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_P6NuhA4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_AgfrkVZs, 0, m, &cVar_AgfrkVZs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2EQzk9zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PetB1rTE_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_aPCUZvk1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_i8BdvX1n_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_9wiP7ccS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4fL4ffWr_sendMessage(_c, 0, m);
  cMsg_2y7EIOfq_sendMessage(_c, 0, m);
  cMsg_VUVwKAGd_sendMessage(_c, 0, m);
  cMsg_RFlsZfWY_sendMessage(_c, 0, m);
  cMsg_4etSKqg1_sendMessage(_c, 0, m);
  cMsg_A7fPKVDP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_00XZKX25, 0, m, &cVar_00XZKX25_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_waDHxliF, 0, m, &cVar_waDHxliF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1kQ4UZ5P, 0, m, &cVar_1kQ4UZ5P_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WtTLrH5T, 0, m, &cVar_WtTLrH5T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Mho8f2UX, 0, m, &cVar_Mho8f2UX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CpgAvpV8, 0, m, &cVar_CpgAvpV8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SKMhT36u, 0, m, &cVar_SKMhT36u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iiOc5bOy, 0, m, &cVar_iiOc5bOy_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kBYw6i5F, 0, m, &cVar_kBYw6i5F_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jHrluBJ9, 0, m, &cVar_jHrluBJ9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pQOymYDR, 0, m, &cVar_pQOymYDR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EPMAoYsw, 0, m, &cVar_EPMAoYsw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UZIZ2knu, 0, m, &cVar_UZIZ2knu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qSnwDKV4, 0, m, &cVar_qSnwDKV4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ppFs5YQH, 0, m, &cVar_ppFs5YQH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fOccWZGA, 0, m, &cVar_fOccWZGA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_c8b1YwNa, 0, m, &cVar_c8b1YwNa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Fu2LmynN, 0, m, &cVar_Fu2LmynN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nM24sZTx, 0, m, &cVar_nM24sZTx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KmJueRo3, 0, m, &cVar_KmJueRo3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GZUqHJN5, 0, m, &cVar_GZUqHJN5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Om6pUeqF, 0, m, &cVar_Om6pUeqF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_W8YE5yJs, 0, m, &cVar_W8YE5yJs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PnnM8CbE, 0, m, &cVar_PnnM8CbE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TS6pQRih, 0, m, &cVar_TS6pQRih_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ul0MPTVW, 0, m, &cVar_ul0MPTVW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ovACBqFA, 0, m, &cVar_ovACBqFA_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ji9ULSjz, 0, m, &cVar_ji9ULSjz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yzhsnxr9, 0, m, &cVar_yzhsnxr9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_I0wGVO4T, 0, m, &cVar_I0wGVO4T_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x4gtU1xv, 0, m, &cVar_x4gtU1xv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WZkWRE5C, 0, m, &cVar_WZkWRE5C_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kBbkJEa1, 0, m, &cVar_kBbkJEa1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PQV3UZge, 0, m, &cVar_PQV3UZge_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hcm46hWq, 0, m, &cVar_hcm46hWq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jJ7jhHrn, 0, m, &cVar_jJ7jhHrn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tqZVNR8g, 0, m, &cVar_tqZVNR8g_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mpJkPYs5, 0, m, &cVar_mpJkPYs5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GTBB6NiB, 0, m, &cVar_GTBB6NiB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IzOwrsre, 0, m, &cVar_IzOwrsre_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8n9384mf, 0, m, &cVar_8n9384mf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WhETMERJ, 0, m, &cVar_WhETMERJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Maw2L9fN, 0, m, &cVar_Maw2L9fN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E2jOiNms, 0, m, &cVar_E2jOiNms_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SSYtOPBt, 0, m, &cVar_SSYtOPBt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kmQvQPPU, 0, m, &cVar_kmQvQPPU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FyQTiD4e, 0, m, &cVar_FyQTiD4e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pF2IPUHe, 0, m, &cVar_pF2IPUHe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qPWYcVBN, 0, m, &cVar_qPWYcVBN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nxxCnwoS, 0, m, &cVar_nxxCnwoS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9TtqVedg, 0, m, &cVar_9TtqVedg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_4AtlXus5, 0, m, &cVar_4AtlXus5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wHMFqTiz, 0, m, &cVar_wHMFqTiz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_x6bIDSh8, 0, m, &cVar_x6bIDSh8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TfZTuRjH, 0, m, &cVar_TfZTuRjH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pks8Tx2u, 0, m, &cVar_pks8Tx2u_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Lu7se2NK, 0, m, &cVar_Lu7se2NK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3Ib33IVH, 0, m, &cVar_3Ib33IVH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BjRVFyB7, 0, m, &cVar_BjRVFyB7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Hoy6B2JM, 0, m, &cVar_Hoy6B2JM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ckMqw03o, 0, m, &cVar_ckMqw03o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5xesWBUg_sendMessage);
  cMsg_K4z8Tpwe_sendMessage(_c, 0, m);
  cMsg_Uciz3Fyx_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2fQ6u9ZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1K1AHZAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_weYc8keV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mRKCC2EJ, 0, m, &cVar_mRKCC2EJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6DArWdMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KhcheFgM, 0, m, &cVar_KhcheFgM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_abnKStkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_r0UQmc3K, 0, m, &cVar_r0UQmc3K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vZcqokvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_waDHxliF, 0, m, &cVar_waDHxliF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_D3LWVS22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n9mMcYOT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VQFC7TzR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ihGn3IwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6ygDaFDP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WqLRUok5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_S5w5Nx7H_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1yqR9uir_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bZnrJ2aS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W7G4p1uR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QNR2zsAZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pKuVHWdM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YR678Vjf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_obAjhLyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yU93IP2a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BDVQCuU0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n5oH3P52_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8NuEoO7d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_L1L7pcgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HmOB5Cu4, HV_BINOP_MULTIPLY, 0, m, &cBinop_HmOB5Cu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PAOSmNSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OsMxfPnY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pyTpbA1I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_B6S9kgbG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Ny8RykrW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_l9J3n0mO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_syK4Al9T_sendMessage);
  cMsg_ApMt1m8M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_hTuANUHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g4OcvHgw, HV_BINOP_MULTIPLY, 0, m, &cBinop_g4OcvHgw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9MPY4t7t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3ewJvZom_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_S3qyPif5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3KGSQBxa, HV_BINOP_MULTIPLY, 1, m, &cBinop_3KGSQBxa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4yuGsYiu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pIlXa0F9_sendMessage);
  cMsg_I59MLcUu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_EsRNtRUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XLpTnhGW, HV_BINOP_MULTIPLY, 0, m, &cBinop_XLpTnhGW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NrFmEcZR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_74BlYElW_sendMessage(_c, 0, m);
  cMsg_L9nXdhYN_sendMessage(_c, 0, m);
  cMsg_bHt3OXcm_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_I0UReeWJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FFIwsnzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qCRvYiDs_sendMessage);
  cMsg_YwkZ3nAG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_RIydixWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Mho8f2UX, 0, m, &cVar_Mho8f2UX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_URmIZkZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KdQ2A6eA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vMoULiZQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vlkKGr3V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_chaSnXVR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YyxY6KUV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LrylYC9j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rJVrBc0K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hzxOqVe2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dWmPQleE_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dngVU6yH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4c5GOKGW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TOuYYeVM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Pxdrq2Ev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_thBmz0Zj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BqjuxxD6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mojRlTD7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iZV1KHLs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GqD03T1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qu8uTKyQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qu8uTKyQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AvEzp8rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RvqPRKp4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_hrW1Jrok_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YHcTvvDx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_UH3KAy9H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BS6BACjK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rEoxyKxx_sendMessage);
  cMsg_Oe3gDVG2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_IqXDorA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oZBzaPd9, HV_BINOP_MULTIPLY, 0, m, &cBinop_oZBzaPd9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_a8EUIwAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Yy1JoCkL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_z2yMyDJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N7StKpq8, HV_BINOP_MULTIPLY, 1, m, &cBinop_N7StKpq8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_R7SmGEb5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_EzFhyldx_sendMessage);
  cMsg_02bsHDhP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_n4MlYepK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bNsRH78T, HV_BINOP_MULTIPLY, 0, m, &cBinop_bNsRH78T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_koDzYlI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RdsmhSs9_sendMessage(_c, 0, m);
  cMsg_R0REf1UB_sendMessage(_c, 0, m);
  cMsg_fmIn6LBl_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_07zBXabU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bWNWbxuY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_IHPOcEJe_sendMessage);
  cMsg_gGespWi8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_0x73W7fX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pgsemKKD, 0, m, &cVar_pgsemKKD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_6r4FsIOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0LoEddKJ, 0, m, &cVar_0LoEddKJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qUl8jZPl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dq9SGiVh, 0, m, &cVar_dq9SGiVh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_oR3v4xWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5wID3qSA, 0, m, &cVar_5wID3qSA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ezFVH3Px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T20VTnHs, 0, m, &cVar_T20VTnHs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_d743fjkq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WUyZb1WY, 0, m, &cVar_WUyZb1WY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_pjSnzgBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_Uv43SMhJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SYVexDWb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Vx6spxHo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aci8luP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_kLmapVVQ, 0, m, &cVar_kLmapVVQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jEgHlgTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IJNhhYMG, 0, m, &cVar_IJNhhYMG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gJMmQPOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ZldRKBAc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KCpHR8bu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1UC6ektG_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mYU5EGCq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GFYSDhpk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cXIVHbqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_d0HHSZXu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_851ahAXU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_D0WYEijN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BfyWXQzb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_VSJBwof0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6Qn9NPUQ, 0, m, &cVar_6Qn9NPUQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_GoQSXUaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1NWRpcQi, 0, m, &cVar_1NWRpcQi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BEZZKpmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_sVjRXECF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AAejjQgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_bNIw97ch_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D8WEBMQf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Cl5K8Oh6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_9Gnu0cJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NaK3G62I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_TXssnfiF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UpoWkETq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SxFFhPP5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_eH6F7lT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_8cfHnNAu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KZgk1hX0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LTh5dVCk, 0, m, &cVar_LTh5dVCk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yNRczHMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1971RmlP, 0, m, &cVar_1971RmlP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uy5RmBRx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_wos4fw5S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_suRHW43E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_g7MV9OUy_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3O4SByHV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NZI0vmke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aCJAnbdz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_k2He1sMP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_4t30uJ7r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kiR8H1iF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o1c9EmSe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_duR5cfRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GqqfnJHt, 0, m, &cVar_GqqfnJHt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iI2XUKFE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oGE9u2C5, 0, m, &cVar_oGE9u2C5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gpfBI8BS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_ZhbnMsuJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_A2FK1ODP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DlhQVYex_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_agygZshf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xWkVb3sC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QveBqcDq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nfHgL6Yz_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vEzqxXun_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_l9JGzCyB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dC3BC2lW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_9DSiBSsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8trWV5Be, 0, m, &cVar_8trWV5Be_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_YwZ4klC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MLugZl8h, 0, m, &cVar_MLugZl8h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2wiBU3Pe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_8QjcTkCA, 0, m, &cVar_8QjcTkCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_uQz4jh2s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bHBLs69x, 0, m, &cVar_bHBLs69x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zvu5s0go_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9geuDKnv, 0, m, &cVar_9geuDKnv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_KUvXBV7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XJOD8dFn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NMQgjnvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_oC7OUAzZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_R0v8YieQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KQ6SCaMz, 0, m, &cVar_KQ6SCaMz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_HEv3ahud_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ecqVXXSx, 0, m, &cVar_ecqVXXSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_oYOf0XBm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_n6NvvY5k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PfjCDOXA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jRsTWqBV_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qIC9gFqF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a1bloxQZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_AIypy3CX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Cs7TQqi1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_x7S6KyPm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LunKUzOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_febq9D5K_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_wEYLFMR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3ce3BwXr, 0, m, &cVar_3ce3BwXr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zGJBmRbb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_P1QL84Ba, 0, m, &cVar_P1QL84Ba_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_LlhZ5U3D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_P8FC9txX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3je2GmWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_RsTwFR0t_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KgNX1WjC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_e9RmWFlR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_p6wgRulk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_4Xdlcem8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_BGxDHvj2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Wld2ApVS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ccPDkSHY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_KpGiKDKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FVrlnGwY, 0, m, &cVar_FVrlnGwY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_wcFf1X32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EED9v9Tb, 0, m, &cVar_EED9v9Tb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dAC1LKHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_isXZ5kbl, 0, m, &cVar_isXZ5kbl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7md1AKdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5zgOyVQm, 0, m, &cVar_5zgOyVQm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_kCLi75KY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_sX8KNmK8, 0, m, &cVar_sX8KNmK8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_DN74hq6m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_w41tvi7v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_eJxoqp0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UEkV0KYU, 0, m, &cVar_UEkV0KYU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_mn84inKY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6dnXM9ij, 0, m, &cVar_6dnXM9ij_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nWQgjPbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_AgfrkVZs, 0, m, &cVar_AgfrkVZs_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_0HucXN3z, VOf(Bf0));
    __hv_line_f(&sLine_nDMOLc3m, VOf(Bf1));
    __hv_line_f(&sLine_BYH4uA5Y, VOf(Bf2));
    __hv_line_f(&sLine_PXg2JSPZ, VOf(Bf3));
    __hv_line_f(&sLine_s6oSb9gt, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_LthPhTIT, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_e8xxJOS0, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_PbDBYzb8, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_5I6MSQ4v, VOf(Bf1));
    __hv_line_f(&sLine_H7sQ16gl, VOf(Bf0));
    __hv_line_f(&sLine_xX4wplt8, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_xctzSyh3, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_tL7mhmue, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_m0KcAdht, VOf(Bf5));
    __hv_line_f(&sLine_S0f2ihLX, VOf(Bf1));
    __hv_line_f(&sLine_0PbuoEW9, VOf(Bf2));
    __hv_line_f(&sLine_P71gEBTC, VOf(Bf4));
    __hv_line_f(&sLine_DBFz2biW, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_zGONn4Mv, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_2TA6eTbV, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_YtZgQT4O, VOf(Bf6));
    __hv_line_f(&sLine_DDscuPlK, VOf(Bf2));
    __hv_line_f(&sLine_Qq0cSRym, VOf(Bf1));
    __hv_line_f(&sLine_iORoK5K4, VOf(Bf5));
    __hv_line_f(&sLine_UUagzppM, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_gFbCgZ6o, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_7xxPHLLZ, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_6iY1H8Kd, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_cjEFPaVo, VOf(Bf2));
    __hv_line_f(&sLine_PZUJhcZk, VOf(Bf6));
    __hv_line_f(&sLine_lWkhNk3t, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_ISk06CUF, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_hQFqWAMI, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_LLrVIbIJ, VOf(Bf8));
    __hv_line_f(&sLine_PvYeXCpk, VOf(Bf2));
    __hv_line_f(&sLine_kBsVJ50Q, VOf(Bf1));
    __hv_line_f(&sLine_b1AdTQDL, VOf(Bf7));
    __hv_line_f(&sLine_9SDkS5Mb, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_JqCaNrYb, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_o1AaAOB1, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_v3j5zxfP, VIf(Bf0));
    __hv_varwrite_f(&sVarf_t2gtX5Et, VIf(Bf6));
    __hv_varwrite_f(&sVarf_jCs1f6uB, VIf(Bf4));
    __hv_varwrite_f(&sVarf_7TjGDr1I, VIf(Bf7));
    __hv_varread_f(&sVarf_CQNAGpX3, VOf(Bf7));
    __hv_varread_f(&sVarf_kpdvl9H7, VOf(Bf4));
    __hv_varread_f(&sVarf_yMXszRg7, VOf(Bf6));
    __hv_varread_f(&sVarf_1CP6RK4K, VOf(Bf0));
    __hv_varread_f(&sVarf_TP6IwKxB, VOf(Bf9));
    __hv_varread_f(&sVarf_Gi1tVZFZ, VOf(Bf1));
    __hv_line_f(&sLine_pY30rcy8, VOf(Bf2));
    __hv_line_f(&sLine_xQHU0Epf, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_yMXszRg7, VIf(Bf7));
    __hv_varwrite_f(&sVarf_TP6IwKxB, VIf(Bf4));
    __hv_varread_f(&sVarf_8N3UFzjd, VOf(Bf2));
    __hv_varread_f(&sVarf_MZyS91H1, VOf(Bf9));
    __hv_varread_f(&sVarf_X3T2mwvT, VOf(Bf1));
    __hv_varread_f(&sVarf_jMIgMWJj, VOf(Bf6));
    __hv_varread_f(&sVarf_rCfEko39, VOf(Bf10));
    __hv_varread_f(&sVarf_7D8hlm6R, VOf(Bf11));
    __hv_varread_f(&sVarf_aHGqMzcp, VOf(Bf12));
    __hv_varwrite_f(&sVarf_SYWXqxEb, VIf(Bf7));
    __hv_varread_f(&sVarf_rVA2MQZE, VOf(Bf13));
    __hv_line_f(&sLine_8BOBNoKg, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_cBp4Z6Yk, VOf(Bf15));
    __hv_line_f(&sLine_qYrhfA9V, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_H2ncCDNp, VOf(Bf14));
    __hv_line_f(&sLine_rv7q04gf, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_jMIgMWJj, VIf(Bf17));
    __hv_varread_f(&sVarf_SYWXqxEb, VOf(Bf17));
    __hv_line_f(&sLine_zEks98oB, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_M8CCoqfr, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_MRRdV0yh, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_rCfEko39, VIf(Bf16));
    __hv_line_f(&sLine_2fBuFhsA, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_zG2tIeqh, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_yHlGqKyB, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_7D8hlm6R, VIf(Bf16));
    __hv_line_f(&sLine_zDS0866T, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_ZUn0YUQJ, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_hkYgUgXE, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_aHGqMzcp, VIf(Bf16));
    __hv_varwrite_f(&sVarf_rVA2MQZE, VIf(Bf2));
    __hv_varwrite_f(&sVarf_cBp4Z6Yk, VIf(Bf9));
    __hv_varwrite_f(&sVarf_H2ncCDNp, VIf(Bf1));
    sEnv_process(this, &sEnv_GgxBQ18X, VIf(Bf6), &sEnv_GgxBQ18X_sendMessage);
    sEnv_process(this, &sEnv_rrgeOUly, VIf(Bf7), &sEnv_rrgeOUly_sendMessage);
    __hv_line_f(&sLine_wqpsTZL8, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_2fOMXUgw, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_b6Qfohmy, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_s22xOvfK, VOf(Bf6));
    __hv_line_f(&sLine_Ebb8WwMA, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_8N3UFzjd, VIf(Bf9));
    __hv_varwrite_f(&sVarf_s22xOvfK, VIf(Bf10));
    __hv_varwrite_f(&sVarf_OHNVvGam, VIf(Bf11));
    __hv_varwrite_f(&sVarf_AVBVcGaW, VIf(Bf12));
    __hv_varread_f(&sVarf_AVBVcGaW, VOf(Bf12));
    __hv_line_f(&sLine_FhWVJ0zi, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_X3T2mwvT, VIf(Bf10));
    __hv_varread_f(&sVarf_OHNVvGam, VOf(Bf10));
    __hv_line_f(&sLine_xo0QmQVi, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_MZyS91H1, VIf(Bf10));
    __hv_varwrite_f(&sVarf_1CP6RK4K, VIf(Bf7));
    __hv_varread_f(&sVarf_VIC6Yeyw, VOf(Bf7));
    __hv_varread_f(&sVarf_NKQy5d4F, VOf(Bf10));
    __hv_varread_f(&sVarf_pZiFwR7Z, VOf(Bf9));
    __hv_varread_f(&sVarf_rpQr75WJ, VOf(Bf11));
    __hv_varread_f(&sVarf_ZH9cElfP, VOf(Bf6));
    __hv_varread_f(&sVarf_hTS9VHpS, VOf(Bf12));
    __hv_varread_f(&sVarf_EBeFvJfq, VOf(Bf1));
    __hv_varwrite_f(&sVarf_6rgvdb1n, VIf(Bf4));
    __hv_varread_f(&sVarf_4GEaY3dq, VOf(Bf2));
    __hv_line_f(&sLine_o8SlLqDS, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_3dByHp3s, VOf(Bf17));
    __hv_line_f(&sLine_oMK9TRn3, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_sPb1rCyx, VOf(Bf16));
    __hv_line_f(&sLine_x6RgB9WE, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_rpQr75WJ, VIf(Bf15));
    __hv_varread_f(&sVarf_6rgvdb1n, VOf(Bf15));
    __hv_line_f(&sLine_YyQEh9u7, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_f1E1Uy1W, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_HsoUeM5i, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_ZH9cElfP, VIf(Bf13));
    __hv_line_f(&sLine_6Mt26uGm, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_I5DCrMpQ, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_ck43FXAX, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_hTS9VHpS, VIf(Bf13));
    __hv_line_f(&sLine_eDgg0PwA, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_pxW1SLgH, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_BHHkwTaM, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_EBeFvJfq, VIf(Bf13));
    __hv_varwrite_f(&sVarf_4GEaY3dq, VIf(Bf7));
    __hv_varwrite_f(&sVarf_3dByHp3s, VIf(Bf10));
    __hv_varwrite_f(&sVarf_sPb1rCyx, VIf(Bf9));
    sEnv_process(this, &sEnv_erGK5Qki, VIf(Bf11), &sEnv_erGK5Qki_sendMessage);
    sEnv_process(this, &sEnv_7ILklKDO, VIf(Bf4), &sEnv_7ILklKDO_sendMessage);
    __hv_line_f(&sLine_gfm3mWj8, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_92HnC1Vy, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_PWnysAH7, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_PltCbYt5, VOf(Bf11));
    __hv_line_f(&sLine_Lezhu0b1, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_VIC6Yeyw, VIf(Bf10));
    __hv_varwrite_f(&sVarf_PltCbYt5, VIf(Bf6));
    __hv_varwrite_f(&sVarf_5fSyx84T, VIf(Bf12));
    __hv_varwrite_f(&sVarf_znImre8P, VIf(Bf1));
    __hv_varread_f(&sVarf_znImre8P, VOf(Bf1));
    __hv_line_f(&sLine_UGLpcDgt, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_pZiFwR7Z, VIf(Bf6));
    __hv_varread_f(&sVarf_5fSyx84T, VOf(Bf6));
    __hv_line_f(&sLine_dNucvAGq, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_NKQy5d4F, VIf(Bf6));
    __hv_varwrite_f(&sVarf_Gi1tVZFZ, VIf(Bf4));
    __hv_varwrite_f(&sVarf_cZQ8Z0JD, VIf(Bf0));
    __hv_varread_f(&sVarf_v3j5zxfP, VOf(Bf0));
    __hv_varread_f(&sVarf_t2gtX5Et, VOf(Bf4));
    __hv_varread_f(&sVarf_reSAgJTx, VOf(Bf6));
    __hv_varread_f(&sVarf_vZHwAdYk, VOf(Bf10));
    __hv_varread_f(&sVarf_rMpquXcZ, VOf(Bf12));
    __hv_varread_f(&sVarf_IHRO1zR1, VOf(Bf11));
    __hv_line_f(&sLine_3xmGkRcs, VOf(Bf1));
    __hv_line_f(&sLine_VHFDXA5G, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_reSAgJTx, VIf(Bf0));
    __hv_varwrite_f(&sVarf_rMpquXcZ, VIf(Bf4));
    __hv_varread_f(&sVarf_daLK4A41, VOf(Bf1));
    __hv_varread_f(&sVarf_jqGKeCdG, VOf(Bf12));
    __hv_varread_f(&sVarf_EfO3E0Nh, VOf(Bf11));
    __hv_varread_f(&sVarf_2PkJkCUm, VOf(Bf6));
    __hv_varread_f(&sVarf_rlNO2e2l, VOf(Bf7));
    __hv_varread_f(&sVarf_eA1uXFGP, VOf(Bf13));
    __hv_varread_f(&sVarf_PENGz0ur, VOf(Bf15));
    __hv_varwrite_f(&sVarf_mI86uprW, VIf(Bf0));
    __hv_varread_f(&sVarf_uZH50O89, VOf(Bf2));
    __hv_line_f(&sLine_ajge1EVh, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_NFDfXXbV, VOf(Bf18));
    __hv_line_f(&sLine_xSRmXzF8, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_BTZ0gOrq, VOf(Bf17));
    __hv_line_f(&sLine_8CLskRsg, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_2PkJkCUm, VIf(Bf14));
    __hv_varread_f(&sVarf_mI86uprW, VOf(Bf14));
    __hv_line_f(&sLine_VHjPO0HH, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_4NevKAYw, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_qgWseyf9, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_rlNO2e2l, VIf(Bf16));
    __hv_line_f(&sLine_Oc8aIfMv, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_cebGtGv0, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_PAbkkNZ5, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_eA1uXFGP, VIf(Bf16));
    __hv_line_f(&sLine_IN6LGc5O, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_f1H87OMH, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_cS8NfZw1, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_PENGz0ur, VIf(Bf16));
    __hv_varwrite_f(&sVarf_uZH50O89, VIf(Bf1));
    __hv_varwrite_f(&sVarf_NFDfXXbV, VIf(Bf12));
    __hv_varwrite_f(&sVarf_BTZ0gOrq, VIf(Bf11));
    sEnv_process(this, &sEnv_jHkLDs2A, VIf(Bf6), &sEnv_jHkLDs2A_sendMessage);
    sEnv_process(this, &sEnv_M1ztaHkP, VIf(Bf0), &sEnv_M1ztaHkP_sendMessage);
    __hv_line_f(&sLine_Cs1Tkt1O, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_nayA95MO, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_YCcuSv6S, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_p7640zv2, VOf(Bf6));
    __hv_line_f(&sLine_BVRin6cN, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_daLK4A41, VIf(Bf12));
    __hv_varwrite_f(&sVarf_p7640zv2, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Hs9k5ie0, VIf(Bf13));
    __hv_varwrite_f(&sVarf_MfTxyNib, VIf(Bf15));
    __hv_varread_f(&sVarf_MfTxyNib, VOf(Bf15));
    __hv_line_f(&sLine_V8ZGuZjh, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_EfO3E0Nh, VIf(Bf7));
    __hv_varread_f(&sVarf_Hs9k5ie0, VOf(Bf7));
    __hv_line_f(&sLine_UY8DMc2t, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_jqGKeCdG, VIf(Bf7));
    __hv_varwrite_f(&sVarf_vZHwAdYk, VIf(Bf0));
    __hv_varread_f(&sVarf_brP5PssF, VOf(Bf0));
    __hv_varread_f(&sVarf_mOO2bNh0, VOf(Bf7));
    __hv_varread_f(&sVarf_ExPlOtyX, VOf(Bf12));
    __hv_varread_f(&sVarf_T5zZOzoK, VOf(Bf13));
    __hv_varread_f(&sVarf_0jTre8CO, VOf(Bf6));
    __hv_varread_f(&sVarf_jk2yhC6U, VOf(Bf15));
    __hv_varread_f(&sVarf_tfhlolxY, VOf(Bf11));
    __hv_varwrite_f(&sVarf_RGu9tjFE, VIf(Bf4));
    __hv_varread_f(&sVarf_kLhIEV6E, VOf(Bf1));
    __hv_line_f(&sLine_atYrB240, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_L5khhKiP, VOf(Bf14));
    __hv_line_f(&sLine_Chh7glFY, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_gbwEZ8Fz, VOf(Bf16));
    __hv_line_f(&sLine_r9UnceFd, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_T5zZOzoK, VIf(Bf18));
    __hv_varread_f(&sVarf_RGu9tjFE, VOf(Bf18));
    __hv_line_f(&sLine_lj11PxgX, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_hWSIOwf6, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_wzTPAB9p, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_0jTre8CO, VIf(Bf2));
    __hv_line_f(&sLine_nt5YWIPu, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_Fs1yZxSE, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_0sqKPS0W, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_jk2yhC6U, VIf(Bf2));
    __hv_line_f(&sLine_5TgBz0pp, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_SGgnbdf8, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_9tt20iza, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_tfhlolxY, VIf(Bf2));
    __hv_varwrite_f(&sVarf_kLhIEV6E, VIf(Bf0));
    __hv_varwrite_f(&sVarf_L5khhKiP, VIf(Bf7));
    __hv_varwrite_f(&sVarf_gbwEZ8Fz, VIf(Bf12));
    sEnv_process(this, &sEnv_Aw4s6Ktc, VIf(Bf13), &sEnv_Aw4s6Ktc_sendMessage);
    sEnv_process(this, &sEnv_6nZ2nBEy, VIf(Bf4), &sEnv_6nZ2nBEy_sendMessage);
    __hv_line_f(&sLine_uHp4Nza9, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_dSRJfNfn, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_p4jwr0K8, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_2WqyrQFu, VOf(Bf13));
    __hv_line_f(&sLine_db3rgKYx, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_brP5PssF, VIf(Bf7));
    __hv_varwrite_f(&sVarf_2WqyrQFu, VIf(Bf6));
    __hv_varwrite_f(&sVarf_7K3FzZh3, VIf(Bf15));
    __hv_varwrite_f(&sVarf_sOCEDgRB, VIf(Bf11));
    __hv_varread_f(&sVarf_sOCEDgRB, VOf(Bf11));
    __hv_line_f(&sLine_RjI3XPcd, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_ExPlOtyX, VIf(Bf6));
    __hv_varread_f(&sVarf_7K3FzZh3, VOf(Bf6));
    __hv_line_f(&sLine_ebwkwDcR, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_mOO2bNh0, VIf(Bf6));
    __hv_varwrite_f(&sVarf_IHRO1zR1, VIf(Bf4));
    __hv_varwrite_f(&sVarf_dMko461o, VIf(Bf10));
    __hv_varread_f(&sVarf_jCs1f6uB, VOf(Bf10));
    __hv_varread_f(&sVarf_7TjGDr1I, VOf(Bf4));
    __hv_varread_f(&sVarf_3Tzt07Xq, VOf(Bf6));
    __hv_varread_f(&sVarf_hPWkA7IK, VOf(Bf7));
    __hv_varread_f(&sVarf_34sa5y57, VOf(Bf15));
    __hv_varread_f(&sVarf_oHc3q8G0, VOf(Bf13));
    __hv_line_f(&sLine_9GagYI1W, VOf(Bf11));
    __hv_line_f(&sLine_n51eMeqk, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_3Tzt07Xq, VIf(Bf10));
    __hv_varwrite_f(&sVarf_34sa5y57, VIf(Bf4));
    __hv_varread_f(&sVarf_PdjVRSMo, VOf(Bf11));
    __hv_varread_f(&sVarf_NCT0qabi, VOf(Bf15));
    __hv_varread_f(&sVarf_lvZzo5gV, VOf(Bf13));
    __hv_varread_f(&sVarf_LoI82Eq5, VOf(Bf6));
    __hv_varread_f(&sVarf_GGRofFvh, VOf(Bf0));
    __hv_varread_f(&sVarf_BcVv9mHr, VOf(Bf2));
    __hv_varread_f(&sVarf_aRpoOTJd, VOf(Bf18));
    __hv_varwrite_f(&sVarf_9QnPw7FR, VIf(Bf10));
    __hv_varread_f(&sVarf_B8vSQbLW, VOf(Bf1));
    __hv_line_f(&sLine_MEFmCGvh, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_mXohqjRm, VOf(Bf19));
    __hv_line_f(&sLine_JUxH14t1, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_edH4RbO6, VOf(Bf14));
    __hv_line_f(&sLine_Yh34iFsi, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_LoI82Eq5, VIf(Bf17));
    __hv_varread_f(&sVarf_9QnPw7FR, VOf(Bf17));
    __hv_line_f(&sLine_h56eAOdX, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_4D4GoHrf, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_vci09NfC, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_GGRofFvh, VIf(Bf16));
    __hv_line_f(&sLine_lElvWhTQ, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_BNiOG6Z4, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_vj9jdnTJ, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_BcVv9mHr, VIf(Bf16));
    __hv_line_f(&sLine_tR4OpRre, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_pl8jjA4C, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_UKq8yFOZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_aRpoOTJd, VIf(Bf16));
    __hv_varwrite_f(&sVarf_B8vSQbLW, VIf(Bf11));
    __hv_varwrite_f(&sVarf_mXohqjRm, VIf(Bf15));
    __hv_varwrite_f(&sVarf_edH4RbO6, VIf(Bf13));
    sEnv_process(this, &sEnv_aLJxoS6L, VIf(Bf6), &sEnv_aLJxoS6L_sendMessage);
    sEnv_process(this, &sEnv_qKAlHCz7, VIf(Bf10), &sEnv_qKAlHCz7_sendMessage);
    __hv_line_f(&sLine_AfVr09VM, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_PGQhgIhc, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_H1gR5cIP, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_sSZ00y7Y, VOf(Bf6));
    __hv_line_f(&sLine_ZznukeWS, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_PdjVRSMo, VIf(Bf15));
    __hv_varwrite_f(&sVarf_sSZ00y7Y, VIf(Bf0));
    __hv_varwrite_f(&sVarf_oAwFFC3n, VIf(Bf2));
    __hv_varwrite_f(&sVarf_xKglvWYP, VIf(Bf18));
    __hv_varread_f(&sVarf_xKglvWYP, VOf(Bf18));
    __hv_line_f(&sLine_mPHkToZa, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_lvZzo5gV, VIf(Bf0));
    __hv_varread_f(&sVarf_oAwFFC3n, VOf(Bf0));
    __hv_line_f(&sLine_y1rWFdUu, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_NCT0qabi, VIf(Bf0));
    __hv_varwrite_f(&sVarf_hPWkA7IK, VIf(Bf10));
    __hv_varread_f(&sVarf_PoxVzO9R, VOf(Bf10));
    __hv_varread_f(&sVarf_J8vmWd6b, VOf(Bf0));
    __hv_varread_f(&sVarf_43uMA4fo, VOf(Bf15));
    __hv_varread_f(&sVarf_cXXy78bn, VOf(Bf2));
    __hv_varread_f(&sVarf_PKP7lM0r, VOf(Bf6));
    __hv_varread_f(&sVarf_4NNInWiE, VOf(Bf18));
    __hv_varread_f(&sVarf_hx0Miwa3, VOf(Bf13));
    __hv_varwrite_f(&sVarf_B6Yg8hcx, VIf(Bf4));
    __hv_varread_f(&sVarf_dAIPgKsV, VOf(Bf11));
    __hv_line_f(&sLine_QSV7jF2H, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_lYKdZe1E, VOf(Bf17));
    __hv_line_f(&sLine_VBzNERzf, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_p3gZauHs, VOf(Bf16));
    __hv_line_f(&sLine_G7K66R7F, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_cXXy78bn, VIf(Bf19));
    __hv_varread_f(&sVarf_B6Yg8hcx, VOf(Bf19));
    __hv_line_f(&sLine_oq5JqRbj, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_kb37IWWA, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_EhzHw3xI, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_PKP7lM0r, VIf(Bf1));
    __hv_line_f(&sLine_NWPIlSaB, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_Km2eSX9z, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_27HAHVZx, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_4NNInWiE, VIf(Bf1));
    __hv_line_f(&sLine_TqENmSrB, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_Yn7gINbm, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_W81k2cl1, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_hx0Miwa3, VIf(Bf1));
    __hv_varwrite_f(&sVarf_dAIPgKsV, VIf(Bf10));
    __hv_varwrite_f(&sVarf_lYKdZe1E, VIf(Bf0));
    __hv_varwrite_f(&sVarf_p3gZauHs, VIf(Bf15));
    sEnv_process(this, &sEnv_rdO8K1Wn, VIf(Bf2), &sEnv_rdO8K1Wn_sendMessage);
    sEnv_process(this, &sEnv_pARMQSOW, VIf(Bf4), &sEnv_pARMQSOW_sendMessage);
    __hv_line_f(&sLine_ZLv5Oz5S, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_EHB8fYs2, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_UmUlPt9H, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_9CTwNomO, VOf(Bf2));
    __hv_line_f(&sLine_e0qFycQ2, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_PoxVzO9R, VIf(Bf0));
    __hv_varwrite_f(&sVarf_9CTwNomO, VIf(Bf6));
    __hv_varwrite_f(&sVarf_3ESRZ7r6, VIf(Bf18));
    __hv_varwrite_f(&sVarf_rYqjhZJq, VIf(Bf13));
    __hv_varread_f(&sVarf_rYqjhZJq, VOf(Bf13));
    __hv_line_f(&sLine_ysdqPJbW, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_43uMA4fo, VIf(Bf6));
    __hv_varread_f(&sVarf_3ESRZ7r6, VOf(Bf6));
    __hv_line_f(&sLine_MaiJM1Ul, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_J8vmWd6b, VIf(Bf6));
    __hv_varwrite_f(&sVarf_oHc3q8G0, VIf(Bf4));
    __hv_varwrite_f(&sVarf_U3bnt8u9, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Kvtdbswp, VIf(Bf8));
    __hv_varwrite_f(&sVarf_7Uoz1Hxn, VIf(Bf9));
    __hv_varwrite_f(&sVarf_fBp5DmdP, VIf(Bf12));
    __hv_varwrite_f(&sVarf_CQNAGpX3, VIf(Bf3));
    __hv_varwrite_f(&sVarf_kpdvl9H7, VIf(Bf5));
    __hv_varread_f(&sVarf_cZQ8Z0JD, VOf(Bf5));
    __hv_varread_f(&sVarf_dMko461o, VOf(Bf3));
    __hv_varread_f(&sVarf_U3bnt8u9, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_Kvtdbswp, VOf(Bf12));
    __hv_varread_f(&sVarf_7Uoz1Hxn, VOf(Bf5));
    __hv_varread_f(&sVarf_fBp5DmdP, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
